pub enum Report<'a> {
Error(u32),
Context(&'a CStr),
FromPid(u32),
FromTid(u32),
ToPid(u32),
ToTid(u32),
IsReply(()),
Flags(u32),
Code(u32),
DataSize(u32),
}Available on crate feature
binder only.Variants
Error(u32)
The enum binder_driver_return_protocol returned to the sender.
Context(&'a CStr)
The binder context where the transaction occurred.
FromPid(u32)
The PID of the sender process.
FromTid(u32)
The TID of the sender thread.
ToPid(u32)
The PID of the recipient process. This attribute may not be present if the target could not be determined.
ToTid(u32)
The TID of the recipient thread. This attribute may not be present if the target could not be determined.
IsReply(())
When present, indicates the failed transaction is a reply.
Flags(u32)
The bitmask of enum transaction_flags from the transaction.
Code(u32)
The application-defined code from the transaction.
DataSize(u32)
The transaction payload size in bytes.
Implementations