PushReport

Struct PushReport 

pub struct PushReport<Prev: Rec> { /* private fields */ }
Available on crate feature binder only.

Implementations

Source

impl<Prev: Rec> PushReport<Prev>

pub fn new(prev: Prev) -> Self

pub fn end_nested(self) -> Prev

pub fn push_error(self, value: u32) -> Self

The enum binder_driver_return_protocol returned to the sender.

pub fn push_context(self, value: &CStr) -> Self

The binder context where the transaction occurred.

pub fn push_context_bytes(self, value: &[u8]) -> Self

The binder context where the transaction occurred.

pub fn push_from_pid(self, value: u32) -> Self

The PID of the sender process.

pub fn push_from_tid(self, value: u32) -> Self

The TID of the sender thread.

pub fn push_to_pid(self, value: u32) -> Self

The PID of the recipient process. This attribute may not be present if the target could not be determined.

pub fn push_to_tid(self, value: u32) -> Self

The TID of the recipient thread. This attribute may not be present if the target could not be determined.

pub fn push_is_reply(self, value: ()) -> Self

When present, indicates the failed transaction is a reply.

pub fn push_flags(self, value: u32) -> Self

The bitmask of enum transaction_flags from the transaction.

pub fn push_code(self, value: u32) -> Self

The application-defined code from the transaction.

pub fn push_data_size(self, value: u32) -> Self

The transaction payload size in bytes.