Module dev_energymodel

Module dev_energymodel 

Available on crate feature dev-energymodel only.
Energy model netlink interface to notify its changes.

Structs

IterablePerfDomain
IterablePerfState
IterablePerfTable
NotifGroup
OpGetPerfDomainsDo
Get the list of information for all performance domains.
OpGetPerfDomainsDump
Get the list of information for all performance domains.
OpGetPerfTableDo
Get the energy model table of a performance domain.
OpPerfDomainCreatedNotif
Notify attributes:
OpPerfDomainDeletedNotif
Notify attributes:
OpPerfDomainUpdatedNotif
Notify attributes:
PushPerfDomain
PushPerfState
PushPerfTable
Request
RequestInfo

Enums

PerfDomain
PerfDomainFlags
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
PerfState
PerfStateFlags
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
PerfTable

Constants

PROTONAME
PROTONAME_CSTR