pub enum PerfDomainFlags {
PerfDomainMicrowatts = 1,
PerfDomainSkipInefficiencies = 2,
PerfDomainArtificial = 4,
}Available on crate feature
dev-energymodel only.Expand description
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
Variants
PerfDomainMicrowatts = 1
The power values are in micro-Watts or some other scale.
PerfDomainSkipInefficiencies = 2
Skip inefficient states when estimating energy consumption.
PerfDomainArtificial = 4
The power values are artificial and might be created by platform missing real power information.
Implementations
Sourceimpl PerfDomainFlags
impl PerfDomainFlags
pub fn from_value(value: u64) -> Option<Self>