pub enum PerfStateFlags {
PerfStateInefficient = 1,
}Available on crate feature
dev-energymodel only.Expand description
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
Variants
PerfStateInefficient = 1
The performance state is inefficient. There is in this perf-domain, another performance state with a higher frequency but a lower or equal power cost.
Implementations
Sourceimpl PerfStateFlags
impl PerfStateFlags
pub fn from_value(value: u64) -> Option<Self>