pub struct Request<'buf> { /* private fields */ }Available on crate feature
dev-energymodel only.Implementations
Sourceimpl<'buf> Request<'buf>
impl<'buf> Request<'buf>
pub fn new_with_buf(buf: &'buf mut Vec<u8>) -> Self
pub fn new_extend(buf: &'buf mut Vec<u8>) -> Self
pub fn buf(&self) -> &Vec<u8> ⓘ
pub fn buf_mut(&mut self) -> &mut Vec<u8> ⓘ
Sourcepub fn set_create(self) -> Self
pub fn set_create(self) -> Self
Set NLM_F_CREATE flag
Sourcepub fn set_replace(self) -> Self
pub fn set_replace(self) -> Self
Set NLM_F_REPLACE flag
Sourcepub fn set_change(self) -> Self
pub fn set_change(self) -> Self
Set NLM_F_CREATE and NLM_F_REPLACE flag
Sourcepub fn set_append(self) -> Self
pub fn set_append(self) -> Self
Set NLM_F_APPEND flag
Sourcepub fn unset_flags(self, flags: u16) -> Self
pub fn unset_flags(self, flags: u16) -> Self
Set self.flags ^= self.flags & flags
Sourcepub fn op_get_perf_domains_dump(self) -> OpGetPerfDomainsDump<'buf>
pub fn op_get_perf_domains_dump(self) -> OpGetPerfDomainsDump<'buf>
Get the list of information for all performance domains.
Reply attributes:
Sourcepub fn op_get_perf_domains_do(self) -> OpGetPerfDomainsDo<'buf>
pub fn op_get_perf_domains_do(self) -> OpGetPerfDomainsDo<'buf>
Get the list of information for all performance domains. Request attributes:
Reply attributes:
Sourcepub fn op_get_perf_table_do(self) -> OpGetPerfTableDo<'buf>
pub fn op_get_perf_table_do(self) -> OpGetPerfTableDo<'buf>
Get the energy model table of a performance domain. Request attributes:
Reply attributes: