Available on crate feature
devlink only.Expand description
Partial family for Devlink.
Structs
- Iterable
Devlink - Iterable
DlAttr Stats - Iterable
DlDev Stats - Iterable
DlDpipe Action - Iterable
DlDpipe Action Value - Iterable
DlDpipe Entries - Iterable
DlDpipe Entry - Iterable
DlDpipe Entry Action Values - Iterable
DlDpipe Entry Match Values - Iterable
DlDpipe Field - Iterable
DlDpipe Header - Iterable
DlDpipe Header Fields - Iterable
DlDpipe Headers - Iterable
DlDpipe Match - Iterable
DlDpipe Match Value - Iterable
DlDpipe Table - Iterable
DlDpipe Table Actions - Iterable
DlDpipe Table Matches - Iterable
DlDpipe Tables - Iterable
DlFmsg - Iterable
DlHealth Reporter - Iterable
DlInfo Version - Iterable
DlLinecard Supported Types - Iterable
DlParam - Iterable
DlPort Function - Iterable
DlRate TcBws - Iterable
DlRegion Chunk - Iterable
DlRegion Chunks - Iterable
DlRegion Snapshot - Iterable
DlRegion Snapshots - Iterable
DlReload ActInfo - Iterable
DlReload ActStats - Iterable
DlReload Stats - Iterable
DlReload Stats Entry - Iterable
DlResource - Iterable
DlResource List - Iterable
DlSelftest Id - Iterable
DlTrap Metadata - OpDpipe
Entries GetDo - Get dpipe entries attributes.
- OpDpipe
Headers GetDo - Get dpipe headers attributes.
- OpDpipe
Table Counters SetDo - Set dpipe counter attributes.
- OpDpipe
Table GetDo - Get dpipe table attributes.
- OpEswitch
GetDo - Get eswitch attributes.
- OpEswitch
SetDo - Set eswitch attributes.
- OpFlash
Update Do - Flash update devlink instances.
- OpGetDo
- Get devlink instances.
- OpGet
Dump - Get devlink instances.
- OpHealth
Reporter Diagnose Do - Diagnose health reporter instances.
- OpHealth
Reporter Dump Clear Do - Clear dump of health reporter instances.
- OpHealth
Reporter Dump GetDump - Dump health reporter instances.
- OpHealth
Reporter GetDo - Get health reporter instances.
- OpHealth
Reporter GetDump - Get health reporter instances.
- OpHealth
Reporter Recover Do - Recover health reporter instances.
- OpHealth
Reporter SetDo - Set health reporter instances.
- OpHealth
Reporter Test Do - Test health reporter instances.
- OpInfo
GetDo - Get device information, like driver name, hardware and firmware versions etc.
- OpInfo
GetDump - Get device information, like driver name, hardware and firmware versions etc.
- OpLinecard
GetDo - Get line card instances.
- OpLinecard
GetDump - Get line card instances.
- OpLinecard
SetDo - Set line card instances.
- OpNotify
Filter SetDo - Set notification messages socket filter.
- OpParam
GetDo - Get param instances.
- OpParam
GetDump - Get param instances.
- OpParam
SetDo - Set param instances.
- OpPort
DelDo - Delete devlink port instances.
- OpPort
GetDo - Get devlink port instances.
- OpPort
GetDump - Get devlink port instances.
- OpPort
NewDo - Create devlink port instances.
- OpPort
Param GetDo - Get port param instances.
- OpPort
Param GetDump - Get port param instances.
- OpPort
Param SetDo - Set port param instances.
- OpPort
SetDo - Set devlink port instances.
- OpPort
Split Do - Split devlink port instances.
- OpPort
Unsplit Do - Unplit devlink port instances.
- OpRate
DelDo - Delete rate instances.
- OpRate
GetDo - Get rate instances.
- OpRate
GetDump - Get rate instances.
- OpRate
NewDo - Create rate instances.
- OpRate
SetDo - Set rate instances.
- OpRegion
DelDo - Delete region snapshot.
- OpRegion
GetDo - Get region instances.
- OpRegion
GetDump - Get region instances.
- OpRegion
NewDo - Create region snapshot.
- OpRegion
Read Dump - Read region data.
- OpReload
Do - Reload devlink.
- OpResource
Dump Do - Get resource attributes.
- OpResource
Dump Dump - Get resource attributes.
- OpResource
SetDo - Set resource attributes.
- OpSb
GetDo - Get shared buffer instances.
- OpSb
GetDump - Get shared buffer instances.
- OpSb
OccMax Clear Do - Clear occupancy watermarks of shared buffer.
- OpSb
OccSnapshot Do - Take occupancy snapshot of shared buffer.
- OpSb
Pool GetDo - Get shared buffer pool instances.
- OpSb
Pool GetDump - Get shared buffer pool instances.
- OpSb
Pool SetDo - Set shared buffer pool instances.
- OpSb
Port Pool GetDo - Get shared buffer port-pool combinations and threshold.
- OpSb
Port Pool GetDump - Get shared buffer port-pool combinations and threshold.
- OpSb
Port Pool SetDo - Set shared buffer port-pool combinations and threshold.
- OpSb
TcPool Bind GetDo - Get shared buffer port-TC to pool bindings and threshold.
- OpSb
TcPool Bind GetDump - Get shared buffer port-TC to pool bindings and threshold.
- OpSb
TcPool Bind SetDo - Set shared buffer port-TC to pool bindings and threshold.
- OpSelftests
GetDo - Get device selftest instances.
- OpSelftests
GetDump - Get device selftest instances.
- OpSelftests
RunDo - Run device selftest instances.
- OpTrap
GetDo - Get trap instances.
- OpTrap
GetDump - Get trap instances.
- OpTrap
Group GetDo - Get trap group instances.
- OpTrap
Group GetDump - Get trap group instances.
- OpTrap
Group SetDo - Set trap group instances.
- OpTrap
Policer GetDo - Get trap policer instances.
- OpTrap
Policer GetDump - Get trap policer instances.
- OpTrap
Policer SetDo - Get trap policer instances.
- OpTrap
SetDo - Set trap instances.
- Push
Devlink - Push
DlAttr Stats - Push
DlDev Stats - Push
DlDpipe Action - Push
DlDpipe Action Value - Push
DlDpipe Entries - Push
DlDpipe Entry - Push
DlDpipe Entry Action Values - Push
DlDpipe Entry Match Values - Push
DlDpipe Field - Push
DlDpipe Header - Push
DlDpipe Header Fields - Push
DlDpipe Headers - Push
DlDpipe Match - Push
DlDpipe Match Value - Push
DlDpipe Table - Push
DlDpipe Table Actions - Push
DlDpipe Table Matches - Push
DlDpipe Tables - Push
DlFmsg - Push
DlHealth Reporter - Push
DlInfo Version - Push
DlLinecard Supported Types - Push
DlParam - Push
DlPort Function - Push
DlRate TcBws - Push
DlRegion Chunk - Push
DlRegion Chunks - Push
DlRegion Snapshot - Push
DlRegion Snapshots - Push
DlReload ActInfo - Push
DlReload ActStats - Push
DlReload Stats - Push
DlReload Stats Entry - Push
DlResource - Push
DlResource List - Push
DlSelftest Id - Push
DlTrap Metadata - Request
- Request
Info
Enums
- Devlink
- DlAttr
Stats - DlDev
Stats - DlDpipe
Action - DlDpipe
Action Value - DlDpipe
Entries - DlDpipe
Entry - DlDpipe
Entry Action Values - DlDpipe
Entry Match Values - DlDpipe
Field - DlDpipe
Header - DlDpipe
Header Fields - DlDpipe
Headers - DlDpipe
Match - DlDpipe
Match Value - DlDpipe
Table - DlDpipe
Table Actions - DlDpipe
Table Matches - DlDpipe
Tables - DlFmsg
- DlHealth
Reporter - DlInfo
Version - DlLinecard
Supported Types - DlParam
- DlPort
Function - DlRate
TcBws - DlRegion
Chunk - DlRegion
Chunks - DlRegion
Snapshot - DlRegion
Snapshots - DlReload
ActInfo - DlReload
ActStats - DlReload
Stats - DlReload
Stats Entry - DlResource
- DlResource
List - DlSelftest
Id - DlTrap
Metadata - Dpipe
Action Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Dpipe
Field Mapping Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Dpipe
Header Id - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Dpipe
Match Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Eswitch
Encap Mode - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Eswitch
Inline Mode - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Eswitch
Mode - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Flash
Overwrite - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Param
Cmode - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Port
Flavour - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Port
FnAttr Cap - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Port
FnOpstate - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Port
FnState - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Port
Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Rate
Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Reload
Action - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Resource
Scope - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Resource
Unit - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- SbPool
Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- SbThreshold
Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Trap
Action - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Trap
Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- VarAttr
Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)