pub enum DlRateTcBws {
Index(u8),
Bw(u32),
}Available on crate feature
devlink only.Variants
Index(u8)
Bw(u32)
Specifies the bandwidth share assigned to the Traffic Class. The bandwidth for the traffic class is determined in proportion to the sum of the shares of all configured classes.
Implementations
Sourceimpl DlRateTcBws
impl DlRateTcBws
pub fn new<'a>(buf: &'a [u8]) -> IterableDlRateTcBws<'a> ⓘ