PushDlRateTcBws

Struct PushDlRateTcBws 

pub struct PushDlRateTcBws<Prev: Pusher> { /* private fields */ }
Available on crate feature devlink only.

Implementations

Source

impl<Prev: Pusher> PushDlRateTcBws<Prev>

pub fn new(prev: Prev) -> Self

pub fn end_nested(self) -> Prev

pub fn push_index(self, value: u8) -> Self

pub fn push_bw(self, value: u32) -> Self

Specifies the bandwidth share assigned to the Traffic Class. The bandwidth for the traffic class is determined in proportion to the sum of the shares of all configured classes.