pub struct Request<'buf> { /* private fields */ }devlink only.Implementations
Sourceimpl<'buf> Request<'buf>
impl<'buf> Request<'buf>
pub fn new_with_buf(buf: &'buf mut Vec<u8>) -> Self
pub fn new_extend(buf: &'buf mut Vec<u8>) -> Self
pub fn buf(&self) -> &Vec<u8> ⓘ
pub fn buf_mut(&mut self) -> &mut Vec<u8> ⓘ
Sourcepub fn set_create(self) -> Self
pub fn set_create(self) -> Self
Set NLM_F_CREATE flag
Sourcepub fn set_replace(self) -> Self
pub fn set_replace(self) -> Self
Set NLM_F_REPLACE flag
Sourcepub fn set_change(self) -> Self
pub fn set_change(self) -> Self
Set NLM_F_CREATE and NLM_F_REPLACE flag
Sourcepub fn set_append(self) -> Self
pub fn set_append(self) -> Self
Set NLM_F_APPEND flag
Sourcepub fn unset_flags(self, flags: u16) -> Self
pub fn unset_flags(self, flags: u16) -> Self
Set self.flags ^= self.flags & flags
Sourcepub fn op_get_dump(self) -> OpGetDump<'buf>
pub fn op_get_dump(self) -> OpGetDump<'buf>
Get devlink instances.
Reply attributes:
Sourcepub fn op_get_do(self) -> OpGetDo<'buf>
pub fn op_get_do(self) -> OpGetDo<'buf>
Get devlink instances. Request attributes:
Reply attributes:
Sourcepub fn op_port_get_dump(self) -> OpPortGetDump<'buf>
pub fn op_port_get_dump(self) -> OpPortGetDump<'buf>
Get devlink port instances. Request attributes:
Reply attributes:
Sourcepub fn op_port_get_do(self) -> OpPortGetDo<'buf>
pub fn op_port_get_do(self) -> OpPortGetDo<'buf>
Get devlink port instances. Request attributes:
Reply attributes:
Sourcepub fn op_port_set_do(self) -> OpPortSetDo<'buf>
pub fn op_port_set_do(self) -> OpPortSetDo<'buf>
Set devlink port instances. Flags: admin-perm Request attributes:
Sourcepub fn op_port_new_do(self) -> OpPortNewDo<'buf>
pub fn op_port_new_do(self) -> OpPortNewDo<'buf>
Create devlink port instances. Flags: admin-perm Request attributes:
- .push_bus_name()
- .push_dev_name()
- .push_port_index()
- .push_port_flavour()
- .push_port_pci_pf_number()
- .push_port_controller_number()
- .push_port_pci_sf_number()
Reply attributes:
Sourcepub fn op_port_del_do(self) -> OpPortDelDo<'buf>
pub fn op_port_del_do(self) -> OpPortDelDo<'buf>
Delete devlink port instances. Flags: admin-perm Request attributes:
Sourcepub fn op_port_split_do(self) -> OpPortSplitDo<'buf>
pub fn op_port_split_do(self) -> OpPortSplitDo<'buf>
Split devlink port instances. Flags: admin-perm Request attributes:
Sourcepub fn op_port_unsplit_do(self) -> OpPortUnsplitDo<'buf>
pub fn op_port_unsplit_do(self) -> OpPortUnsplitDo<'buf>
Unplit devlink port instances. Flags: admin-perm Request attributes:
Sourcepub fn op_sb_get_dump(self) -> OpSbGetDump<'buf>
pub fn op_sb_get_dump(self) -> OpSbGetDump<'buf>
Get shared buffer instances. Request attributes:
Reply attributes:
Sourcepub fn op_sb_get_do(self) -> OpSbGetDo<'buf>
pub fn op_sb_get_do(self) -> OpSbGetDo<'buf>
Get shared buffer instances. Request attributes:
Reply attributes:
Sourcepub fn op_sb_pool_get_dump(self) -> OpSbPoolGetDump<'buf>
pub fn op_sb_pool_get_dump(self) -> OpSbPoolGetDump<'buf>
Get shared buffer pool instances. Request attributes:
Reply attributes:
Sourcepub fn op_sb_pool_get_do(self) -> OpSbPoolGetDo<'buf>
pub fn op_sb_pool_get_do(self) -> OpSbPoolGetDo<'buf>
Get shared buffer pool instances. Request attributes:
Reply attributes:
Sourcepub fn op_sb_pool_set_do(self) -> OpSbPoolSetDo<'buf>
pub fn op_sb_pool_set_do(self) -> OpSbPoolSetDo<'buf>
Set shared buffer pool instances. Flags: admin-perm Request attributes:
Sourcepub fn op_sb_port_pool_get_dump(self) -> OpSbPortPoolGetDump<'buf>
pub fn op_sb_port_pool_get_dump(self) -> OpSbPortPoolGetDump<'buf>
Get shared buffer port-pool combinations and threshold. Request attributes:
Reply attributes:
Sourcepub fn op_sb_port_pool_get_do(self) -> OpSbPortPoolGetDo<'buf>
pub fn op_sb_port_pool_get_do(self) -> OpSbPortPoolGetDo<'buf>
Get shared buffer port-pool combinations and threshold. Request attributes:
Reply attributes:
Sourcepub fn op_sb_port_pool_set_do(self) -> OpSbPortPoolSetDo<'buf>
pub fn op_sb_port_pool_set_do(self) -> OpSbPortPoolSetDo<'buf>
Set shared buffer port-pool combinations and threshold. Flags: admin-perm Request attributes:
Sourcepub fn op_sb_tc_pool_bind_get_dump(self) -> OpSbTcPoolBindGetDump<'buf>
pub fn op_sb_tc_pool_bind_get_dump(self) -> OpSbTcPoolBindGetDump<'buf>
Get shared buffer port-TC to pool bindings and threshold. Request attributes:
Reply attributes:
Sourcepub fn op_sb_tc_pool_bind_get_do(self) -> OpSbTcPoolBindGetDo<'buf>
pub fn op_sb_tc_pool_bind_get_do(self) -> OpSbTcPoolBindGetDo<'buf>
Get shared buffer port-TC to pool bindings and threshold. Request attributes:
- .push_bus_name()
- .push_dev_name()
- .push_port_index()
- .push_sb_index()
- .push_sb_pool_type()
- .push_sb_tc_index()
Reply attributes:
Sourcepub fn op_sb_tc_pool_bind_set_do(self) -> OpSbTcPoolBindSetDo<'buf>
pub fn op_sb_tc_pool_bind_set_do(self) -> OpSbTcPoolBindSetDo<'buf>
Set shared buffer port-TC to pool bindings and threshold. Flags: admin-perm Request attributes:
Sourcepub fn op_sb_occ_snapshot_do(self) -> OpSbOccSnapshotDo<'buf>
pub fn op_sb_occ_snapshot_do(self) -> OpSbOccSnapshotDo<'buf>
Take occupancy snapshot of shared buffer. Flags: admin-perm Request attributes:
Sourcepub fn op_sb_occ_max_clear_do(self) -> OpSbOccMaxClearDo<'buf>
pub fn op_sb_occ_max_clear_do(self) -> OpSbOccMaxClearDo<'buf>
Clear occupancy watermarks of shared buffer. Flags: admin-perm Request attributes:
Sourcepub fn op_eswitch_get_do(self) -> OpEswitchGetDo<'buf>
pub fn op_eswitch_get_do(self) -> OpEswitchGetDo<'buf>
Get eswitch attributes. Flags: admin-perm Request attributes:
Reply attributes:
Sourcepub fn op_eswitch_set_do(self) -> OpEswitchSetDo<'buf>
pub fn op_eswitch_set_do(self) -> OpEswitchSetDo<'buf>
Set eswitch attributes. Flags: admin-perm Request attributes:
Sourcepub fn op_dpipe_table_get_do(self) -> OpDpipeTableGetDo<'buf>
pub fn op_dpipe_table_get_do(self) -> OpDpipeTableGetDo<'buf>
Get dpipe table attributes. Request attributes:
Reply attributes:
Sourcepub fn op_dpipe_entries_get_do(self) -> OpDpipeEntriesGetDo<'buf>
pub fn op_dpipe_entries_get_do(self) -> OpDpipeEntriesGetDo<'buf>
Get dpipe entries attributes. Request attributes:
Reply attributes:
Sourcepub fn op_dpipe_headers_get_do(self) -> OpDpipeHeadersGetDo<'buf>
pub fn op_dpipe_headers_get_do(self) -> OpDpipeHeadersGetDo<'buf>
Get dpipe headers attributes. Request attributes:
Reply attributes:
Sourcepub fn op_dpipe_table_counters_set_do(self) -> OpDpipeTableCountersSetDo<'buf>
pub fn op_dpipe_table_counters_set_do(self) -> OpDpipeTableCountersSetDo<'buf>
Set dpipe counter attributes. Flags: admin-perm Request attributes:
Sourcepub fn op_resource_set_do(self) -> OpResourceSetDo<'buf>
pub fn op_resource_set_do(self) -> OpResourceSetDo<'buf>
Set resource attributes. Flags: admin-perm Request attributes:
Sourcepub fn op_resource_dump_do(self) -> OpResourceDumpDo<'buf>
pub fn op_resource_dump_do(self) -> OpResourceDumpDo<'buf>
Get resource attributes. Request attributes:
Reply attributes:
Sourcepub fn op_reload_do(self) -> OpReloadDo<'buf>
pub fn op_reload_do(self) -> OpReloadDo<'buf>
Reload devlink. Flags: admin-perm Request attributes:
- .push_bus_name()
- .push_dev_name()
- .push_netns_fd()
- .push_netns_pid()
- .push_netns_id()
- .push_reload_action()
- .push_reload_limits()
Reply attributes:
Sourcepub fn op_param_get_dump(self) -> OpParamGetDump<'buf>
pub fn op_param_get_dump(self) -> OpParamGetDump<'buf>
Get param instances. Request attributes:
Reply attributes:
Sourcepub fn op_param_get_do(self) -> OpParamGetDo<'buf>
pub fn op_param_get_do(self) -> OpParamGetDo<'buf>
Get param instances. Request attributes:
Reply attributes:
Sourcepub fn op_param_set_do(self) -> OpParamSetDo<'buf>
pub fn op_param_set_do(self) -> OpParamSetDo<'buf>
Set param instances. Flags: admin-perm Request attributes:
Sourcepub fn op_region_get_dump(self) -> OpRegionGetDump<'buf>
pub fn op_region_get_dump(self) -> OpRegionGetDump<'buf>
Get region instances. Request attributes:
Reply attributes:
Sourcepub fn op_region_get_do(self) -> OpRegionGetDo<'buf>
pub fn op_region_get_do(self) -> OpRegionGetDo<'buf>
Get region instances. Request attributes:
Reply attributes:
Sourcepub fn op_region_new_do(self) -> OpRegionNewDo<'buf>
pub fn op_region_new_do(self) -> OpRegionNewDo<'buf>
Create region snapshot. Flags: admin-perm Request attributes:
Reply attributes:
Sourcepub fn op_region_del_do(self) -> OpRegionDelDo<'buf>
pub fn op_region_del_do(self) -> OpRegionDelDo<'buf>
Delete region snapshot. Flags: admin-perm Request attributes:
Sourcepub fn op_region_read_dump(self) -> OpRegionReadDump<'buf>
pub fn op_region_read_dump(self) -> OpRegionReadDump<'buf>
Read region data. Flags: admin-perm Request attributes:
- .push_bus_name()
- .push_dev_name()
- .push_port_index()
- .push_region_name()
- .push_region_snapshot_id()
- .push_region_chunk_addr()
- .push_region_chunk_len()
- .push_region_direct()
Reply attributes:
Sourcepub fn op_port_param_get_dump(self) -> OpPortParamGetDump<'buf>
pub fn op_port_param_get_dump(self) -> OpPortParamGetDump<'buf>
Sourcepub fn op_port_param_get_do(self) -> OpPortParamGetDo<'buf>
pub fn op_port_param_get_do(self) -> OpPortParamGetDo<'buf>
Get port param instances. Request attributes:
Reply attributes:
Sourcepub fn op_port_param_set_do(self) -> OpPortParamSetDo<'buf>
pub fn op_port_param_set_do(self) -> OpPortParamSetDo<'buf>
Set port param instances. Flags: admin-perm Request attributes:
Sourcepub fn op_info_get_dump(self) -> OpInfoGetDump<'buf>
pub fn op_info_get_dump(self) -> OpInfoGetDump<'buf>
Get device information, like driver name, hardware and firmware versions etc.
Reply attributes:
Sourcepub fn op_info_get_do(self) -> OpInfoGetDo<'buf>
pub fn op_info_get_do(self) -> OpInfoGetDo<'buf>
Get device information, like driver name, hardware and firmware versions etc.
Request attributes:
Reply attributes:
Sourcepub fn op_health_reporter_get_dump(self) -> OpHealthReporterGetDump<'buf>
pub fn op_health_reporter_get_dump(self) -> OpHealthReporterGetDump<'buf>
Get health reporter instances. Request attributes:
Reply attributes:
Sourcepub fn op_health_reporter_get_do(self) -> OpHealthReporterGetDo<'buf>
pub fn op_health_reporter_get_do(self) -> OpHealthReporterGetDo<'buf>
Get health reporter instances. Request attributes:
Reply attributes:
Sourcepub fn op_health_reporter_set_do(self) -> OpHealthReporterSetDo<'buf>
pub fn op_health_reporter_set_do(self) -> OpHealthReporterSetDo<'buf>
Set health reporter instances. Flags: admin-perm Request attributes:
Sourcepub fn op_health_reporter_recover_do(self) -> OpHealthReporterRecoverDo<'buf>
pub fn op_health_reporter_recover_do(self) -> OpHealthReporterRecoverDo<'buf>
Recover health reporter instances. Flags: admin-perm Request attributes:
Sourcepub fn op_health_reporter_diagnose_do(self) -> OpHealthReporterDiagnoseDo<'buf>
pub fn op_health_reporter_diagnose_do(self) -> OpHealthReporterDiagnoseDo<'buf>
Diagnose health reporter instances. Flags: admin-perm Request attributes:
Sourcepub fn op_health_reporter_dump_get_dump(
self,
) -> OpHealthReporterDumpGetDump<'buf>
pub fn op_health_reporter_dump_get_dump( self, ) -> OpHealthReporterDumpGetDump<'buf>
Dump health reporter instances. Flags: admin-perm Request attributes:
Reply attributes:
Sourcepub fn op_health_reporter_dump_clear_do(
self,
) -> OpHealthReporterDumpClearDo<'buf>
pub fn op_health_reporter_dump_clear_do( self, ) -> OpHealthReporterDumpClearDo<'buf>
Clear dump of health reporter instances. Flags: admin-perm Request attributes:
Sourcepub fn op_flash_update_do(self) -> OpFlashUpdateDo<'buf>
pub fn op_flash_update_do(self) -> OpFlashUpdateDo<'buf>
Flash update devlink instances. Flags: admin-perm Request attributes:
Sourcepub fn op_trap_get_dump(self) -> OpTrapGetDump<'buf>
pub fn op_trap_get_dump(self) -> OpTrapGetDump<'buf>
Get trap instances. Request attributes:
Reply attributes:
Sourcepub fn op_trap_get_do(self) -> OpTrapGetDo<'buf>
pub fn op_trap_get_do(self) -> OpTrapGetDo<'buf>
Get trap instances. Request attributes:
Reply attributes:
Sourcepub fn op_trap_set_do(self) -> OpTrapSetDo<'buf>
pub fn op_trap_set_do(self) -> OpTrapSetDo<'buf>
Set trap instances. Flags: admin-perm Request attributes:
Sourcepub fn op_trap_group_get_dump(self) -> OpTrapGroupGetDump<'buf>
pub fn op_trap_group_get_dump(self) -> OpTrapGroupGetDump<'buf>
Get trap group instances. Request attributes:
Reply attributes:
Sourcepub fn op_trap_group_get_do(self) -> OpTrapGroupGetDo<'buf>
pub fn op_trap_group_get_do(self) -> OpTrapGroupGetDo<'buf>
Get trap group instances. Request attributes:
Reply attributes:
Sourcepub fn op_trap_group_set_do(self) -> OpTrapGroupSetDo<'buf>
pub fn op_trap_group_set_do(self) -> OpTrapGroupSetDo<'buf>
Set trap group instances. Flags: admin-perm Request attributes:
Sourcepub fn op_trap_policer_get_dump(self) -> OpTrapPolicerGetDump<'buf>
pub fn op_trap_policer_get_dump(self) -> OpTrapPolicerGetDump<'buf>
Get trap policer instances. Request attributes:
Reply attributes:
Sourcepub fn op_trap_policer_get_do(self) -> OpTrapPolicerGetDo<'buf>
pub fn op_trap_policer_get_do(self) -> OpTrapPolicerGetDo<'buf>
Get trap policer instances. Request attributes:
Reply attributes:
Sourcepub fn op_trap_policer_set_do(self) -> OpTrapPolicerSetDo<'buf>
pub fn op_trap_policer_set_do(self) -> OpTrapPolicerSetDo<'buf>
Get trap policer instances. Flags: admin-perm Request attributes:
Sourcepub fn op_health_reporter_test_do(self) -> OpHealthReporterTestDo<'buf>
pub fn op_health_reporter_test_do(self) -> OpHealthReporterTestDo<'buf>
Test health reporter instances. Flags: admin-perm Request attributes:
Sourcepub fn op_rate_get_dump(self) -> OpRateGetDump<'buf>
pub fn op_rate_get_dump(self) -> OpRateGetDump<'buf>
Get rate instances. Request attributes:
Reply attributes:
Sourcepub fn op_rate_get_do(self) -> OpRateGetDo<'buf>
pub fn op_rate_get_do(self) -> OpRateGetDo<'buf>
Get rate instances. Request attributes:
Reply attributes:
Sourcepub fn op_rate_set_do(self) -> OpRateSetDo<'buf>
pub fn op_rate_set_do(self) -> OpRateSetDo<'buf>
Set rate instances. Flags: admin-perm Request attributes:
Sourcepub fn op_rate_new_do(self) -> OpRateNewDo<'buf>
pub fn op_rate_new_do(self) -> OpRateNewDo<'buf>
Create rate instances. Flags: admin-perm Request attributes:
Sourcepub fn op_rate_del_do(self) -> OpRateDelDo<'buf>
pub fn op_rate_del_do(self) -> OpRateDelDo<'buf>
Delete rate instances. Flags: admin-perm Request attributes:
Sourcepub fn op_linecard_get_dump(self) -> OpLinecardGetDump<'buf>
pub fn op_linecard_get_dump(self) -> OpLinecardGetDump<'buf>
Get line card instances. Request attributes:
Reply attributes:
Sourcepub fn op_linecard_get_do(self) -> OpLinecardGetDo<'buf>
pub fn op_linecard_get_do(self) -> OpLinecardGetDo<'buf>
Get line card instances. Request attributes:
Reply attributes:
Sourcepub fn op_linecard_set_do(self) -> OpLinecardSetDo<'buf>
pub fn op_linecard_set_do(self) -> OpLinecardSetDo<'buf>
Set line card instances. Flags: admin-perm Request attributes:
Sourcepub fn op_selftests_get_dump(self) -> OpSelftestsGetDump<'buf>
pub fn op_selftests_get_dump(self) -> OpSelftestsGetDump<'buf>
Sourcepub fn op_selftests_get_do(self) -> OpSelftestsGetDo<'buf>
pub fn op_selftests_get_do(self) -> OpSelftestsGetDo<'buf>
Get device selftest instances. Request attributes:
Reply attributes:
Sourcepub fn op_selftests_run_do(self) -> OpSelftestsRunDo<'buf>
pub fn op_selftests_run_do(self) -> OpSelftestsRunDo<'buf>
Run device selftest instances. Flags: admin-perm Request attributes:
Sourcepub fn op_notify_filter_set_do(self) -> OpNotifyFilterSetDo<'buf>
pub fn op_notify_filter_set_do(self) -> OpNotifyFilterSetDo<'buf>
Set notification messages socket filter. Request attributes: