pub enum ClockQualityLevel {
ItuOpt1Prc = 1,
ItuOpt1SsuA = 2,
ItuOpt1SsuB = 3,
ItuOpt1Eec1 = 4,
ItuOpt1Prtc = 5,
ItuOpt1Eprtc = 6,
ItuOpt1Eeec = 7,
ItuOpt1Eprc = 8,
}Available on crate feature
dpll only.Expand description
level of quality of a clock device. This mainly applies when the dpll lock-status is DPLL_LOCK_STATUS_HOLDOVER. The current list is defined according to the table 11-7 contained in ITU-T G.8264/Y.1364 document. One may extend this list freely by other ITU-T defined clock qualities, or different ones defined by another standardization body (for those, please use different prefix). Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
Variants
ItuOpt1Prc = 1
ItuOpt1SsuA = 2
ItuOpt1SsuB = 3
ItuOpt1Eec1 = 4
ItuOpt1Prtc = 5
ItuOpt1Eprtc = 6
ItuOpt1Eeec = 7
ItuOpt1Eprc = 8
Implementations
Sourceimpl ClockQualityLevel
impl ClockQualityLevel
pub fn from_value(value: u64) -> Option<Self>