Dpll

Enum Dpll 

pub enum Dpll<'a> {
Show 14 variants Id(u32), ModuleName(&'a CStr), Pad(&'a [u8]), ClockId(u64), Mode(u32), ModeSupported(u32), LockStatus(u32), Temp(i32), Type(u32), LockStatusError(u32), ClockQualityLevel(u32), PhaseOffsetMonitor(u32), PhaseOffsetAvgFactor(u32), FrequencyMonitor(u32),
}
Available on crate feature dpll only.

Variants



Id(u32)



ModuleName(&'a CStr)



Pad(&'a [u8])



ClockId(u64)



Mode(u32)

Associated type: Mode (enum)



ModeSupported(u32)

Associated type: Mode (enum) Attribute may repeat multiple times (treat it as array)



LockStatus(u32)

Associated type: LockStatus (enum)



Temp(i32)



Type(u32)

Associated type: Type (enum)



LockStatusError(u32)

Associated type: LockStatusError (enum)



ClockQualityLevel(u32)

Level of quality of a clock device. This mainly applies when the dpll lock-status is DPLL_LOCK_STATUS_HOLDOVER. This could be put to message multiple times to indicate possible parallel quality levels (e.g. one specified by ITU option 1 and another one specified by option 2).

Associated type: ClockQualityLevel (enum) Attribute may repeat multiple times (treat it as array)



PhaseOffsetMonitor(u32)

Receive or request state of phase offset monitor feature. If enabled, dpll device shall monitor and notify all currently available inputs for changes of their phase offset against the dpll device.

Associated type: FeatureState (enum)



PhaseOffsetAvgFactor(u32)

Averaging factor applied to calculation of reported phase offset.



FrequencyMonitor(u32)

Current or desired state of the frequency monitor feature. If enabled, dpll device shall measure all currently available inputs for their actual input frequency.

Associated type: FeatureState (enum)

Implementations

Source

impl Dpll<'_>

pub fn new<'a>(buf: &'a [u8]) -> IterableDpll<'a>