pub enum LockStatus {
Unlocked = 1,
Locked = 2,
LockedHoAcq = 3,
Holdover = 4,
}Available on crate feature
dpll only.Expand description
provides information of dpll device lock status, valid values for DPLL_A_LOCK_STATUS attribute Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
Variants
Unlocked = 1
dpll was not yet locked to any valid input (or forced by setting DPLL_A_MODE to DPLL_MODE_DETACHED)
Locked = 2
dpll is locked to a valid signal, but no holdover available
LockedHoAcq = 3
dpll is locked and holdover acquired
Holdover = 4
dpll is in holdover state - lost a valid lock or was forced by disconnecting all the pins (latter possible only when dpll lock-state was already DPLL_LOCK_STATUS_LOCKED_HO_ACQ, if dpll lock-state was not DPLL_LOCK_STATUS_LOCKED_HO_ACQ, the dpll's lock-state shall remain DPLL_LOCK_STATUS_UNLOCKED)
Implementations
Sourceimpl LockStatus
impl LockStatus
pub fn from_value(value: u64) -> Option<Self>