LockStatusError

Enum LockStatusError 

pub enum LockStatusError {
    None = 1,
    Undefined = 2,
    MediaDown = 3,
    FractionalFrequencyOffsetTooHigh = 4,
}
Available on crate feature dpll only.
if previous status change was done due to a failure, this provides information of dpll device lock status error. Valid values for DPLL_A_LOCK_STATUS_ERROR attribute Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)

Variants



None = 1

dpll device lock status was changed without any error



Undefined = 2

dpll device lock status was changed due to undefined error. Driver fills this value up in case it is not able to obtain suitable exact error type.



MediaDown = 3

dpll device lock status was changed because of associated media got down. This may happen for example if dpll device was previously locked on an input pin of type PIN_TYPE_SYNCE_ETH_PORT.



FractionalFrequencyOffsetTooHigh = 4

the FFO (Fractional Frequency Offset) between the RX and TX symbol rate on the media got too high. This may happen for example if dpll device was previously locked on an input pin of type PIN_TYPE_SYNCE_ETH_PORT.

Implementations