pub enum Mode {
Manual = 1,
Automatic = 2,
}Available on crate feature
dpll only.Expand description
working modes a dpll can support, differentiates if and how dpll selects one of its inputs to syntonize with it, valid values for DPLL_A_MODE attribute Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
Variants
Manual = 1
input can be only selected by sending a request to dpll
Automatic = 2
highest prio input pin auto selected by dpll
Implementations