pub enum Pin<'a> {
Show 32 variants
Id(u32),
ParentId(u32),
ModuleName(&'a CStr),
Pad(&'a [u8]),
ClockId(u64),
BoardLabel(&'a CStr),
PanelLabel(&'a CStr),
PackageLabel(&'a CStr),
Type(u32),
Direction(u32),
Frequency(u64),
FrequencySupported(IterableFrequencyRange<'a>),
FrequencyMin(u64),
FrequencyMax(u64),
Prio(u32),
State(u32),
Capabilities(u32),
ParentDevice(IterablePinParentDevice<'a>),
ParentPin(IterablePinParentPin<'a>),
PhaseAdjustMin(i32),
PhaseAdjustMax(i32),
PhaseAdjust(i32),
PhaseOffset(i64),
FractionalFrequencyOffset(i32),
EsyncFrequency(u64),
EsyncFrequencySupported(IterableFrequencyRange<'a>),
EsyncPulse(u32),
ReferenceSync(IterableReferenceSync<'a>),
PhaseAdjustGran(u32),
FractionalFrequencyOffsetPpt(i32),
MeasuredFrequency(u64),
Operstate(u32),
}dpll only.Variants
Id(u32)
ParentId(u32)
ModuleName(&'a CStr)
Pad(&'a [u8])
ClockId(u64)
BoardLabel(&'a CStr)
PanelLabel(&'a CStr)
PackageLabel(&'a CStr)
Type(u32)
Associated type: PinType (enum)
Direction(u32)
Associated type: PinDirection (enum)
Frequency(u64)
FrequencySupported(IterableFrequencyRange<'a>)
Attribute may repeat multiple times (treat it as array)
FrequencyMin(u64)
FrequencyMax(u64)
Prio(u32)
State(u32)
Associated type: PinState (enum)
Capabilities(u32)
Associated type: PinCapabilities (enum)
ParentDevice(IterablePinParentDevice<'a>)
Attribute may repeat multiple times (treat it as array)
ParentPin(IterablePinParentPin<'a>)
Attribute may repeat multiple times (treat it as array)
PhaseAdjustMin(i32)
PhaseAdjustMax(i32)
PhaseAdjust(i32)
PhaseOffset(i64)
FractionalFrequencyOffset(i32)
The FFO (Fractional Frequency Offset) of the pin. At top level this represents the RX vs TX symbol rate offset on the media associated with the pin. Inside the pin-parent-device nest it represents the frequency offset between the pin and its parent DPLL device. Value is in PPM (parts per million). This is a lower-precision version of fractional-frequency-offset-ppt.
EsyncFrequency(u64)
Frequency of Embedded SYNC signal. If provided, the pin is configured with a SYNC signal embedded into its base clock frequency.
EsyncFrequencySupported(IterableFrequencyRange<'a>)
If provided a pin is capable of embedding a SYNC signal (within given range) into its base frequency signal.
Attribute may repeat multiple times (treat it as array)
EsyncPulse(u32)
A ratio of high to low state of a SYNC signal pulse embedded into base clock frequency. Value is in percents.
ReferenceSync(IterableReferenceSync<'a>)
Capable pin provides list of pins that can be bound to create a reference-sync pin pair.
Attribute may repeat multiple times (treat it as array)
PhaseAdjustGran(u32)
Granularity of phase adjustment, in picoseconds. The value of phase adjustment must be a multiple of this granularity.
FractionalFrequencyOffsetPpt(i32)
The FFO (Fractional Frequency Offset) of the pin. At top level this represents the RX vs TX symbol rate offset on the media associated with the pin. Inside the pin-parent-device nest it represents the frequency offset between the pin and its parent DPLL device. Value is in PPT (parts per trillion, 10^-12). This is a higher-precision version of fractional-frequency-offset.
MeasuredFrequency(u64)
The measured frequency of the input pin in millihertz (mHz). Value of (DPLL_A_PIN_MEASURED_FREQUENCY / DPLL_PIN_MEASURED_FREQUENCY_DIVIDER) is an integer part (Hz) of a measured frequency value. Value of (DPLL_A_PIN_MEASURED_FREQUENCY % DPLL_PIN_MEASURED_FREQUENCY_DIVIDER) is a fractional part of a measured frequency value.
Operstate(u32)
Operational state of the pin with respect to its parent DPLL device. Unlike state (which reflects the administrative intent), operstate reflects the actual hardware status.
Associated type: PinOperstate (enum)