pub enum PinDirection {
Input = 1,
Output = 2,
}Available on crate feature
dpll only.Expand description
defines possible direction of a pin, valid values for DPLL_A_PIN_DIRECTION attribute Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
Variants
Implementations
Sourceimpl PinDirection
impl PinDirection
pub fn from_value(value: u64) -> Option<Self>