pub enum PinOperstate {
Active = 1,
Standby = 2,
NoSignal = 3,
QualFailed = 4,
}Available on crate feature
dpll only.Expand description
defines possible operational states of a pin with respect to its parent DPLL device, valid values for DPLL_A_PIN_OPERSTATE attribute Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
Variants
Active = 1
pin is qualified and actively used by the DPLL
Standby = 2
pin is qualified but not actively used by the DPLL
NoSignal = 3
pin does not have a valid signal
QualFailed = 4
pin signal failed qualification (e.g. frequency or phase monitor)
Implementations
Sourceimpl PinOperstate
impl PinOperstate
pub fn from_value(value: u64) -> Option<Self>