PinParentDevice

Enum PinParentDevice 

pub enum PinParentDevice {
    ParentId(u32),
    Direction(u32),
    Prio(u32),
    State(u32),
    PhaseOffset(i64),
    FractionalFrequencyOffset(i32),
    FractionalFrequencyOffsetPpt(i32),
    Operstate(u32),
}
Available on crate feature dpll only.

Variants



ParentId(u32)



Direction(u32)

Associated type: PinDirection (enum)



Prio(u32)



State(u32)

Associated type: PinState (enum)



PhaseOffset(i64)



FractionalFrequencyOffset(i32)

The FFO (Fractional Frequency Offset) of the pin. At top level this represents the RX vs TX symbol rate offset on the media associated with the pin. Inside the pin-parent-device nest it represents the frequency offset between the pin and its parent DPLL device. Value is in PPM (parts per million). This is a lower-precision version of fractional-frequency-offset-ppt.



FractionalFrequencyOffsetPpt(i32)

The FFO (Fractional Frequency Offset) of the pin. At top level this represents the RX vs TX symbol rate offset on the media associated with the pin. Inside the pin-parent-device nest it represents the frequency offset between the pin and its parent DPLL device. Value is in PPT (parts per trillion, 10^-12). This is a higher-precision version of fractional-frequency-offset.



Operstate(u32)

Operational state of the pin with respect to its parent DPLL device. Unlike state (which reflects the administrative intent), operstate reflects the actual hardware status.

Associated type: PinOperstate (enum)

Implementations