pub enum PinState {
Connected = 1,
Disconnected = 2,
Selectable = 3,
}Available on crate feature
dpll only.Expand description
defines possible states of a pin, valid values for DPLL_A_PIN_STATE attribute Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
Variants
Connected = 1
pin connected, active input of phase locked loop
Disconnected = 2
pin disconnected, not considered as a valid input
Selectable = 3
pin enabled for automatic input selection
Implementations