pub enum PinType {
Mux = 1,
Ext = 2,
SynceEthPort = 3,
IntOscillator = 4,
Gnss = 5,
}Available on crate feature
dpll only.Expand description
defines possible types of a pin, valid values for DPLL_A_PIN_TYPE attribute Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
Variants
Mux = 1
aggregates another layer of selectable pins
Ext = 2
external input
SynceEthPort = 3
ethernet port PHY’s recovered clock
IntOscillator = 4
device internal oscillator
Gnss = 5
GNSS recovered clock
Implementations