pub struct IterableDpll<'a> { /* private fields */ }dpll only.Implementations
Sourceimpl<'a> IterableDpll<'a>
impl<'a> IterableDpll<'a>
pub fn get_id(&self) -> Result<u32, ErrorContext>
pub fn get_module_name(&self) -> Result<&'a CStr, ErrorContext>
pub fn get_pad(&self) -> Result<&'a [u8], ErrorContext>
pub fn get_clock_id(&self) -> Result<u64, ErrorContext>
Sourcepub fn get_mode_supported(&self) -> MultiAttrIterable<Self, Dpll<'a>, u32> ⓘ
pub fn get_mode_supported(&self) -> MultiAttrIterable<Self, Dpll<'a>, u32> ⓘ
Associated type: Mode (enum)
Attribute may repeat multiple times (treat it as array)
Sourcepub fn get_lock_status(&self) -> Result<u32, ErrorContext>
pub fn get_lock_status(&self) -> Result<u32, ErrorContext>
Associated type: LockStatus (enum)
pub fn get_temp(&self) -> Result<i32, ErrorContext>
Sourcepub fn get_lock_status_error(&self) -> Result<u32, ErrorContext>
pub fn get_lock_status_error(&self) -> Result<u32, ErrorContext>
Associated type: LockStatusError (enum)
Sourcepub fn get_clock_quality_level(&self) -> MultiAttrIterable<Self, Dpll<'a>, u32> ⓘ
pub fn get_clock_quality_level(&self) -> MultiAttrIterable<Self, Dpll<'a>, u32> ⓘ
Level of quality of a clock device. This mainly applies when the dpll lock-status is DPLL_LOCK_STATUS_HOLDOVER. This could be put to message multiple times to indicate possible parallel quality levels (e.g. one specified by ITU option 1 and another one specified by option 2).
Associated type: ClockQualityLevel (enum)
Attribute may repeat multiple times (treat it as array)
Sourcepub fn get_phase_offset_monitor(&self) -> Result<u32, ErrorContext>
pub fn get_phase_offset_monitor(&self) -> Result<u32, ErrorContext>
Receive or request state of phase offset monitor feature. If enabled, dpll device shall monitor and notify all currently available inputs for changes of their phase offset against the dpll device.
Associated type: FeatureState (enum)
Sourcepub fn get_phase_offset_avg_factor(&self) -> Result<u32, ErrorContext>
pub fn get_phase_offset_avg_factor(&self) -> Result<u32, ErrorContext>
Averaging factor applied to calculation of reported phase offset.
Sourcepub fn get_frequency_monitor(&self) -> Result<u32, ErrorContext>
pub fn get_frequency_monitor(&self) -> Result<u32, ErrorContext>
Current or desired state of the frequency monitor feature. If enabled, dpll device shall measure all currently available inputs for their actual input frequency.
Associated type: FeatureState (enum)