pub struct IterablePin<'a> { /* private fields */ }dpll only.Implementations
Sourceimpl<'a> IterablePin<'a>
impl<'a> IterablePin<'a>
pub fn get_id(&self) -> Result<u32, ErrorContext>
pub fn get_parent_id(&self) -> Result<u32, ErrorContext>
pub fn get_module_name(&self) -> Result<&'a CStr, ErrorContext>
pub fn get_pad(&self) -> Result<&'a [u8], ErrorContext>
pub fn get_clock_id(&self) -> Result<u64, ErrorContext>
pub fn get_board_label(&self) -> Result<&'a CStr, ErrorContext>
pub fn get_panel_label(&self) -> Result<&'a CStr, ErrorContext>
pub fn get_package_label(&self) -> Result<&'a CStr, ErrorContext>
Sourcepub fn get_direction(&self) -> Result<u32, ErrorContext>
pub fn get_direction(&self) -> Result<u32, ErrorContext>
Associated type: PinDirection (enum)
pub fn get_frequency(&self) -> Result<u64, ErrorContext>
Sourcepub fn get_frequency_supported(
&self,
) -> MultiAttrIterable<Self, Pin<'a>, IterableFrequencyRange<'a>> ⓘ
pub fn get_frequency_supported( &self, ) -> MultiAttrIterable<Self, Pin<'a>, IterableFrequencyRange<'a>> ⓘ
Attribute may repeat multiple times (treat it as array)
pub fn get_frequency_min(&self) -> Result<u64, ErrorContext>
pub fn get_frequency_max(&self) -> Result<u64, ErrorContext>
pub fn get_prio(&self) -> Result<u32, ErrorContext>
Sourcepub fn get_capabilities(&self) -> Result<u32, ErrorContext>
pub fn get_capabilities(&self) -> Result<u32, ErrorContext>
Associated type: PinCapabilities (enum)
Sourcepub fn get_parent_device(
&self,
) -> MultiAttrIterable<Self, Pin<'a>, IterablePinParentDevice<'a>> ⓘ
pub fn get_parent_device( &self, ) -> MultiAttrIterable<Self, Pin<'a>, IterablePinParentDevice<'a>> ⓘ
Attribute may repeat multiple times (treat it as array)
Sourcepub fn get_parent_pin(
&self,
) -> MultiAttrIterable<Self, Pin<'a>, IterablePinParentPin<'a>> ⓘ
pub fn get_parent_pin( &self, ) -> MultiAttrIterable<Self, Pin<'a>, IterablePinParentPin<'a>> ⓘ
Attribute may repeat multiple times (treat it as array)
pub fn get_phase_adjust_min(&self) -> Result<i32, ErrorContext>
pub fn get_phase_adjust_max(&self) -> Result<i32, ErrorContext>
pub fn get_phase_adjust(&self) -> Result<i32, ErrorContext>
pub fn get_phase_offset(&self) -> Result<i64, ErrorContext>
Sourcepub fn get_fractional_frequency_offset(&self) -> Result<i32, ErrorContext>
pub fn get_fractional_frequency_offset(&self) -> Result<i32, ErrorContext>
The FFO (Fractional Frequency Offset) between the RX and TX symbol rate on the media associated with the pin: (rx_frequency-tx_frequency)/rx_frequency Value is in PPM (parts per million). This may be implemented for example for pin of type PIN_TYPE_SYNCE_ETH_PORT.
Sourcepub fn get_esync_frequency(&self) -> Result<u64, ErrorContext>
pub fn get_esync_frequency(&self) -> Result<u64, ErrorContext>
Frequency of Embedded SYNC signal. If provided, the pin is configured with a SYNC signal embedded into its base clock frequency.
Sourcepub fn get_esync_frequency_supported(
&self,
) -> MultiAttrIterable<Self, Pin<'a>, IterableFrequencyRange<'a>> ⓘ
pub fn get_esync_frequency_supported( &self, ) -> MultiAttrIterable<Self, Pin<'a>, IterableFrequencyRange<'a>> ⓘ
If provided a pin is capable of embedding a SYNC signal (within given range) into its base frequency signal.
Attribute may repeat multiple times (treat it as array)
Sourcepub fn get_esync_pulse(&self) -> Result<u32, ErrorContext>
pub fn get_esync_pulse(&self) -> Result<u32, ErrorContext>
A ratio of high to low state of a SYNC signal pulse embedded into base clock frequency. Value is in percents.
Sourcepub fn get_reference_sync(
&self,
) -> MultiAttrIterable<Self, Pin<'a>, IterableReferenceSync<'a>> ⓘ
pub fn get_reference_sync( &self, ) -> MultiAttrIterable<Self, Pin<'a>, IterableReferenceSync<'a>> ⓘ
Capable pin provides list of pins that can be bound to create a reference-sync pin pair.
Attribute may repeat multiple times (treat it as array)
Sourcepub fn get_phase_adjust_gran(&self) -> Result<u32, ErrorContext>
pub fn get_phase_adjust_gran(&self) -> Result<u32, ErrorContext>
Granularity of phase adjustment, in picoseconds. The value of phase adjustment must be a multiple of this granularity.
Sourcepub fn get_fractional_frequency_offset_ppt(&self) -> Result<i32, ErrorContext>
pub fn get_fractional_frequency_offset_ppt(&self) -> Result<i32, ErrorContext>
The FFO (Fractional Frequency Offset) of the pin with respect to the nominal frequency. Value = (frequency_measured - frequency_nominal) / frequency_nominal Value is in PPT (parts per trillion, 10^-12). Note: This attribute provides higher resolution than the standard fractional-frequency-offset (which is in PPM).