pub struct OpPinGetDo<'r> { /* private fields */ }Available on crate feature
dpll only.Expand description
Get list of pins and its attributes.
- dump request without any attributes given - list all the pins in the system
- dump request with target dpll - list all the pins registered with a given dpll device
- do request with target dpll and target pin - single pin attributes
Flags: admin-perm
Request attributes:
Reply attributes:
- .get_id()
- .get_module_name()
- .get_clock_id()
- .get_board_label()
- .get_panel_label()
- .get_package_label()
- .get_type()
- .get_frequency()
- .get_frequency_supported()
- .get_capabilities()
- .get_parent_device()
- .get_parent_pin()
- .get_phase_adjust_min()
- .get_phase_adjust_max()
- .get_phase_adjust()
- .get_fractional_frequency_offset()
- .get_esync_frequency()
- .get_esync_frequency_supported()
- .get_esync_pulse()
- .get_reference_sync()
- .get_phase_adjust_gran()
- .get_fractional_frequency_offset_ppt()
- .get_measured_frequency()
Implementations
Sourceimpl<'r> OpPinGetDo<'r>
impl<'r> OpPinGetDo<'r>
pub fn new(request: Request<'r>) -> Self
pub fn encode_request<'buf>( buf: &'buf mut Vec<u8>, ) -> PushPin<&'buf mut Vec<u8>>
pub fn encode(&mut self) -> PushPin<&mut Vec<u8>>
pub fn into_encoder(self) -> PushPin<RequestBuf<'r>>
pub fn decode_request<'a>(buf: &'a [u8]) -> IterablePin<'a> ⓘ