PushDpll

Struct PushDpll 

pub struct PushDpll<Prev: Pusher> { /* private fields */ }
Available on crate feature dpll only.

Implementations

Source

impl<Prev: Pusher> PushDpll<Prev>

pub fn new(prev: Prev) -> Self

pub fn end_nested(self) -> Prev

pub fn push_id(self, value: u32) -> Self

pub fn push_module_name(self, value: &CStr) -> Self

pub fn push_module_name_bytes(self, value: &[u8]) -> Self

pub fn push_pad(self, value: &[u8]) -> Self

pub fn push_clock_id(self, value: u64) -> Self

pub fn push_mode(self, value: u32) -> Self

Associated type: Mode (enum)

pub fn push_mode_supported(self, value: u32) -> Self

Associated type: Mode (enum) Attribute may repeat multiple times (treat it as array)

pub fn push_lock_status(self, value: u32) -> Self

Associated type: LockStatus (enum)

pub fn push_temp(self, value: i32) -> Self

pub fn push_type(self, value: u32) -> Self

Associated type: Type (enum)

pub fn push_lock_status_error(self, value: u32) -> Self

Associated type: LockStatusError (enum)

pub fn push_clock_quality_level(self, value: u32) -> Self

Level of quality of a clock device. This mainly applies when the dpll lock-status is DPLL_LOCK_STATUS_HOLDOVER. This could be put to message multiple times to indicate possible parallel quality levels (e.g. one specified by ITU option 1 and another one specified by option 2).

Associated type: ClockQualityLevel (enum) Attribute may repeat multiple times (treat it as array)

pub fn push_phase_offset_monitor(self, value: u32) -> Self

Receive or request state of phase offset monitor feature. If enabled, dpll device shall monitor and notify all currently available inputs for changes of their phase offset against the dpll device.

Associated type: FeatureState (enum)

pub fn push_phase_offset_avg_factor(self, value: u32) -> Self

Averaging factor applied to calculation of reported phase offset.

pub fn push_frequency_monitor(self, value: u32) -> Self

Current or desired state of the frequency monitor feature. If enabled, dpll device shall measure all currently available inputs for their actual input frequency.

Associated type: FeatureState (enum)