PushPin

Struct PushPin 

pub struct PushPin<Prev: Pusher> { /* private fields */ }
Available on crate feature dpll only.

Implementations

Source

impl<Prev: Pusher> PushPin<Prev>

pub fn new(prev: Prev) -> Self

pub fn end_nested(self) -> Prev

pub fn push_id(self, value: u32) -> Self

pub fn push_parent_id(self, value: u32) -> Self

pub fn push_module_name(self, value: &CStr) -> Self

pub fn push_module_name_bytes(self, value: &[u8]) -> Self

pub fn push_pad(self, value: &[u8]) -> Self

pub fn push_clock_id(self, value: u64) -> Self

pub fn push_board_label(self, value: &CStr) -> Self

pub fn push_board_label_bytes(self, value: &[u8]) -> Self

pub fn push_panel_label(self, value: &CStr) -> Self

pub fn push_panel_label_bytes(self, value: &[u8]) -> Self

pub fn push_package_label(self, value: &CStr) -> Self

pub fn push_package_label_bytes(self, value: &[u8]) -> Self

pub fn push_type(self, value: u32) -> Self

Associated type: PinType (enum)

pub fn push_direction(self, value: u32) -> Self

Associated type: PinDirection (enum)

pub fn push_frequency(self, value: u64) -> Self

pub fn nested_frequency_supported(self) -> PushFrequencyRange<Self>

Attribute may repeat multiple times (treat it as array)

pub fn push_frequency_min(self, value: u64) -> Self

pub fn push_frequency_max(self, value: u64) -> Self

pub fn push_prio(self, value: u32) -> Self

pub fn push_state(self, value: u32) -> Self

Associated type: PinState (enum)

pub fn push_capabilities(self, value: u32) -> Self

Associated type: PinCapabilities (enum)

pub fn nested_parent_device(self) -> PushPinParentDevice<Self>

Attribute may repeat multiple times (treat it as array)

pub fn nested_parent_pin(self) -> PushPinParentPin<Self>

Attribute may repeat multiple times (treat it as array)

pub fn push_phase_adjust_min(self, value: i32) -> Self

pub fn push_phase_adjust_max(self, value: i32) -> Self

pub fn push_phase_adjust(self, value: i32) -> Self

pub fn push_phase_offset(self, value: i64) -> Self

pub fn push_fractional_frequency_offset(self, value: i32) -> Self

The FFO (Fractional Frequency Offset) of the pin. At top level this represents the RX vs TX symbol rate offset on the media associated with the pin. Inside the pin-parent-device nest it represents the frequency offset between the pin and its parent DPLL device. Value is in PPM (parts per million). This is a lower-precision version of fractional-frequency-offset-ppt.

pub fn push_esync_frequency(self, value: u64) -> Self

Frequency of Embedded SYNC signal. If provided, the pin is configured with a SYNC signal embedded into its base clock frequency.

pub fn nested_esync_frequency_supported(self) -> PushFrequencyRange<Self>

If provided a pin is capable of embedding a SYNC signal (within given range) into its base frequency signal.

Attribute may repeat multiple times (treat it as array)

pub fn push_esync_pulse(self, value: u32) -> Self

A ratio of high to low state of a SYNC signal pulse embedded into base clock frequency. Value is in percents.

pub fn nested_reference_sync(self) -> PushReferenceSync<Self>

Capable pin provides list of pins that can be bound to create a reference-sync pin pair.

Attribute may repeat multiple times (treat it as array)

pub fn push_phase_adjust_gran(self, value: u32) -> Self

Granularity of phase adjustment, in picoseconds. The value of phase adjustment must be a multiple of this granularity.

pub fn push_fractional_frequency_offset_ppt(self, value: i32) -> Self

The FFO (Fractional Frequency Offset) of the pin. At top level this represents the RX vs TX symbol rate offset on the media associated with the pin. Inside the pin-parent-device nest it represents the frequency offset between the pin and its parent DPLL device. Value is in PPT (parts per trillion, 10^-12). This is a higher-precision version of fractional-frequency-offset.

pub fn push_measured_frequency(self, value: u64) -> Self

The measured frequency of the input pin in millihertz (mHz). Value of (DPLL_A_PIN_MEASURED_FREQUENCY / DPLL_PIN_MEASURED_FREQUENCY_DIVIDER) is an integer part (Hz) of a measured frequency value. Value of (DPLL_A_PIN_MEASURED_FREQUENCY % DPLL_PIN_MEASURED_FREQUENCY_DIVIDER) is a fractional part of a measured frequency value.

pub fn push_operstate(self, value: u32) -> Self

Operational state of the pin with respect to its parent DPLL device. Unlike state (which reflects the administrative intent), operstate reflects the actual hardware status.

Associated type: PinOperstate (enum)