PushPinParentDevice

Struct PushPinParentDevice 

pub struct PushPinParentDevice<Prev: Pusher> { /* private fields */ }
Available on crate feature dpll only.

Implementations

Source

impl<Prev: Pusher> PushPinParentDevice<Prev>

pub fn new(prev: Prev) -> Self

pub fn end_nested(self) -> Prev

pub fn push_parent_id(self, value: u32) -> Self

pub fn push_direction(self, value: u32) -> Self

Associated type: PinDirection (enum)

pub fn push_prio(self, value: u32) -> Self

pub fn push_state(self, value: u32) -> Self

Associated type: PinState (enum)

pub fn push_phase_offset(self, value: i64) -> Self

pub fn push_fractional_frequency_offset(self, value: i32) -> Self

The FFO (Fractional Frequency Offset) of the pin. At top level this represents the RX vs TX symbol rate offset on the media associated with the pin. Inside the pin-parent-device nest it represents the frequency offset between the pin and its parent DPLL device. Value is in PPM (parts per million). This is a lower-precision version of fractional-frequency-offset-ppt.

pub fn push_fractional_frequency_offset_ppt(self, value: i32) -> Self

The FFO (Fractional Frequency Offset) of the pin. At top level this represents the RX vs TX symbol rate offset on the media associated with the pin. Inside the pin-parent-device nest it represents the frequency offset between the pin and its parent DPLL device. Value is in PPT (parts per trillion, 10^-12). This is a higher-precision version of fractional-frequency-offset.

pub fn push_operstate(self, value: u32) -> Self

Operational state of the pin with respect to its parent DPLL device. Unlike state (which reflects the administrative intent), operstate reflects the actual hardware status.

Associated type: PinOperstate (enum)