pub struct Request<'buf> { /* private fields */ }dpll only.Implementations
Sourceimpl<'buf> Request<'buf>
impl<'buf> Request<'buf>
pub fn new_with_buf(buf: &'buf mut Vec<u8>) -> Self
pub fn new_extend(buf: &'buf mut Vec<u8>) -> Self
pub fn buf(&self) -> &Vec<u8> ⓘ
pub fn buf_mut(&mut self) -> &mut Vec<u8> ⓘ
Sourcepub fn set_create(self) -> Self
pub fn set_create(self) -> Self
Set NLM_F_CREATE flag
Sourcepub fn set_replace(self) -> Self
pub fn set_replace(self) -> Self
Set NLM_F_REPLACE flag
Sourcepub fn set_change(self) -> Self
pub fn set_change(self) -> Self
Set NLM_F_CREATE and NLM_F_REPLACE flag
Sourcepub fn set_append(self) -> Self
pub fn set_append(self) -> Self
Set NLM_F_APPEND flag
Sourcepub fn unset_flags(self, flags: u16) -> Self
pub fn unset_flags(self, flags: u16) -> Self
Set self.flags ^= self.flags & flags
Sourcepub fn op_device_id_get_do(self) -> OpDeviceIdGetDo<'buf>
pub fn op_device_id_get_do(self) -> OpDeviceIdGetDo<'buf>
Get id of dpll device that matches given attributes
Flags: admin-perm
Request attributes:
Reply attributes:
Sourcepub fn op_device_get_dump(self) -> OpDeviceGetDump<'buf>
pub fn op_device_get_dump(self) -> OpDeviceGetDump<'buf>
Get list of DPLL devices (dump) or attributes of a single dpll device
Flags: admin-perm
Reply attributes:
Sourcepub fn op_device_get_do(self) -> OpDeviceGetDo<'buf>
pub fn op_device_get_do(self) -> OpDeviceGetDo<'buf>
Get list of DPLL devices (dump) or attributes of a single dpll device
Flags: admin-perm
Request attributes:
Reply attributes:
Sourcepub fn op_device_set_do(self) -> OpDeviceSetDo<'buf>
pub fn op_device_set_do(self) -> OpDeviceSetDo<'buf>
Set attributes for a DPLL device
Flags: admin-perm
Request attributes:
Sourcepub fn op_pin_id_get_do(self) -> OpPinIdGetDo<'buf>
pub fn op_pin_id_get_do(self) -> OpPinIdGetDo<'buf>
Get id of a pin that matches given attributes
Flags: admin-perm
Request attributes:
- .push_module_name()
- .push_clock_id()
- .push_board_label()
- .push_panel_label()
- .push_package_label()
- .push_type()
Reply attributes:
Sourcepub fn op_pin_get_dump(self) -> OpPinGetDump<'buf>
pub fn op_pin_get_dump(self) -> OpPinGetDump<'buf>
Get list of pins and its attributes.
- dump request without any attributes given - list all the pins in the system
- dump request with target dpll - list all the pins registered with a given dpll device
- do request with target dpll and target pin - single pin attributes
Flags: admin-perm
Request attributes:
Reply attributes:
- .get_id()
- .get_module_name()
- .get_clock_id()
- .get_board_label()
- .get_panel_label()
- .get_package_label()
- .get_type()
- .get_frequency()
- .get_frequency_supported()
- .get_capabilities()
- .get_parent_device()
- .get_parent_pin()
- .get_phase_adjust_min()
- .get_phase_adjust_max()
- .get_phase_adjust()
- .get_fractional_frequency_offset()
- .get_esync_frequency()
- .get_esync_frequency_supported()
- .get_esync_pulse()
- .get_reference_sync()
- .get_phase_adjust_gran()
- .get_fractional_frequency_offset_ppt()
- .get_measured_frequency()
Sourcepub fn op_pin_get_do(self) -> OpPinGetDo<'buf>
pub fn op_pin_get_do(self) -> OpPinGetDo<'buf>
Get list of pins and its attributes.
- dump request without any attributes given - list all the pins in the system
- dump request with target dpll - list all the pins registered with a given dpll device
- do request with target dpll and target pin - single pin attributes
Flags: admin-perm
Request attributes:
Reply attributes:
- .get_id()
- .get_module_name()
- .get_clock_id()
- .get_board_label()
- .get_panel_label()
- .get_package_label()
- .get_type()
- .get_frequency()
- .get_frequency_supported()
- .get_capabilities()
- .get_parent_device()
- .get_parent_pin()
- .get_phase_adjust_min()
- .get_phase_adjust_max()
- .get_phase_adjust()
- .get_fractional_frequency_offset()
- .get_esync_frequency()
- .get_esync_frequency_supported()
- .get_esync_pulse()
- .get_reference_sync()
- .get_phase_adjust_gran()
- .get_fractional_frequency_offset_ppt()
- .get_measured_frequency()
Sourcepub fn op_pin_set_do(self) -> OpPinSetDo<'buf>
pub fn op_pin_set_do(self) -> OpPinSetDo<'buf>
Set attributes of a target pin
Flags: admin-perm
Request attributes: