pub enum NodeType {
ErrorCounter = 1,
}Available on crate feature
drm-ras only.Expand description
Type of the node. Currently, only error-counter nodes are supported, which expose reliability counters for a hardware/software component. Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
Variants
ErrorCounter = 1
Implementations