pub struct PushNodeAttrs<Prev: Pusher> { /* private fields */ }Available on crate feature
drm-ras only.Implementations
Sourceimpl<Prev: Pusher> PushNodeAttrs<Prev>
impl<Prev: Pusher> PushNodeAttrs<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
Sourcepub fn push_node_id(self, value: u32) -> Self
pub fn push_node_id(self, value: u32) -> Self
Unique identifier for the node. Assigned dynamically by the DRM RAS core upon registration.
Sourcepub fn push_device_name(self, value: &CStr) -> Self
pub fn push_device_name(self, value: &CStr) -> Self
Device name chosen by the driver at registration. Can be a PCI BDF, UUID, or module name if unique.
Sourcepub fn push_device_name_bytes(self, value: &[u8]) -> Self
pub fn push_device_name_bytes(self, value: &[u8]) -> Self
Device name chosen by the driver at registration. Can be a PCI BDF, UUID, or module name if unique.
Sourcepub fn push_node_name(self, value: &CStr) -> Self
pub fn push_node_name(self, value: &CStr) -> Self
Node name chosen by the driver at registration. Can be an IP block name, or any name that identifies the RAS node inside the device.
Sourcepub fn push_node_name_bytes(self, value: &[u8]) -> Self
pub fn push_node_name_bytes(self, value: &[u8]) -> Self
Node name chosen by the driver at registration. Can be an IP block name, or any name that identifies the RAS node inside the device.
Sourcepub fn push_node_type(self, value: u32) -> Self
pub fn push_node_type(self, value: u32) -> Self
Type of this node, identifying its function.
Associated type: NodeType (enum)