pub struct Request<'buf> { /* private fields */ }drm-ras only.Implementations
Sourceimpl<'buf> Request<'buf>
impl<'buf> Request<'buf>
pub fn new_with_buf(buf: &'buf mut Vec<u8>) -> Self
pub fn new_extend(buf: &'buf mut Vec<u8>) -> Self
pub fn buf(&self) -> &Vec<u8> ⓘ
pub fn buf_mut(&mut self) -> &mut Vec<u8> ⓘ
Sourcepub fn set_create(self) -> Self
pub fn set_create(self) -> Self
Set NLM_F_CREATE flag
Sourcepub fn set_replace(self) -> Self
pub fn set_replace(self) -> Self
Set NLM_F_REPLACE flag
Sourcepub fn set_change(self) -> Self
pub fn set_change(self) -> Self
Set NLM_F_CREATE and NLM_F_REPLACE flag
Sourcepub fn set_append(self) -> Self
pub fn set_append(self) -> Self
Set NLM_F_APPEND flag
Sourcepub fn unset_flags(self, flags: u16) -> Self
pub fn unset_flags(self, flags: u16) -> Self
Set self.flags ^= self.flags & flags
Sourcepub fn op_list_nodes_dump(self) -> OpListNodesDump<'buf>
pub fn op_list_nodes_dump(self) -> OpListNodesDump<'buf>
Retrieve the full list of currently registered DRM RAS nodes. Each node includes its dynamically assigned ID, name, and type. Important: User space must call this operation first to obtain the node IDs. These IDs are required for all subsequent operations on nodes, such as querying error counters.
Flags: admin-perm
Reply attributes:
Sourcepub fn op_get_error_counter_dump(self) -> OpGetErrorCounterDump<'buf>
pub fn op_get_error_counter_dump(self) -> OpGetErrorCounterDump<'buf>
Retrieve error counter for a given node. The response includes the id, the name, and even the current value of each counter.
Flags: admin-perm
Request attributes:
Reply attributes:
Sourcepub fn op_get_error_counter_do(self) -> OpGetErrorCounterDo<'buf>
pub fn op_get_error_counter_do(self) -> OpGetErrorCounterDo<'buf>
Retrieve error counter for a given node. The response includes the id, the name, and even the current value of each counter.
Flags: admin-perm
Request attributes:
Reply attributes:
Sourcepub fn op_clear_error_counter_do(self) -> OpClearErrorCounterDo<'buf>
pub fn op_clear_error_counter_do(self) -> OpClearErrorCounterDo<'buf>
Clear error counter for a given node. The request includes the error-id and node-id of the counter to be cleared.
Flags: admin-perm
Request attributes: