pub enum InputXfrm {
SymXor = 1,
SymOrXor = 2,
}Available on crate feature
ethtool only.Expand description
RSS hash function transformations. Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
Variants
SymXor = 1
XOR the corresponding source and destination fields of each specified protocol. Both copies of the XOR'ed fields are fed into the RSS and RXHASH calculation. Note that this XORing reduces the input set entropy and could be exploited to reduce the RSS queue spread.
SymOrXor = 2
Similar to SYM_XOR, except that one copy of the XOR'ed fields is replaced by an OR of the same fields.
Implementations