pub struct PushPauseStat<Prev: Rec> { /* private fields */ }Available on crate feature
ethtool only.Implementations
Sourceimpl<Prev: Rec> PushPauseStat<Prev>
impl<Prev: Rec> PushPauseStat<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
pub fn push_pad(self, value: &[u8]) -> Self
pub fn push_tx_frames(self, value: u64) -> Self
pub fn push_rx_frames(self, value: u64) -> Self
Sourcepub fn push_tx_pause_storm_events(self, value: u64) -> Self
pub fn push_tx_pause_storm_events(self, value: u64) -> Self
TX pause storm event count. Increments each time device detects that its pause assertion condition has been true for too long for normal operation. As a result, the device has temporarily disabled its own Pause TX function to protect the network from itself. This counter should never increment under normal overload conditions; it indicates catastrophic failure like an OS crash. The rate of incrementing is implementation specific.