EventType

Enum EventType 

pub enum EventType {
    Unspec = 0,
    Created = 1,
    Established = 2,
    Closed = 3,
    Announced = 6,
    Removed = 7,
    SubEstablished = 10,
    SubClosed = 11,
    SubPriority = 13,
    ListenerCreated = 15,
    ListenerClosed = 16,
}
Available on crate feature mptcp_pm only.
Netlink MPTCP event types Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)

Variants



Unspec = 0

unused event



Created = 1

A new MPTCP connection has been created. It is the good time to allocate memory and send ADD_ADDR if needed. Depending on the traffic-patterns it can take a long time until the MPTCP_EVENT_ESTABLISHED is sent. Attributes: token, family, saddr4 | saddr6, daddr4 | daddr6, sport, dport, [server-side], [flags].



Established = 2

A MPTCP connection is established (can start new subflows). Attributes: token, family, saddr4 | saddr6, daddr4 | daddr6, sport, dport, [server-side], [flags].



Closed = 3

A MPTCP connection has stopped. Attribute: token.



Announced = 6

A new address has been announced by the peer. Attributes: token, rem_id, family, daddr4 | daddr6 [, dport].



Removed = 7

An address has been lost by the peer. Attributes: token, rem_id.



SubEstablished = 10

A new subflow has been established. 'error' should not be set. Attributes: token, family, loc_id, rem_id, saddr4 | saddr6, daddr4 | daddr6, sport, dport, backup, if-idx [, error].



SubClosed = 11

A subflow has been closed. An error (copy of sk_err) could be set if an error has been detected for this subflow. Attributes: token, family, loc_id, rem_id, saddr4 | saddr6, daddr4 | daddr6, sport, dport, backup, if-idx [, error].



SubPriority = 13

The priority of a subflow has changed. 'error' should not be set. Attributes: token, family, loc_id, rem_id, saddr4 | saddr6, daddr4 | daddr6, sport, dport, backup, if-idx [, error].



ListenerCreated = 15

A new PM listener is created. Attributes: family, sport, saddr4 | saddr6.



ListenerClosed = 16

A PM listener is closed. Attributes: family, sport, saddr4 | saddr6.

Implementations

Source

impl EventType

pub fn from_value(value: u64) -> Option<Self>