NetShaper

Enum NetShaper 

pub enum NetShaper<'a> {
    Handle(IterableHandle<'a>),
    Metric(u32),
    BwMin(u32),
    BwMax(u32),
    Burst(u32),
    Priority(u32),
    Weight(u32),
    Ifindex(u32),
    Parent(IterableHandle<'a>),
    Leaves(IterableLeafInfo<'a>),
}
Available on crate feature net-shaper only.

Variants



Handle(IterableHandle<'a>)

Unique identifier for the given shaper inside the owning device.



Metric(u32)

Metric used by the given shaper for bw-min, bw-max and burst.

Associated type: Metric (enum)



BwMin(u32)

Guaranteed bandwidth for the given shaper.



BwMax(u32)

Maximum bandwidth for the given shaper or 0 when unlimited.



Burst(u32)

Maximum burst-size for shaping. Should not be interpreted as a quantum.



Priority(u32)

Scheduling priority for the given shaper. The priority scheduling is applied to sibling shapers.



Weight(u32)

Relative weight for round robin scheduling of the given shaper. The scheduling is applied to all sibling shapers with the same priority.



Ifindex(u32)

Interface index owning the specified shaper.



Parent(IterableHandle<'a>)

Identifier for the parent of the affected shaper. Only needed for @group operation.



Leaves(IterableLeafInfo<'a>)

Describes a set of leaves shapers for a @group operation.

Attribute may repeat multiple times (treat it as array)

Implementations

Source

impl NetShaper<'_>

pub fn new<'a>(buf: &'a [u8]) -> IterableNetShaper<'a>