pub enum Scope {
Unspec = 0,
Netdev = 1,
Queue = 2,
Node = 3,
}Available on crate feature
net-shaper only.Expand description
Defines the shaper @id interpretation. Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
Variants
Unspec = 0
The scope is not specified.
Netdev = 1
The main shaper for the given network device.
Queue = 2
The shaper is attached to the given device queue, the @id represents the queue number.
Node = 3
The shaper allows grouping of queues or other node shapers; can be nested in either @netdev shapers or other @node shapers, allowing placement in any location of the scheduling tree, except leaves and root.
Implementations