OpGroupDo

Struct OpGroupDo 

pub struct OpGroupDo<'r> { /* private fields */ }
Available on crate feature net-shaper only.
Create or update a scheduling group, attaching the specified @leaves shapers under the specified node identified by @handle. The @leaves shapers scope must be @queue and the node shaper scope must be either @node or @netdev. When the node shaper has @node scope, if the @handle @id is not specified, a new shaper of such scope is created, otherwise the specified node must already exist. When updating an existing node shaper, the specified @leaves are added to the existing node; such node will also retain any preexisting leave. The @parent handle for a new node shaper defaults to the parent of all the leaves, provided all the leaves share the same parent. Otherwise @parent handle must be specified. The user can optionally provide shaping attributes for the node shaper. The operation is atomic, on failure no change is applied to the device shaping configuration, otherwise the @node shaper full identifier, comprising @binding and @handle, is provided as the reply.

Flags: admin-perm

Request attributes:

Reply attributes:

Implementations

Source

impl<'r> OpGroupDo<'r>

pub fn new(request: Request<'r>) -> Self

pub fn encode_request<'buf>( buf: &'buf mut Vec<u8>, ) -> PushNetShaper<&'buf mut Vec<u8>>

pub fn encode(&mut self) -> PushNetShaper<&mut Vec<u8>>

pub fn into_encoder(self) -> PushNetShaper<RequestBuf<'r>>

pub fn decode_request<'a>(buf: &'a [u8]) -> IterableNetShaper<'a>