pub enum OpNapiGetDoReply {
Ifindex(u32),
Id(u32),
Irq(u32),
Pid(u32),
DeferHardIrqs(u32),
GroFlushTimeout(u32),
IrqSuspendTimeout(u32),
Threaded(u32),
}netdev only.Expand description
Get information about NAPI instances configured on the system.
Variants
Ifindex(u32)
ifindex of the netdevice to which NAPI instance belongs.
Id(u32)
ID of the NAPI instance.
Irq(u32)
The associated interrupt vector number for the napi
Pid(u32)
PID of the napi thread, if NAPI is configured to operate in threaded mode. If NAPI is not in threaded mode (i.e. uses normal softirq context), the attribute will be absent.
DeferHardIrqs(u32)
The number of consecutive empty polls before IRQ deferral ends and hardware IRQs are re-enabled.
GroFlushTimeout(u32)
The timeout, in nanoseconds, of when to trigger the NAPI watchdog timer which schedules NAPI processing. Additionally, a non-zero value will also prevent GRO from flushing recent super-frames at the end of a NAPI cycle. This may add receive latency in exchange for reducing the number of frames processed by the network stack.
IrqSuspendTimeout(u32)
The timeout, in nanoseconds, of how long to suspend irq processing, if event polling finds events
Threaded(u32)
Whether the NAPI is configured to operate in threaded polling mode. If this is set to enabled then the NAPI context operates in threaded polling mode. If this is set to busy-poll, then the threaded polling mode also busy polls. Associated type: “NapiThreaded” (enum)
Implementations
Sourceimpl OpNapiGetDoReply
impl OpNapiGetDoReply
pub fn new<'a>(buf: &'a [u8]) -> IterableOpNapiGetDoReply<'a> ⓘ