pub enum OpNapiSetDoRequest {
Id(u32),
DeferHardIrqs(u32),
GroFlushTimeout(u32),
IrqSuspendTimeout(u32),
Threaded(u32),
}netdev only.Expand description
Set configurable NAPI instance settings.
Variants
Id(u32)
ID of the NAPI instance.
DeferHardIrqs(u32)
The number of consecutive empty polls before IRQ deferral ends and hardware IRQs are re-enabled.
GroFlushTimeout(u32)
The timeout, in nanoseconds, of when to trigger the NAPI watchdog timer which schedules NAPI processing. Additionally, a non-zero value will also prevent GRO from flushing recent super-frames at the end of a NAPI cycle. This may add receive latency in exchange for reducing the number of frames processed by the network stack.
IrqSuspendTimeout(u32)
The timeout, in nanoseconds, of how long to suspend irq processing, if event polling finds events
Threaded(u32)
Whether the NAPI is configured to operate in threaded polling mode. If this is set to enabled then the NAPI context operates in threaded polling mode. If this is set to busy-poll, then the threaded polling mode also busy polls. Associated type: “NapiThreaded” (enum)
Implementations
Sourceimpl OpNapiSetDoRequest
impl OpNapiSetDoRequest
pub fn new<'a>(buf: &'a [u8]) -> IterableOpNapiSetDoRequest<'a> ⓘ