OpPagePoolGetDoReply

Enum OpPagePoolGetDoReply 

pub enum OpPagePoolGetDoReply<'a> {
    Id(u32),
    Ifindex(u32),
    NapiId(u32),
    Inflight(u32),
    InflightMem(u32),
    DetachTime(u32),
    Dmabuf(u32),
    IoUring(IterableIoUringProviderInfo<'a>),
}
Available on crate feature netdev only.
Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)

Variants



Id(u32)

Unique ID of a Page Pool instance.



Ifindex(u32)

ifindex of the netdev to which the pool belongs. May be reported as 0 if the page pool was allocated for a netdev which got destroyed already (page pools may outlast their netdevs because they wait for all memory to be returned).



NapiId(u32)

Id of NAPI using this Page Pool instance.



Inflight(u32)

Number of outstanding references to this page pool (allocated but yet to be freed pages). Allocated pages may be held in socket receive queues, driver receive ring, page pool recycling ring, the page pool cache, etc.



InflightMem(u32)

Amount of memory held by inflight pages.



DetachTime(u32)

Seconds in CLOCK_BOOTTIME of when Page Pool was detached by the driver. Once detached Page Pool can no longer be used to allocate memory. Page Pools wait for all the memory allocated from them to be freed before truly disappearing. “Detached” Page Pools cannot be “re-attached”, they are just waiting to disappear. Attribute is absent if Page Pool has not been detached, and can still be used to allocate new memory.



Dmabuf(u32)

ID of the dmabuf this page-pool is attached to.



IoUring(IterableIoUringProviderInfo<'a>)

io-uring memory provider information.

Implementations