pub enum OpQstatsGetDumpRequest {
Ifindex(u32),
Scope(u32),
}Available on crate feature
netdev only.Expand description
Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
Variants
Ifindex(u32)
ifindex of the netdevice to which stats belong.
Scope(u32)
What object type should be used to iterate over the stats.
Associated type: “QstatsScope” (enum)
Implementations
Sourceimpl OpQstatsGetDumpRequest
impl OpQstatsGetDumpRequest
pub fn new<'a>(buf: &'a [u8]) -> IterableOpQstatsGetDumpRequest<'a> ⓘ