pub enum OpQueueGetDoRequest {
Id(u32),
Ifindex(u32),
Type(u32),
}Available on crate feature
netdev only.Expand description
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
Variants
Id(u32)
Queue index; most queue types are indexed like a C array, with indexes starting at 0 and ending at queue count - 1. Queue indexes are scoped to an interface and queue type.
Ifindex(u32)
ifindex of the netdevice to which the queue belongs.
Type(u32)
Queue type as rx, tx. Each queue type defines a separate ID space. XDP TX queues allocated in the kernel are not linked to NAPIs and thus not listed. AF_XDP queues will have more information set in the xsk attribute. Associated type: “QueueType” (enum)
Implementations
Sourceimpl OpQueueGetDoRequest
impl OpQueueGetDoRequest
pub fn new<'a>(buf: &'a [u8]) -> IterableOpQueueGetDoRequest<'a> ⓘ