pub enum PagePoolInfo {
Id(u32),
Ifindex(u32),
}Available on crate feature
netdev only.Variants
Id(u32)
Unique ID of a Page Pool instance.
Ifindex(u32)
ifindex of the netdev to which the pool belongs. May be reported as 0 if the page pool was allocated for a netdev which got destroyed already (page pools may outlast their netdevs because they wait for all memory to be returned).
Implementations
Sourceimpl PagePoolInfo
impl PagePoolInfo
pub fn new<'a>(buf: &'a [u8]) -> IterablePagePoolInfo<'a> ⓘ