pub enum QueueId {
Id(u32),
Type(u32),
}Available on crate feature
netdev only.Variants
Id(u32)
Queue index; most queue types are indexed like a C array, with indexes starting at 0 and ending at queue count - 1. Queue indexes are scoped to an interface and queue type.
Type(u32)
Queue type as rx, tx. Each queue type defines a separate ID space. XDP TX queues allocated in the kernel are not linked to NAPIs and thus not listed. AF_XDP queues will have more information set in the xsk attribute. Associated type: “QueueType” (enum)
Implementations