pub enum XskFlags {
TxTimestamp = 1,
TxChecksum = 2,
TxLaunchTimeFifo = 4,
}Available on crate feature
netdev only.Expand description
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
Variants
TxTimestamp = 1
HW timestamping egress packets is supported by the driver.
TxChecksum = 2
L3 checksum HW offload is supported by the driver.
TxLaunchTimeFifo = 4
Launch time HW offload is supported by the driver.
Implementations