pub struct IterableNapi<'a> { /* private fields */ }netdev only.Implementations
Sourceimpl<'a> IterableNapi<'a>
impl<'a> IterableNapi<'a>
Sourcepub fn get_ifindex(&self) -> Result<u32, ErrorContext>
pub fn get_ifindex(&self) -> Result<u32, ErrorContext>
ifindex of the netdevice to which NAPI instance belongs.
Sourcepub fn get_id(&self) -> Result<u32, ErrorContext>
pub fn get_id(&self) -> Result<u32, ErrorContext>
ID of the NAPI instance.
Sourcepub fn get_irq(&self) -> Result<u32, ErrorContext>
pub fn get_irq(&self) -> Result<u32, ErrorContext>
The associated interrupt vector number for the napi
Sourcepub fn get_pid(&self) -> Result<u32, ErrorContext>
pub fn get_pid(&self) -> Result<u32, ErrorContext>
PID of the napi thread, if NAPI is configured to operate in threaded mode. If NAPI is not in threaded mode (i.e. uses normal softirq context), the attribute will be absent.
Sourcepub fn get_defer_hard_irqs(&self) -> Result<u32, ErrorContext>
pub fn get_defer_hard_irqs(&self) -> Result<u32, ErrorContext>
The number of consecutive empty polls before IRQ deferral ends and hardware IRQs are re-enabled.
Sourcepub fn get_gro_flush_timeout(&self) -> Result<u32, ErrorContext>
pub fn get_gro_flush_timeout(&self) -> Result<u32, ErrorContext>
The timeout, in nanoseconds, of when to trigger the NAPI watchdog timer which schedules NAPI processing. Additionally, a non-zero value will also prevent GRO from flushing recent super-frames at the end of a NAPI cycle. This may add receive latency in exchange for reducing the number of frames processed by the network stack.
Sourcepub fn get_irq_suspend_timeout(&self) -> Result<u32, ErrorContext>
pub fn get_irq_suspend_timeout(&self) -> Result<u32, ErrorContext>
The timeout, in nanoseconds, of how long to suspend irq processing, if event polling finds events
Sourcepub fn get_threaded(&self) -> Result<u32, ErrorContext>
pub fn get_threaded(&self) -> Result<u32, ErrorContext>
Whether the NAPI is configured to operate in threaded polling mode. If this is set to enabled then the NAPI context operates in threaded polling mode. If this is set to busy-poll, then the threaded polling mode also busy polls. Associated type: “NapiThreaded” (enum)