pub struct IterableOpPagePoolGetDoReply<'a> { /* private fields */ }netdev only.Implementations
Sourceimpl<'a> IterableOpPagePoolGetDoReply<'a>
impl<'a> IterableOpPagePoolGetDoReply<'a>
Sourcepub fn get_id(&self) -> Result<u32, ErrorContext>
pub fn get_id(&self) -> Result<u32, ErrorContext>
Unique ID of a Page Pool instance.
Sourcepub fn get_ifindex(&self) -> Result<u32, ErrorContext>
pub fn get_ifindex(&self) -> Result<u32, ErrorContext>
ifindex of the netdev to which the pool belongs. May be reported as 0 if the page pool was allocated for a netdev which got destroyed already (page pools may outlast their netdevs because they wait for all memory to be returned).
Sourcepub fn get_napi_id(&self) -> Result<u32, ErrorContext>
pub fn get_napi_id(&self) -> Result<u32, ErrorContext>
Id of NAPI using this Page Pool instance.
Sourcepub fn get_inflight(&self) -> Result<u32, ErrorContext>
pub fn get_inflight(&self) -> Result<u32, ErrorContext>
Number of outstanding references to this page pool (allocated but yet to be freed pages). Allocated pages may be held in socket receive queues, driver receive ring, page pool recycling ring, the page pool cache, etc.
Sourcepub fn get_inflight_mem(&self) -> Result<u32, ErrorContext>
pub fn get_inflight_mem(&self) -> Result<u32, ErrorContext>
Amount of memory held by inflight pages.
Sourcepub fn get_detach_time(&self) -> Result<u32, ErrorContext>
pub fn get_detach_time(&self) -> Result<u32, ErrorContext>
Seconds in CLOCK_BOOTTIME of when Page Pool was detached by the driver. Once detached Page Pool can no longer be used to allocate memory. Page Pools wait for all the memory allocated from them to be freed before truly disappearing. “Detached” Page Pools cannot be “re-attached”, they are just waiting to disappear. Attribute is absent if Page Pool has not been detached, and can still be used to allocate new memory.
Sourcepub fn get_dmabuf(&self) -> Result<u32, ErrorContext>
pub fn get_dmabuf(&self) -> Result<u32, ErrorContext>
ID of the dmabuf this page-pool is attached to.
Sourcepub fn get_io_uring(
&self,
) -> Result<IterableIoUringProviderInfo<'a>, ErrorContext>
pub fn get_io_uring( &self, ) -> Result<IterableIoUringProviderInfo<'a>, ErrorContext>
io-uring memory provider information.