pub struct OpQstatsGetDump<'r> { /* private fields */ }Available on crate feature
netdev only.Expand description
Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
Request attributes:
Reply attributes:
- .get_ifindex()
- .get_queue_type()
- .get_queue_id()
- .get_rx_packets()
- .get_rx_bytes()
- .get_tx_packets()
- .get_tx_bytes()
- .get_rx_alloc_fail()
- .get_rx_hw_drops()
- .get_rx_hw_drop_overruns()
- .get_rx_csum_complete()
- .get_rx_csum_unnecessary()
- .get_rx_csum_none()
- .get_rx_csum_bad()
- .get_rx_hw_gro_packets()
- .get_rx_hw_gro_bytes()
- .get_rx_hw_gro_wire_packets()
- .get_rx_hw_gro_wire_bytes()
- .get_rx_hw_drop_ratelimits()
- .get_tx_hw_drops()
- .get_tx_hw_drop_errors()
- .get_tx_csum_none()
- .get_tx_needs_csum()
- .get_tx_hw_gso_packets()
- .get_tx_hw_gso_bytes()
- .get_tx_hw_gso_wire_packets()
- .get_tx_hw_gso_wire_bytes()
- .get_tx_hw_drop_ratelimits()
- .get_tx_stop()
- .get_tx_wake()
Implementations
Sourceimpl<'r> OpQstatsGetDump<'r>
impl<'r> OpQstatsGetDump<'r>
pub fn new(request: Request<'r>) -> Self
pub fn encode_request<'buf>( buf: &'buf mut Vec<u8>, ) -> PushQstats<&'buf mut Vec<u8>>
pub fn encode(&mut self) -> PushQstats<&mut Vec<u8>>
pub fn into_encoder(self) -> PushQstats<RequestBuf<'r>>
pub fn decode_request<'a>(buf: &'a [u8]) -> IterableQstats<'a> ⓘ