pub struct PushOpPagePoolGetDoReply<Prev: Rec> { /* private fields */ }netdev only.Expand description
Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
Implementations
Sourceimpl<Prev: Rec> PushOpPagePoolGetDoReply<Prev>
impl<Prev: Rec> PushOpPagePoolGetDoReply<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
Sourcepub fn push_ifindex(self, value: u32) -> Self
pub fn push_ifindex(self, value: u32) -> Self
ifindex of the netdev to which the pool belongs. May be reported as 0 if the page pool was allocated for a netdev which got destroyed already (page pools may outlast their netdevs because they wait for all memory to be returned).
Sourcepub fn push_napi_id(self, value: u32) -> Self
pub fn push_napi_id(self, value: u32) -> Self
Id of NAPI using this Page Pool instance.
Sourcepub fn push_inflight(self, value: u32) -> Self
pub fn push_inflight(self, value: u32) -> Self
Number of outstanding references to this page pool (allocated but yet to be freed pages). Allocated pages may be held in socket receive queues, driver receive ring, page pool recycling ring, the page pool cache, etc.
Sourcepub fn push_inflight_mem(self, value: u32) -> Self
pub fn push_inflight_mem(self, value: u32) -> Self
Amount of memory held by inflight pages.
Sourcepub fn push_detach_time(self, value: u32) -> Self
pub fn push_detach_time(self, value: u32) -> Self
Seconds in CLOCK_BOOTTIME of when Page Pool was detached by the driver. Once detached Page Pool can no longer be used to allocate memory. Page Pools wait for all the memory allocated from them to be freed before truly disappearing. “Detached” Page Pools cannot be “re-attached”, they are just waiting to disappear. Attribute is absent if Page Pool has not been detached, and can still be used to allocate new memory.
Sourcepub fn push_dmabuf(self, value: u32) -> Self
pub fn push_dmabuf(self, value: u32) -> Self
ID of the dmabuf this page-pool is attached to.
Sourcepub fn nested_io_uring(self) -> PushIoUringProviderInfo<Self>
pub fn nested_io_uring(self) -> PushIoUringProviderInfo<Self>
io-uring memory provider information.