pub struct PushOpQstatsGetDumpRequest<Prev: Rec> { /* private fields */ }Available on crate feature
netdev only.Expand description
Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
Implementations
Sourceimpl<Prev: Rec> PushOpQstatsGetDumpRequest<Prev>
impl<Prev: Rec> PushOpQstatsGetDumpRequest<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
Sourcepub fn push_ifindex(self, value: u32) -> Self
pub fn push_ifindex(self, value: u32) -> Self
ifindex of the netdevice to which stats belong.
Sourcepub fn push_scope(self, value: u32) -> Self
pub fn push_scope(self, value: u32) -> Self
What object type should be used to iterate over the stats.
Associated type: “QstatsScope” (enum)