PushPagePool

Struct PushPagePool 

pub struct PushPagePool<Prev: Pusher> { /* private fields */ }
Available on crate feature netdev only.

Implementations

Source

impl<Prev: Pusher> PushPagePool<Prev>

pub fn new(prev: Prev) -> Self

pub fn end_nested(self) -> Prev

pub fn push_id(self, value: u32) -> Self

Unique ID of a Page Pool instance.

pub fn push_ifindex(self, value: u32) -> Self

ifindex of the netdev to which the pool belongs. May not be reported if the page pool was allocated for a netdev which got destroyed already (page pools may outlast their netdevs because they wait for all memory to be returned).

pub fn push_napi_id(self, value: u32) -> Self

Id of NAPI using this Page Pool instance.

pub fn push_inflight(self, value: u32) -> Self

Number of outstanding references to this page pool (allocated but yet to be freed pages). Allocated pages may be held in socket receive queues, driver receive ring, page pool recycling ring, the page pool cache, etc.

pub fn push_inflight_mem(self, value: u32) -> Self

Amount of memory held by inflight pages.

pub fn push_detach_time(self, value: u32) -> Self

Seconds in CLOCK_BOOTTIME of when Page Pool was detached by the driver. Once detached Page Pool can no longer be used to allocate memory. Page Pools wait for all the memory allocated from them to be freed before truly disappearing. "Detached" Page Pools cannot be "re-attached", they are just waiting to disappear. Attribute is absent if Page Pool has not been detached, and can still be used to allocate new memory.

pub fn push_dmabuf(self, value: u32) -> Self

ID of the dmabuf this page-pool is attached to.

pub fn nested_io_uring(self) -> PushIoUringProviderInfo<Self>

io-uring memory provider information.