pub struct PushPagePoolInfo<Prev: Rec> { /* private fields */ }Available on crate feature
netdev only.Implementations
Sourceimpl<Prev: Rec> PushPagePoolInfo<Prev>
impl<Prev: Rec> PushPagePoolInfo<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
Sourcepub fn push_ifindex(self, value: u32) -> Self
pub fn push_ifindex(self, value: u32) -> Self
ifindex of the netdev to which the pool belongs. May not be reported if the page pool was allocated for a netdev which got destroyed already (page pools may outlast their netdevs because they wait for all memory to be returned).