pub struct Request<'buf> { /* private fields */ }netdev only.Implementations
Sourceimpl<'buf> Request<'buf>
impl<'buf> Request<'buf>
pub fn new_with_buf(buf: &'buf mut Vec<u8>) -> Self
pub fn new_extend(buf: &'buf mut Vec<u8>) -> Self
pub fn buf(&self) -> &Vec<u8> ⓘ
pub fn buf_mut(&mut self) -> &mut Vec<u8> ⓘ
Sourcepub fn set_create(self) -> Self
pub fn set_create(self) -> Self
Set NLM_F_CREATE flag
Sourcepub fn set_replace(self) -> Self
pub fn set_replace(self) -> Self
Set NLM_F_REPLACE flag
Sourcepub fn set_change(self) -> Self
pub fn set_change(self) -> Self
Set NLM_F_CREATE and NLM_F_REPLACE flag
Sourcepub fn set_append(self) -> Self
pub fn set_append(self) -> Self
Set NLM_F_APPEND flag
Sourcepub fn unset_flags(self, flags: u16) -> Self
pub fn unset_flags(self, flags: u16) -> Self
Set self.flags ^= self.flags & flags
Sourcepub fn op_dev_get_dump(self) -> OpDevGetDump<'buf>
pub fn op_dev_get_dump(self) -> OpDevGetDump<'buf>
Get / dump information about a netdev.
Reply attributes:
Sourcepub fn op_dev_get_do(self) -> OpDevGetDo<'buf>
pub fn op_dev_get_do(self) -> OpDevGetDo<'buf>
Get / dump information about a netdev. Request attributes:
Reply attributes:
Sourcepub fn op_page_pool_get_dump(self) -> OpPagePoolGetDump<'buf>
pub fn op_page_pool_get_dump(self) -> OpPagePoolGetDump<'buf>
Get / dump information about Page Pools. Only Page Pools associated by the driver with a net_device can be listed. ifindex will not be reported if the net_device no longer exists.
Reply attributes:
Sourcepub fn op_page_pool_get_do(self) -> OpPagePoolGetDo<'buf>
pub fn op_page_pool_get_do(self) -> OpPagePoolGetDo<'buf>
Get / dump information about Page Pools. Only Page Pools associated by the driver with a net_device can be listed. ifindex will not be reported if the net_device no longer exists.
Request attributes:
Reply attributes:
Sourcepub fn op_page_pool_stats_get_dump(self) -> OpPagePoolStatsGetDump<'buf>
pub fn op_page_pool_stats_get_dump(self) -> OpPagePoolStatsGetDump<'buf>
Get page pool statistics.
Reply attributes:
Sourcepub fn op_page_pool_stats_get_do(self) -> OpPagePoolStatsGetDo<'buf>
pub fn op_page_pool_stats_get_do(self) -> OpPagePoolStatsGetDo<'buf>
Get page pool statistics. Request attributes:
Reply attributes:
Sourcepub fn op_queue_get_dump(self) -> OpQueueGetDump<'buf>
pub fn op_queue_get_dump(self) -> OpQueueGetDump<'buf>
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues). Request attributes:
Reply attributes:
Sourcepub fn op_queue_get_do(self) -> OpQueueGetDo<'buf>
pub fn op_queue_get_do(self) -> OpQueueGetDo<'buf>
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues). Request attributes:
Reply attributes:
Sourcepub fn op_napi_get_dump(self) -> OpNapiGetDump<'buf>
pub fn op_napi_get_dump(self) -> OpNapiGetDump<'buf>
Get information about NAPI instances configured on the system. Request attributes:
Reply attributes:
Sourcepub fn op_napi_get_do(self) -> OpNapiGetDo<'buf>
pub fn op_napi_get_do(self) -> OpNapiGetDo<'buf>
Get information about NAPI instances configured on the system. Request attributes:
Reply attributes:
Sourcepub fn op_qstats_get_dump(self) -> OpQstatsGetDump<'buf>
pub fn op_qstats_get_dump(self) -> OpQstatsGetDump<'buf>
Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
Request attributes:
Reply attributes:
- .get_ifindex()
- .get_queue_type()
- .get_queue_id()
- .get_rx_packets()
- .get_rx_bytes()
- .get_tx_packets()
- .get_tx_bytes()
- .get_rx_alloc_fail()
- .get_rx_hw_drops()
- .get_rx_hw_drop_overruns()
- .get_rx_csum_complete()
- .get_rx_csum_unnecessary()
- .get_rx_csum_none()
- .get_rx_csum_bad()
- .get_rx_hw_gro_packets()
- .get_rx_hw_gro_bytes()
- .get_rx_hw_gro_wire_packets()
- .get_rx_hw_gro_wire_bytes()
- .get_rx_hw_drop_ratelimits()
- .get_tx_hw_drops()
- .get_tx_hw_drop_errors()
- .get_tx_csum_none()
- .get_tx_needs_csum()
- .get_tx_hw_gso_packets()
- .get_tx_hw_gso_bytes()
- .get_tx_hw_gso_wire_packets()
- .get_tx_hw_gso_wire_bytes()
- .get_tx_hw_drop_ratelimits()
- .get_tx_stop()
- .get_tx_wake()
Sourcepub fn op_bind_rx_do(self) -> OpBindRxDo<'buf>
pub fn op_bind_rx_do(self) -> OpBindRxDo<'buf>
Bind dmabuf to netdev Flags: admin-perm Request attributes:
Reply attributes:
Sourcepub fn op_napi_set_do(self) -> OpNapiSetDo<'buf>
pub fn op_napi_set_do(self) -> OpNapiSetDo<'buf>
Set configurable NAPI instance settings. Flags: admin-perm Request attributes:
Sourcepub fn op_bind_tx_do(self) -> OpBindTxDo<'buf>
pub fn op_bind_tx_do(self) -> OpBindTxDo<'buf>
Bind dmabuf to netdev for TX Request attributes:
Reply attributes: