PushUnlockExport

Struct PushUnlockExport 

pub struct PushUnlockExport<Prev: Pusher> { /* private fields */ }
Available on crate feature nfsd only.

Implementations

Source

impl<Prev: Pusher> PushUnlockExport<Prev>

pub fn new(prev: Prev) -> Self

pub fn end_nested(self) -> Prev

pub fn push_path(self, value: &CStr) -> Self

Export path whose NFSv4 state should be revoked. All state (opens, locks, delegations, layouts) acquired through any export of this path is revoked, regardless of which client holds the state. Intended for use after all clients have been unexported from a given path, enabling the underlying filesystem to be unmounted.

pub fn push_path_bytes(self, value: &[u8]) -> Self

Export path whose NFSv4 state should be revoked. All state (opens, locks, delegations, layouts) acquired through any export of this path is revoked, regardless of which client holds the state. Intended for use after all clients have been unexported from a given path, enabling the underlying filesystem to be unmounted.