Request

Struct Request 

pub struct Request<'buf> { /* private fields */ }
Available on crate feature nfsd only.

Implementations

Source

impl Request<'static>

pub fn new() -> Self

pub fn new_from_buf(buf: Vec<u8>) -> Self

pub fn into_buf(self) -> Vec<u8>

Source

impl<'buf> Request<'buf>

pub fn new_with_buf(buf: &'buf mut Vec<u8>) -> Self

pub fn new_extend(buf: &'buf mut Vec<u8>) -> Self

pub fn buf(&self) -> &Vec<u8>

pub fn buf_mut(&mut self) -> &mut Vec<u8>

pub fn set_create(self) -> Self

Set NLM_F_CREATE flag

pub fn set_excl(self) -> Self

Set NLM_F_EXCL flag

pub fn set_replace(self) -> Self

Set NLM_F_REPLACE flag

pub fn set_change(self) -> Self

Set NLM_F_CREATE and NLM_F_REPLACE flag

pub fn set_append(self) -> Self

Set NLM_F_APPEND flag

pub fn set_flags(self, flags: u16) -> Self

Set self.flags |= flags

pub fn unset_flags(self, flags: u16) -> Self

Set self.flags ^= self.flags & flags

pub fn op_rpc_status_get_dump(self) -> OpRpcStatusGetDump<'buf>

pub fn op_threads_set_do(self) -> OpThreadsSetDo<'buf>

set the maximum number of running threads

Flags: admin-perm

Request attributes:

pub fn op_threads_get_do(self) -> OpThreadsGetDo<'buf>

get the maximum number of running threads

Reply attributes:

pub fn op_version_set_do(self) -> OpVersionSetDo<'buf>

set nfs enabled versions

Flags: admin-perm

Request attributes:

pub fn op_version_get_do(self) -> OpVersionGetDo<'buf>

get nfs enabled versions

Reply attributes:

pub fn op_listener_set_do(self) -> OpListenerSetDo<'buf>

set nfs running sockets

Flags: admin-perm

Request attributes:

pub fn op_listener_get_do(self) -> OpListenerGetDo<'buf>

get nfs running listeners

Reply attributes:

pub fn op_pool_mode_set_do(self) -> OpPoolModeSetDo<'buf>

set the current server pool-mode

Flags: admin-perm

Request attributes:

pub fn op_pool_mode_get_do(self) -> OpPoolModeGetDo<'buf>

get info about server pool-mode

Reply attributes:

pub fn op_svc_export_get_reqs_dump(self) -> OpSvcExportGetReqsDump<'buf>

Dump all pending svc_export requests

Flags: admin-perm

Reply attributes:

pub fn op_svc_export_set_reqs_do(self) -> OpSvcExportSetReqsDo<'buf>

Respond to one or more svc_export requests

Flags: admin-perm

Request attributes:

pub fn op_expkey_get_reqs_dump(self) -> OpExpkeyGetReqsDump<'buf>

Dump all pending expkey requests

Flags: admin-perm

Reply attributes:

pub fn op_expkey_set_reqs_do(self) -> OpExpkeySetReqsDo<'buf>

Respond to one or more expkey requests

Flags: admin-perm

Request attributes:

pub fn op_cache_flush_do(self) -> OpCacheFlushDo<'buf>

Flush nfsd caches (svc_export and/or expkey)

Flags: admin-perm

Request attributes:

pub fn op_unlock_ip_do(self) -> OpUnlockIpDo<'buf>

release NLM locks held by an IP address

Flags: admin-perm

Request attributes:

pub fn op_unlock_filesystem_do(self) -> OpUnlockFilesystemDo<'buf>

revoke NFS state under a filesystem path

Flags: admin-perm

Request attributes:

pub fn op_unlock_export_do(self) -> OpUnlockExportDo<'buf>

Revoke NFSv4 state acquired through exports of a given path. Unlike unlock-filesystem, which operates at superblock granularity, this command targets only state associated with a specific export path. Userspace (exportfs -u) sends this after removing the last client for a path so the underlying filesystem can be unmounted.

Flags: admin-perm

Request attributes: