Registers

Enum Registers 

pub enum Registers {
Show 21 variants RegVerdict = 0, Reg1 = 1, Reg2 = 2, Reg3 = 3, Reg4 = 4, Reg3200 = 8, Reg3201 = 9, Reg3202 = 10, Reg3203 = 11, Reg3204 = 12, Reg3205 = 13, Reg3206 = 14, Reg3207 = 15, Reg3208 = 16, Reg3209 = 17, Reg3210 = 18, Reg3211 = 19, Reg3212 = 20, Reg3213 = 21, Reg3214 = 22, Reg3215 = 23,
}
Available on crate feature nftables only.
nf_tables registers. nf_tables used to have five registers: a verdict register and four data registers of size 16. The data registers have been changed to 16 registers of size 4. For compatibility reasons, the NFT_REG[1-4] registers still map to areas of size 16, the 4 byte registers are addressed using NFT_REG32_00 - NFT_REG32_15. Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)

Variants



RegVerdict = 0



Reg1 = 1



Reg2 = 2



Reg3 = 3



Reg4 = 4



Reg3200 = 8



Reg3201 = 9



Reg3202 = 10



Reg3203 = 11



Reg3204 = 12



Reg3205 = 13



Reg3206 = 14



Reg3207 = 15



Reg3208 = 16



Reg3209 = 17



Reg3210 = 18



Reg3211 = 19



Reg3212 = 20



Reg3213 = 21



Reg3214 = 22



Reg3215 = 23

Implementations

Source

impl Registers

pub fn from_value(value: u64) -> Option<Self>