pub struct Request<'buf> { /* private fields */ }nl80211 only.Implementations
Sourceimpl<'buf> Request<'buf>
impl<'buf> Request<'buf>
pub fn new_with_buf(buf: &'buf mut Vec<u8>) -> Self
pub fn new_extend(buf: &'buf mut Vec<u8>) -> Self
pub fn buf(&self) -> &Vec<u8> ⓘ
pub fn buf_mut(&mut self) -> &mut Vec<u8> ⓘ
Sourcepub fn set_create(self) -> Self
pub fn set_create(self) -> Self
Set NLM_F_CREATE flag
Sourcepub fn set_replace(self) -> Self
pub fn set_replace(self) -> Self
Set NLM_F_REPLACE flag
Sourcepub fn set_change(self) -> Self
pub fn set_change(self) -> Self
Set NLM_F_CREATE and NLM_F_REPLACE flag
Sourcepub fn set_append(self) -> Self
pub fn set_append(self) -> Self
Set NLM_F_APPEND flag
Sourcepub fn unset_flags(self, flags: u16) -> Self
pub fn unset_flags(self, flags: u16) -> Self
Set self.flags ^= self.flags & flags
Sourcepub fn op_get_wiphy_dump(self) -> OpGetWiphyDump<'buf>
pub fn op_get_wiphy_dump(self) -> OpGetWiphyDump<'buf>
Get information about a wiphy or dump a list of all wiphys. Requests to dump get-wiphy should unconditionally include the split-wiphy-dump flag in the request.
Request attributes:
Reply attributes:
- .get_wiphy()
- .get_wiphy_name()
- .get_mac()
- .get_wiphy_bands()
- .get_supported_iftypes()
- .get_max_num_scan_ssids()
- .get_generation()
- .get_supported_commands()
- .get_max_scan_ie_len()
- .get_cipher_suites()
- .get_wiphy_retry_short()
- .get_wiphy_retry_long()
- .get_wiphy_frag_threshold()
- .get_wiphy_rts_threshold()
- .get_max_num_pmkids()
- .get_wiphy_coverage_class()
- .get_tx_frame_types()
- .get_rx_frame_types()
- .get_control_port_ethertype()
- .get_wiphy_antenna_tx()
- .get_wiphy_antenna_rx()
- .get_offchannel_tx_ok()
- .get_max_remain_on_channel_duration()
- .get_wiphy_antenna_avail_tx()
- .get_wiphy_antenna_avail_rx()
- .get_wowlan_triggers_supported()
- .get_interface_combinations()
- .get_software_iftypes()
- .get_max_num_sched_scan_ssids()
- .get_max_sched_scan_ie_len()
- .get_support_ap_uapsd()
- .get_max_match_sets()
- .get_tdls_support()
- .get_tdls_external_setup()
- .get_feature_flags()
- .get_ht_capability_mask()
- .get_ext_capa()
- .get_ext_capa_mask()
- .get_vht_capability_mask()
- .get_max_csa_counters()
- .get_ext_features()
- .get_max_num_sched_scan_plans()
- .get_max_scan_plan_interval()
- .get_max_scan_plan_iterations()
- .get_bands()
- .get_sched_scan_max_reqs()
- .get_txq_stats()
- .get_txq_limit()
- .get_txq_memory_limit()
- .get_txq_quantum()
- .get_sar_spec()
- .get_max_num_akm_suites()
Sourcepub fn op_get_wiphy_do(self) -> OpGetWiphyDo<'buf>
pub fn op_get_wiphy_do(self) -> OpGetWiphyDo<'buf>
Get information about a wiphy or dump a list of all wiphys. Requests to dump get-wiphy should unconditionally include the split-wiphy-dump flag in the request.
Request attributes:
Reply attributes:
- .get_wiphy()
- .get_wiphy_name()
- .get_mac()
- .get_wiphy_bands()
- .get_supported_iftypes()
- .get_max_num_scan_ssids()
- .get_generation()
- .get_supported_commands()
- .get_max_scan_ie_len()
- .get_cipher_suites()
- .get_wiphy_retry_short()
- .get_wiphy_retry_long()
- .get_wiphy_frag_threshold()
- .get_wiphy_rts_threshold()
- .get_max_num_pmkids()
- .get_wiphy_coverage_class()
- .get_tx_frame_types()
- .get_rx_frame_types()
- .get_control_port_ethertype()
- .get_wiphy_antenna_tx()
- .get_wiphy_antenna_rx()
- .get_offchannel_tx_ok()
- .get_max_remain_on_channel_duration()
- .get_wiphy_antenna_avail_tx()
- .get_wiphy_antenna_avail_rx()
- .get_wowlan_triggers_supported()
- .get_interface_combinations()
- .get_software_iftypes()
- .get_max_num_sched_scan_ssids()
- .get_max_sched_scan_ie_len()
- .get_support_ap_uapsd()
- .get_max_match_sets()
- .get_tdls_support()
- .get_tdls_external_setup()
- .get_feature_flags()
- .get_ht_capability_mask()
- .get_ext_capa()
- .get_ext_capa_mask()
- .get_vht_capability_mask()
- .get_max_csa_counters()
- .get_ext_features()
- .get_max_num_sched_scan_plans()
- .get_max_scan_plan_interval()
- .get_max_scan_plan_iterations()
- .get_bands()
- .get_sched_scan_max_reqs()
- .get_txq_stats()
- .get_txq_limit()
- .get_txq_memory_limit()
- .get_txq_quantum()
- .get_sar_spec()
- .get_max_num_akm_suites()
Sourcepub fn op_get_interface_dump(self) -> OpGetInterfaceDump<'buf>
pub fn op_get_interface_dump(self) -> OpGetInterfaceDump<'buf>
Get information about an interface or dump a list of all interfaces
Request attributes:
Reply attributes:
Sourcepub fn op_get_interface_do(self) -> OpGetInterfaceDo<'buf>
pub fn op_get_interface_do(self) -> OpGetInterfaceDo<'buf>
Get information about an interface or dump a list of all interfaces
Request attributes:
Reply attributes:
Sourcepub fn op_get_protocol_features_do(self) -> OpGetProtocolFeaturesDo<'buf>
pub fn op_get_protocol_features_do(self) -> OpGetProtocolFeaturesDo<'buf>
Get information about supported protocol features
Request attributes:
Reply attributes: