pub enum Keyconf<'a> {
PeerId(u32),
Slot(u32),
KeyId(u32),
CipherAlg(u32),
EncryptDir(IterableKeydir<'a>),
DecryptDir(IterableKeydir<'a>),
}Available on crate feature
ovpn only.Variants
PeerId(u32)
The unique ID of the peer in the device context. To be used to identify peers during key operations
Slot(u32)
The slot where the key should be stored
Associated type: KeySlot (enum)
KeyId(u32)
The unique ID of the key in the peer context. Used to fetch the correct key upon decryption
CipherAlg(u32)
The cipher to be used when communicating with the peer
Associated type: CipherAlg (enum)
EncryptDir(IterableKeydir<'a>)
Key material for encrypt direction
DecryptDir(IterableKeydir<'a>)
Key material for decrypt direction
Implementations