pub enum KeyconfGet {
PeerId(u32),
Slot(u32),
KeyId(u32),
CipherAlg(u32),
}Available on crate feature
ovpn only.Variants
PeerId(u32)
The unique ID of the peer in the device context. To be used to identify peers during key operations
Slot(u32)
The slot where the key should be stored
Associated type: KeySlot (enum)
KeyId(u32)
The unique ID of the key in the peer context. Used to fetch the correct key upon decryption
CipherAlg(u32)
The cipher to be used when communicating with the peer
Associated type: CipherAlg (enum)
Implementations
Sourceimpl KeyconfGet
impl KeyconfGet
pub fn new<'a>(buf: &'a [u8]) -> IterableKeyconfGet<'a> ⓘ