pub enum Keydir<'a> {
CipherKey(&'a [u8]),
NonceTail(&'a [u8]),
}Available on crate feature
ovpn only.Variants
CipherKey(&'a [u8])
The actual key to be used by the cipher
NonceTail(&'a [u8])
Random nonce to be concatenated to the packet ID, in order to obtain the actual cipher IV
Implementations