pub enum PeerDelInput {
Id(u32),
}Available on crate feature
ovpn only.Variants
Id(u32)
The unique ID of the peer in the device context. To be used to identify peers during operations for a specific device. Also used to match packets received from this peer.
Implementations
Sourceimpl PeerDelInput
impl PeerDelInput
pub fn new<'a>(buf: &'a [u8]) -> IterablePeerDelInput<'a> ⓘ