PeerSetInput

Enum PeerSetInput 

pub enum PeerSetInput<'a> {
    Id(u32),
    RemoteIpv4(Ipv4Addr),
    RemoteIpv6(&'a [u8]),
    RemoteIpv6ScopeId(u32),
    RemotePort(u16),
    VpnIpv4(Ipv4Addr),
    VpnIpv6(&'a [u8]),
    LocalIpv4(Ipv4Addr),
    LocalIpv6(&'a [u8]),
    KeepaliveInterval(u32),
    KeepaliveTimeout(u32),
    TxId(u32),
}
Available on crate feature ovpn only.

Variants



Id(u32)

The unique ID of the peer in the device context. To be used to identify peers during operations for a specific device. Also used to match packets received from this peer.



RemoteIpv4(Ipv4Addr)

The remote IPv4 address of the peer



RemoteIpv6(&'a [u8])

The remote IPv6 address of the peer



RemoteIpv6ScopeId(u32)

The scope id of the remote IPv6 address of the peer (RFC2553)



RemotePort(u16)

The remote port of the peer



VpnIpv4(Ipv4Addr)

The IPv4 address assigned to the peer by the server



VpnIpv6(&'a [u8])

The IPv6 address assigned to the peer by the server



LocalIpv4(Ipv4Addr)

The local IPv4 to be used to send packets to the peer (UDP only)



LocalIpv6(&'a [u8])

The local IPv6 to be used to send packets to the peer (UDP only)



KeepaliveInterval(u32)

The number of seconds after which a keep alive message is sent to the peer



KeepaliveTimeout(u32)

The number of seconds from the last activity after which the peer is assumed dead



TxId(u32)

The ID value used when transmitting packets to this peer. This way outgoing packets can have a different ID than incoming ones. Useful in multipeer-to-multipeer connections, where each peer will advertise the tx-id to be used on the link.

Implementations

Source

impl PeerSetInput<'_>

pub fn new<'a>(buf: &'a [u8]) -> IterablePeerSetInput<'a>