pub struct PushKeyconfGet<Prev: Pusher> { /* private fields */ }Available on crate feature
ovpn only.Implementations
Sourceimpl<Prev: Pusher> PushKeyconfGet<Prev>
impl<Prev: Pusher> PushKeyconfGet<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
Sourcepub fn push_peer_id(self, value: u32) -> Self
pub fn push_peer_id(self, value: u32) -> Self
The unique ID of the peer in the device context. To be used to identify peers during key operations
Sourcepub fn push_slot(self, value: u32) -> Self
pub fn push_slot(self, value: u32) -> Self
The slot where the key should be stored
Associated type: KeySlot (enum)
Sourcepub fn push_key_id(self, value: u32) -> Self
pub fn push_key_id(self, value: u32) -> Self
The unique ID of the key in the peer context. Used to fetch the correct key upon decryption
Sourcepub fn push_cipher_alg(self, value: u32) -> Self
pub fn push_cipher_alg(self, value: u32) -> Self
The cipher to be used when communicating with the peer
Associated type: CipherAlg (enum)