pub struct PushKeydir<Prev: Rec> { /* private fields */ }Available on crate feature
ovpn only.Implementations
Sourceimpl<Prev: Rec> PushKeydir<Prev>
impl<Prev: Rec> PushKeydir<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
Sourcepub fn push_cipher_key(self, value: &[u8]) -> Self
pub fn push_cipher_key(self, value: &[u8]) -> Self
The actual key to be used by the cipher
Sourcepub fn push_nonce_tail(self, value: &[u8]) -> Self
pub fn push_nonce_tail(self, value: &[u8]) -> Self
Random nonce to be concatenated to the packet ID, in order to obtain the actual cipher IV