pub struct PushPeerNewInput<Prev: Pusher> { /* private fields */ }ovpn only.Implementations
Sourceimpl<Prev: Pusher> PushPeerNewInput<Prev>
impl<Prev: Pusher> PushPeerNewInput<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
Sourcepub fn push_id(self, value: u32) -> Self
pub fn push_id(self, value: u32) -> Self
The unique ID of the peer in the device context. To be used to identify peers during operations for a specific device. Also used to match packets received from this peer.
Sourcepub fn push_remote_ipv4(self, value: Ipv4Addr) -> Self
pub fn push_remote_ipv4(self, value: Ipv4Addr) -> Self
The remote IPv4 address of the peer
Sourcepub fn push_remote_ipv6(self, value: &[u8]) -> Self
pub fn push_remote_ipv6(self, value: &[u8]) -> Self
The remote IPv6 address of the peer
Sourcepub fn push_remote_ipv6_scope_id(self, value: u32) -> Self
pub fn push_remote_ipv6_scope_id(self, value: u32) -> Self
The scope id of the remote IPv6 address of the peer (RFC2553)
Sourcepub fn push_remote_port(self, value: u16) -> Self
pub fn push_remote_port(self, value: u16) -> Self
The remote port of the peer
Sourcepub fn push_socket(self, value: u32) -> Self
pub fn push_socket(self, value: u32) -> Self
The socket to be used to communicate with the peer
Sourcepub fn push_vpn_ipv4(self, value: Ipv4Addr) -> Self
pub fn push_vpn_ipv4(self, value: Ipv4Addr) -> Self
The IPv4 address assigned to the peer by the server
Sourcepub fn push_vpn_ipv6(self, value: &[u8]) -> Self
pub fn push_vpn_ipv6(self, value: &[u8]) -> Self
The IPv6 address assigned to the peer by the server
Sourcepub fn push_local_ipv4(self, value: Ipv4Addr) -> Self
pub fn push_local_ipv4(self, value: Ipv4Addr) -> Self
The local IPv4 to be used to send packets to the peer (UDP only)
Sourcepub fn push_local_ipv6(self, value: &[u8]) -> Self
pub fn push_local_ipv6(self, value: &[u8]) -> Self
The local IPv6 to be used to send packets to the peer (UDP only)
Sourcepub fn push_keepalive_interval(self, value: u32) -> Self
pub fn push_keepalive_interval(self, value: u32) -> Self
The number of seconds after which a keep alive message is sent to the peer
Sourcepub fn push_keepalive_timeout(self, value: u32) -> Self
pub fn push_keepalive_timeout(self, value: u32) -> Self
The number of seconds from the last activity after which the peer is assumed dead
Sourcepub fn push_tx_id(self, value: u32) -> Self
pub fn push_tx_id(self, value: u32) -> Self
The ID value used when transmitting packets to this peer. This way outgoing packets can have a different ID than incoming ones. Useful in multipeer-to-multipeer connections, where each peer will advertise the tx-id to be used on the link.