IterableFlowAttrs

Struct IterableFlowAttrs 

pub struct IterableFlowAttrs<'a> { /* private fields */ }
Available on crate feature ovs_flow only.

Implementations

Source

impl<'a> IterableFlowAttrs<'a>

pub fn get_key(&self) -> Result<IterableKeyAttrs<'a>, ErrorContext>

Nested attributes specifying the flow key. Always present in notifications. Required for all requests (except dumps).

pub fn get_actions(&self) -> Result<IterableActionAttrs<'a>, ErrorContext>

Nested attributes specifying the actions to take for packets that match the key. Always present in notifications. Required for OVS_FLOW_CMD_NEW requests, optional for OVS_FLOW_CMD_SET requests. An OVS_FLOW_CMD_SET without OVS_FLOW_ATTR_ACTIONS will not modify the actions. To clear the actions, an OVS_FLOW_ATTR_ACTIONS without any nested attributes must be given.

pub fn get_stats(&self) -> Result<OvsFlowStats, ErrorContext>

Statistics for this flow. Present in notifications if the stats would be nonzero. Ignored in requests.

pub fn get_tcp_flags(&self) -> Result<u8, ErrorContext>

An 8-bit value giving the ORed value of all of the TCP flags seen on packets in this flow. Only present in notifications for TCP flows, and only if it would be nonzero. Ignored in requests.

pub fn get_used(&self) -> Result<u64, ErrorContext>

A 64-bit integer giving the time, in milliseconds on the system monotonic clock, at which a packet was last processed for this flow. Only present in notifications if a packet has been processed for this flow. Ignored in requests.

pub fn get_clear(&self) -> Result<(), ErrorContext>

If present in a OVS_FLOW_CMD_SET request, clears the last-used time, accumulated TCP flags, and statistics for this flow. Otherwise ignored in requests. Never present in notifications.

pub fn get_mask(&self) -> Result<IterableKeyAttrs<'a>, ErrorContext>

Nested attributes specifying the mask bits for wildcarded flow match. Mask bit value '1' specifies exact match with corresponding flow key bit, while mask bit value '0' specifies a wildcarded match. Omitting attribute is treated as wildcarding all corresponding fields. Optional for all requests. If not present, all flow key bits are exact match bits.

pub fn get_probe(&self) -> Result<&'a [u8], ErrorContext>

Flow operation is a feature probe, error logging should be suppressed.

pub fn get_ufid(&self) -> Result<&'a [u8], ErrorContext>

A value between 1-16 octets specifying a unique identifier for the flow. Causes the flow to be indexed by this value rather than the value of the OVS_FLOW_ATTR_KEY attribute. Optional for all requests. Present in notifications if the flow was created with this attribute.

pub fn get_ufid_flags(&self) -> Result<u32, ErrorContext>

A 32-bit value of ORed flags that provide alternative semantics for flow installation and retrieval. Optional for all requests.

Associated type: OvsUfidFlags (enum)

pub fn get_pad(&self) -> Result<&'a [u8], ErrorContext>

Source

impl<'a> IterableFlowAttrs<'a>

pub fn get_buf(&self) -> &'a [u8]

Source

impl IterableFlowAttrs<'_>

pub fn lookup_attr( &self, offset: usize, missing_type: Option<u16>, ) -> (Vec<(&'static str, usize)>, Option<&'static str>)