#[repr(C, packed(4))]pub struct OvsHeader {
pub dp_ifindex: u32,
}Available on crate feature
ovs_flow only.Expand description
Header for OVS Generic Netlink messages.
Fields
dp_ifindex: u32ifindex of local port for datapath (0 to make a request not specific to a datapath).
Implementations
Sourceimpl OvsHeader
impl OvsHeader
Sourcepub fn new_from_slice(other: &[u8]) -> Option<Self>
pub fn new_from_slice(other: &[u8]) -> Option<Self>
Copy from contents from slice
Sourcepub fn new_from_zeroed(other: &[u8]) -> Self
pub fn new_from_zeroed(other: &[u8]) -> Self
Copy from contents from another slice, padding with zeros or truncating when needed
pub fn new_from_array(buf: [u8; 4]) -> Self
pub fn as_slice(&self) -> &[u8] ⓘ
pub fn from_slice(buf: &[u8]) -> &Self
pub fn as_array(&self) -> &[u8; 4]
pub fn from_array(buf: &[u8; 4]) -> &Self
pub fn into_array(self) -> [u8; 4]
pub const fn len() -> usize