Packet

Enum Packet 

pub enum Packet<'a> {
    Packet(&'a [u8]),
    Key(&'a [u8]),
    Actions(&'a [u8]),
    Userdata(&'a [u8]),
    EgressTunKey(&'a [u8]),
    Probe(()),
    Mru(u16),
    Len(u32),
    Hash(u64),
    UpcallPid(u32),
}
Available on crate feature ovs_packet only.

Variants



Packet(&'a [u8])

Packet data, from the start of the Ethernet header.



Key(&'a [u8])

Nested OVS_KEY_ATTR* attributes, extracted flow key. Defined as binary because the key attribute-set belongs to the ovs_flow family spec; cross-spec references are not supported.



Actions(&'a [u8])

Nested OVS_ACTION_ATTR* attributes. Defined as binary for the same reason as key.



Userdata(&'a [u8])

Opaque userspace cookie from OVS_USERSPACE_ATTR_USERDATA.



EgressTunKey(&'a [u8])

Nested OVS_TUNNEL_KEY_ATTR* for output tunnel metadata.



Probe(())

Packet operation is a feature probe, error logging suppressed.



Mru(u16)

Maximum received IP fragment size.



Len(u32)

Packet size before truncation.



Hash(u64)

Packet hash, low 32 bits are skb hash, upper bits are flags.



UpcallPid(u32)

Netlink PID to use for upcalls during EXECUTE processing.

Implementations

Source

impl Packet<'_>

pub fn new<'a>(buf: &'a [u8]) -> IterablePacket<'a>