pub enum Assoc<'a> {
DevId(u32),
Version(u32),
RxKey(IterableKeys<'a>),
TxKey(IterableKeys<'a>),
SockFd(u32),
}Available on crate feature
psp only.Variants
DevId(u32)
PSP device ID.
Version(u32)
PSP versions (AEAD and protocol version) used by this association, dictates the size of the key.
Associated type: Version (enum)
RxKey(IterableKeys<'a>)
TxKey(IterableKeys<'a>)
SockFd(u32)
Sockets which should be bound to the association immediately.
Implementations