pub enum Dev<'a> {
Id(u32),
Ifindex(u32),
PspVersionsCap(u32),
PspVersionsEna(u32),
AssocList(IterableAssocDevInfo<'a>),
Nsid(i32),
ByAssociation(()),
}psp only.Variants
Id(u32)
PSP device ID.
Ifindex(u32)
ifindex of the main netdevice linked to the PSP device, or the ifindex to associate with the PSP device.
PspVersionsCap(u32)
Bitmask of PSP versions supported by the device.
Associated type: Version (1 bit per enumeration)
PspVersionsEna(u32)
Bitmask of currently enabled (accepted on Rx) PSP versions.
Associated type: Version (1 bit per enumeration)
AssocList(IterableAssocDevInfo<'a>)
List of associated virtual devices.
Attribute may repeat multiple times (treat it as array)
Nsid(i32)
Network namespace ID for the device to associate/disassociate. Optional for dev-assoc and dev-disassoc; if not present, the device is looked up in the caller's network namespace.
ByAssociation(())
Flag indicating the PSP device is an associated device from a different network namespace. Present when in associated namespace, absent when in primary/host namespace.