pub enum Stats {
DevId(u32),
KeyRotations(u32),
StaleEvents(u32),
RxPackets(u32),
RxBytes(u32),
RxAuthFail(u32),
RxError(u32),
RxBad(u32),
TxPackets(u32),
TxBytes(u32),
TxError(u32),
}psp only.Variants
DevId(u32)
PSP device ID.
KeyRotations(u32)
Number of key rotations during the lifetime of the device. Kernel statistic.
StaleEvents(u32)
Number of times a socket's Rx got shut down due to using a key which went stale (fully rotated out). Kernel statistic.
RxPackets(u32)
Number of successfully processed and authenticated PSP packets. Device statistic (from the PSP spec).
RxBytes(u32)
Number of successfully authenticated PSP bytes received, counting from the first byte after the IV through the last byte of payload. The fixed initial portion of the PSP header (16 bytes) and the PSP trailer/ICV (16 bytes) are not included in this count. Device statistic (from the PSP spec).
RxAuthFail(u32)
Number of received PSP packets with unsuccessful authentication. Device statistic (from the PSP spec).
RxError(u32)
Number of received PSP packets with length/framing errors. Device statistic (from the PSP spec).
RxBad(u32)
Number of received PSP packets with miscellaneous errors (invalid master key indicated by SPI, unsupported version, etc.) Device statistic (from the PSP spec).
TxPackets(u32)
Number of successfully processed PSP packets for transmission. Device statistic (from the PSP spec).
TxBytes(u32)
Number of successfully processed PSP bytes for transmit, counting from the first byte after the IV through the last byte of payload. The fixed initial portion of the PSP header (16 bytes) and the PSP trailer/ICV (16 bytes) are not included in this count. Device statistic (from the PSP spec).
TxError(u32)
Number of PSP packets for transmission with errors. Device statistic (from the PSP spec).