pub struct IterableStats<'a> { /* private fields */ }psp only.Implementations
Sourceimpl<'a> IterableStats<'a>
impl<'a> IterableStats<'a>
Sourcepub fn get_dev_id(&self) -> Result<u32, ErrorContext>
pub fn get_dev_id(&self) -> Result<u32, ErrorContext>
PSP device ID.
Sourcepub fn get_key_rotations(&self) -> Result<u32, ErrorContext>
pub fn get_key_rotations(&self) -> Result<u32, ErrorContext>
Number of key rotations during the lifetime of the device. Kernel statistic.
Sourcepub fn get_stale_events(&self) -> Result<u32, ErrorContext>
pub fn get_stale_events(&self) -> Result<u32, ErrorContext>
Number of times a socket's Rx got shut down due to using a key which went stale (fully rotated out). Kernel statistic.
Sourcepub fn get_rx_packets(&self) -> Result<u32, ErrorContext>
pub fn get_rx_packets(&self) -> Result<u32, ErrorContext>
Number of successfully processed and authenticated PSP packets. Device statistic (from the PSP spec).
Sourcepub fn get_rx_bytes(&self) -> Result<u32, ErrorContext>
pub fn get_rx_bytes(&self) -> Result<u32, ErrorContext>
Number of successfully authenticated PSP bytes received, counting from the first byte after the IV through the last byte of payload. The fixed initial portion of the PSP header (16 bytes) and the PSP trailer/ICV (16 bytes) are not included in this count. Device statistic (from the PSP spec).
Sourcepub fn get_rx_auth_fail(&self) -> Result<u32, ErrorContext>
pub fn get_rx_auth_fail(&self) -> Result<u32, ErrorContext>
Number of received PSP packets with unsuccessful authentication. Device statistic (from the PSP spec).
Sourcepub fn get_rx_error(&self) -> Result<u32, ErrorContext>
pub fn get_rx_error(&self) -> Result<u32, ErrorContext>
Number of received PSP packets with length/framing errors. Device statistic (from the PSP spec).
Sourcepub fn get_rx_bad(&self) -> Result<u32, ErrorContext>
pub fn get_rx_bad(&self) -> Result<u32, ErrorContext>
Number of received PSP packets with miscellaneous errors (invalid master key indicated by SPI, unsupported version, etc.) Device statistic (from the PSP spec).
Sourcepub fn get_tx_packets(&self) -> Result<u32, ErrorContext>
pub fn get_tx_packets(&self) -> Result<u32, ErrorContext>
Number of successfully processed PSP packets for transmission. Device statistic (from the PSP spec).
Sourcepub fn get_tx_bytes(&self) -> Result<u32, ErrorContext>
pub fn get_tx_bytes(&self) -> Result<u32, ErrorContext>
Number of successfully processed PSP bytes for transmit, counting from the first byte after the IV through the last byte of payload. The fixed initial portion of the PSP header (16 bytes) and the PSP trailer/ICV (16 bytes) are not included in this count. Device statistic (from the PSP spec).
Sourcepub fn get_tx_error(&self) -> Result<u32, ErrorContext>
pub fn get_tx_error(&self) -> Result<u32, ErrorContext>
Number of PSP packets for transmission with errors. Device statistic (from the PSP spec).