PushDev

Struct PushDev 

pub struct PushDev<Prev: Pusher> { /* private fields */ }
Available on crate feature psp only.

Implementations

Source

impl<Prev: Pusher> PushDev<Prev>

pub fn new(prev: Prev) -> Self

pub fn end_nested(self) -> Prev

pub fn push_id(self, value: u32) -> Self

PSP device ID.

pub fn push_ifindex(self, value: u32) -> Self

ifindex of the main netdevice linked to the PSP device, or the ifindex to associate with the PSP device.

pub fn push_psp_versions_cap(self, value: u32) -> Self

Bitmask of PSP versions supported by the device.

Associated type: Version (1 bit per enumeration)

pub fn push_psp_versions_ena(self, value: u32) -> Self

Bitmask of currently enabled (accepted on Rx) PSP versions.

Associated type: Version (1 bit per enumeration)

pub fn nested_assoc_list(self) -> PushAssocDevInfo<Self>

List of associated virtual devices.

Attribute may repeat multiple times (treat it as array)

pub fn push_nsid(self, value: i32) -> Self

Network namespace ID for the device to associate/disassociate. Optional for dev-assoc and dev-disassoc; if not present, the device is looked up in the caller's network namespace.

pub fn push_by_association(self, value: ()) -> Self

Flag indicating the PSP device is an associated device from a different network namespace. Present when in associated namespace, absent when in primary/host namespace.