pub struct PushTcCodelXstats { /* private fields */ }Available on crate feature
tc only.Implementations
Sourceimpl PushTcCodelXstats
impl PushTcCodelXstats
Sourcepub fn new_from_slice(other: &[u8]) -> Option<Self>
pub fn new_from_slice(other: &[u8]) -> Option<Self>
Copy from contents from other slice
Sourcepub fn new_from_zeroed(other: &[u8]) -> Self
pub fn new_from_zeroed(other: &[u8]) -> Self
Copy from contents from another slice, padding with zeros or truncating when needed
pub fn as_slice(&self) -> &[u8] ⓘ
pub fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
pub const fn len() -> usize
Sourcepub fn set_maxpacket(&mut self, value: u32)
pub fn set_maxpacket(&mut self, value: u32)
Largest packet we’ve seen so far
Sourcepub fn count(&self) -> u32
pub fn count(&self) -> u32
How many drops we’ve done since the last time we entered dropping state
Sourcepub fn set_count(&mut self, value: u32)
pub fn set_count(&mut self, value: u32)
How many drops we’ve done since the last time we entered dropping state
Sourcepub fn set_lastcount(&mut self, value: u32)
pub fn set_lastcount(&mut self, value: u32)
Count at entry to dropping state
Sourcepub fn set_ldelay(&mut self, value: u32)
pub fn set_ldelay(&mut self, value: u32)
in-queue delay seen by most recently dequeued packet
Sourcepub fn set_drop_next(&mut self, value: i32)
pub fn set_drop_next(&mut self, value: i32)
Time to drop next packet
Sourcepub fn drop_overlimit(&self) -> u32
pub fn drop_overlimit(&self) -> u32
Number of times max qdisc packet limit was hit
Sourcepub fn set_drop_overlimit(&mut self, value: u32)
pub fn set_drop_overlimit(&mut self, value: u32)
Number of times max qdisc packet limit was hit
Sourcepub fn set_ecn_mark(&mut self, value: u32)
pub fn set_ecn_mark(&mut self, value: u32)
Number of packets we’ve ECN marked instead of dropped
Sourcepub fn set_dropping(&mut self, value: u32)
pub fn set_dropping(&mut self, value: u32)
Are we in a dropping state?
Sourcepub fn set_ce_mark(&mut self, value: u32)
pub fn set_ce_mark(&mut self, value: u32)
Number of CE marked packets because of ce-threshold