pub struct PushTcFqCodelXstats { /* private fields */ }Available on crate feature
tc only.Implementations
Sourceimpl PushTcFqCodelXstats
impl PushTcFqCodelXstats
Sourcepub fn new_from_slice(other: &[u8]) -> Option<Self>
pub fn new_from_slice(other: &[u8]) -> Option<Self>
Copy from contents from other slice
Sourcepub fn new_from_zeroed(other: &[u8]) -> Self
pub fn new_from_zeroed(other: &[u8]) -> Self
Copy from contents from another slice, padding with zeros or truncating when needed
pub fn as_slice(&self) -> &[u8] ⓘ
pub fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
pub const fn len() -> usize
pub fn get_type(&self) -> u32
pub fn set_type(&mut self, value: u32)
Sourcepub fn set_maxpacket(&mut self, value: u32)
pub fn set_maxpacket(&mut self, value: u32)
Largest packet we’ve seen so far
Sourcepub fn drop_overlimit(&self) -> u32
pub fn drop_overlimit(&self) -> u32
Number of times max qdisc packet limit was hit
Sourcepub fn set_drop_overlimit(&mut self, value: u32)
pub fn set_drop_overlimit(&mut self, value: u32)
Number of times max qdisc packet limit was hit
Sourcepub fn set_ecn_mark(&mut self, value: u32)
pub fn set_ecn_mark(&mut self, value: u32)
Number of packets we ECN marked instead of being dropped
Sourcepub fn new_flow_count(&self) -> u32
pub fn new_flow_count(&self) -> u32
Number of times packets created a new flow
Sourcepub fn set_new_flow_count(&mut self, value: u32)
pub fn set_new_flow_count(&mut self, value: u32)
Number of times packets created a new flow
Sourcepub fn new_flows_len(&self) -> u32
pub fn new_flows_len(&self) -> u32
Count of flows in new list
Sourcepub fn set_new_flows_len(&mut self, value: u32)
pub fn set_new_flows_len(&mut self, value: u32)
Count of flows in new list
Sourcepub fn old_flows_len(&self) -> u32
pub fn old_flows_len(&self) -> u32
Count of flows in old list
Sourcepub fn set_old_flows_len(&mut self, value: u32)
pub fn set_old_flows_len(&mut self, value: u32)
Count of flows in old list
Sourcepub fn set_ce_mark(&mut self, value: u32)
pub fn set_ce_mark(&mut self, value: u32)
Packets above ce-threshold
Sourcepub fn memory_usage(&self) -> u32
pub fn memory_usage(&self) -> u32
Memory usage in bytes
Sourcepub fn set_memory_usage(&mut self, value: u32)
pub fn set_memory_usage(&mut self, value: u32)
Memory usage in bytes
pub fn drop_overmemory(&self) -> u32
pub fn set_drop_overmemory(&mut self, value: u32)