pub struct PushTcStats { /* private fields */ }Available on crate feature
tc only.Implementations
Sourceimpl PushTcStats
impl PushTcStats
Sourcepub fn new_from_slice(other: &[u8]) -> Option<Self>
pub fn new_from_slice(other: &[u8]) -> Option<Self>
Copy from contents from other slice
Sourcepub fn new_from_zeroed(other: &[u8]) -> Self
pub fn new_from_zeroed(other: &[u8]) -> Self
Copy from contents from another slice, padding with zeros or truncating when needed
pub fn as_slice(&self) -> &[u8] ⓘ
pub fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
pub const fn len() -> usize
Sourcepub fn set_packets(&mut self, value: u32)
pub fn set_packets(&mut self, value: u32)
Number of enqueued packets
Sourcepub fn overlimits(&self) -> u32
pub fn overlimits(&self) -> u32
Number of throttle events when this flow goes out of allocated bandwidth
Sourcepub fn set_overlimits(&mut self, value: u32)
pub fn set_overlimits(&mut self, value: u32)
Number of throttle events when this flow goes out of allocated bandwidth
pub fn qlen(&self) -> u32
pub fn set_qlen(&mut self, value: u32)
pub fn backlog(&self) -> u32
pub fn set_backlog(&mut self, value: u32)