#[repr(C, packed(4))]pub struct TcCodelXstats {
pub maxpacket: u32,
pub count: u32,
pub lastcount: u32,
pub ldelay: u32,
pub drop_next: i32,
pub drop_overlimit: u32,
pub ecn_mark: u32,
pub dropping: u32,
pub ce_mark: u32,
}Available on crate feature
tc only.Fields
maxpacket: u32Largest packet we've seen so far
count: u32How many drops we've done since the last time we entered dropping state
lastcount: u32Count at entry to dropping state
ldelay: u32in-queue delay seen by most recently dequeued packet
drop_next: i32Time to drop next packet
drop_overlimit: u32Number of times max qdisc packet limit was hit
ecn_mark: u32Number of packets we've ECN marked instead of dropped
dropping: u32Are we in a dropping state?
ce_mark: u32Number of CE marked packets because of ce-threshold
Implementations
Sourceimpl TcCodelXstats
impl TcCodelXstats
Sourcepub fn new_from_slice(other: &[u8]) -> Option<Self>
pub fn new_from_slice(other: &[u8]) -> Option<Self>
Copy from contents from slice
Sourcepub fn new_from_zeroed(other: &[u8]) -> Self
pub fn new_from_zeroed(other: &[u8]) -> Self
Copy from contents from another slice, padding with zeros or truncating when needed
pub fn new_from_array(buf: [u8; 36]) -> Self
pub fn as_slice(&self) -> &[u8] ⓘ
pub fn from_slice(buf: &[u8]) -> &Self
pub fn as_array(&self) -> &[u8; 36]
pub fn from_array(buf: &[u8; 36]) -> &Self
pub fn into_array(self) -> [u8; 36]
pub const fn len() -> usize