#[repr(C, packed(4))]pub struct TcFqCodelXstats {
pub type: u32,
pub maxpacket: u32,
pub drop_overlimit: u32,
pub ecn_mark: u32,
pub new_flow_count: u32,
pub new_flows_len: u32,
pub old_flows_len: u32,
pub ce_mark: u32,
pub memory_usage: u32,
pub drop_overmemory: u32,
}Available on crate feature
tc only.Fields
type: u32maxpacket: u32Largest packet we've seen so far
drop_overlimit: u32Number of times max qdisc packet limit was hit
ecn_mark: u32Number of packets we ECN marked instead of being dropped
new_flow_count: u32Number of times packets created a new flow
new_flows_len: u32Count of flows in new list
old_flows_len: u32Count of flows in old list
ce_mark: u32Packets above ce-threshold
memory_usage: u32Memory usage in bytes
drop_overmemory: u32Implementations
Sourceimpl TcFqCodelXstats
impl TcFqCodelXstats
Sourcepub fn new_from_slice(other: &[u8]) -> Option<Self>
pub fn new_from_slice(other: &[u8]) -> Option<Self>
Copy from contents from slice
Sourcepub fn new_from_zeroed(other: &[u8]) -> Self
pub fn new_from_zeroed(other: &[u8]) -> Self
Copy from contents from another slice, padding with zeros or truncating when needed
pub fn new_from_array(buf: [u8; 40]) -> Self
pub fn as_slice(&self) -> &[u8] ⓘ
pub fn from_slice(buf: &[u8]) -> &Self
pub fn as_array(&self) -> &[u8; 40]
pub fn from_array(buf: &[u8; 40]) -> &Self
pub fn into_array(self) -> [u8; 40]
pub const fn len() -> usize