#[repr(C, packed(4))]pub struct TcStats {
pub bytes: u64,
pub packets: u32,
pub drops: u32,
pub overlimits: u32,
pub bps: u32,
pub pps: u32,
pub qlen: u32,
pub backlog: u32,
pub _pad_36: [u8; 4],
}Available on crate feature
tc only.Fields
bytes: u64Number of enqueued bytes
packets: u32Number of enqueued packets
drops: u32Packets dropped because of lack of resources
overlimits: u32Number of throttle events when this flow goes out of allocated bandwidth
bps: u32Current flow byte rate
pps: u32Current flow packet rate
qlen: u32backlog: u32_pad_36: [u8; 4]Implementations
Sourceimpl TcStats
impl TcStats
Sourcepub fn new_from_slice(other: &[u8]) -> Option<Self>
pub fn new_from_slice(other: &[u8]) -> Option<Self>
Copy from contents from slice
Sourcepub fn new_from_zeroed(other: &[u8]) -> Self
pub fn new_from_zeroed(other: &[u8]) -> Self
Copy from contents from another slice, padding with zeros or truncating when needed
pub fn new_from_array(buf: [u8; 40]) -> Self
pub fn as_slice(&self) -> &[u8] ⓘ
pub fn from_slice(buf: &[u8]) -> &Self
pub fn as_array(&self) -> &[u8; 40]
pub fn from_array(buf: &[u8; 40]) -> &Self
pub fn into_array(self) -> [u8; 40]
pub const fn len() -> usize