NetlinkRequest

Trait NetlinkRequest 

pub trait NetlinkRequest {
    type ReplyType<'buf>;

    // Required methods
    fn protocol(&self) -> Protocol;
    fn flags(&self) -> u16;
    fn payload(&self) -> &[u8] ;
    fn decode_reply(buf: &[u8]) -> Self::ReplyType<'_>;

    // Provided method
    fn lookup(
        buf: &[u8],
        offset: usize,
        missing_type: Option<u16>,
    ) -> (Vec<(&'static str, usize)>, Option<&'static str>) { ... }
}
A trait describing how to handle a particular request. It designed to be used by a netlink socket implementation.

Required Associated Types

type ReplyType<'buf>

Required Methods

fn protocol(&self) -> Protocol

Netlink protocol to use

fn flags(&self) -> u16

Additional flags specified in the message header

fn payload(&self) -> &[u8]

Encoded payload of the message (without message header)

fn decode_reply(buf: &[u8]) -> Self::ReplyType<'_>

Provided Methods

fn lookup( buf: &[u8], offset: usize, missing_type: Option<u16>, ) -> (Vec<(&'static str, usize)>, Option<&'static str>)

Lookup an attribute and it’s parents in the request payload by offset

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl NetlinkRequest for OpAcceptDo<'_>

Available on crate feature handshake only.
Source

impl NetlinkRequest for OpAddAddrDo<'_>

Available on crate feature mptcp_pm only.
Source

impl NetlinkRequest for OpAddDo<'_>

Available on crate feature fou only.
Source

type ReplyType<'buf> = IterableFou<'buf>

Source

impl NetlinkRequest for OpAnnounceDo<'_>

Available on crate feature mptcp_pm only.
Source

type ReplyType<'buf> = IterableAttr<'buf>

Source

impl NetlinkRequest for OpBatchBeginDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpBatchEndDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpBindRxDo<'_>

Available on crate feature netdev only.
Source

impl NetlinkRequest for OpBindTxDo<'_>

Available on crate feature netdev only.
Source

impl NetlinkRequest for OpCableTestActDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpCableTestTdrActDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for netlink_bindings::nfsd::OpCacheFlushDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for netlink_bindings::sunrpc::OpCacheFlushDo<'_>

Available on crate feature sunrpc only.
Source

impl NetlinkRequest for OpCapGetDo<'_>

Available on crate feature net-shaper only.
Source

type ReplyType<'buf> = IterableCaps<'buf>

Source

impl NetlinkRequest for OpCapGetDump<'_>

Available on crate feature net-shaper only.
Source

type ReplyType<'buf> = IterableCaps<'buf>

Source

impl NetlinkRequest for OpChannelsGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpChannelsGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpChannelsSetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpClearErrorCounterDo<'_>

Available on crate feature drm-ras only.
Source

impl NetlinkRequest for OpCoalesceGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpCoalesceGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpCoalesceSetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpDebugGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableDebug<'buf>

Source

impl NetlinkRequest for OpDebugGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableDebug<'buf>

Source

impl NetlinkRequest for OpDebugSetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableDebug<'buf>

Source

impl NetlinkRequest for OpDelAddrDo<'_>

Available on crate feature mptcp_pm only.
Source

impl NetlinkRequest for netlink_bindings::fou::OpDelDo<'_>

Available on crate feature fou only.
Source

type ReplyType<'buf> = IterableFou<'buf>

Source

impl NetlinkRequest for netlink_bindings::ovs_datapath::OpDelDo<'_>

Available on crate feature ovs_datapath only.
Source

impl NetlinkRequest for netlink_bindings::ovs_vport::OpDelDo<'_>

Available on crate feature ovs_vport only.
Source

impl NetlinkRequest for netlink_bindings::tcp_metrics::OpDelDo<'_>

Available on crate feature tcp_metrics only.
Source

impl NetlinkRequest for OpDeladdrDo<'_>

Available on crate feature rt-addr only.
Source

impl NetlinkRequest for netlink_bindings::nftables::OpDelchainDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for netlink_bindings::tc::OpDelchainDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpDeleteDo<'_>

Available on crate feature net-shaper only.
Source

impl NetlinkRequest for OpDelflowtableDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDellinkDo<'_>

Available on crate feature rt-link only.
Source

impl NetlinkRequest for OpDelneighDo<'_>

Available on crate feature rt-neigh only.
Source

impl NetlinkRequest for OpDelobjDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDelqdiscDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpDelrouteDo<'_>

Available on crate feature rt-route only.
Source

impl NetlinkRequest for netlink_bindings::nftables::OpDelruleDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for netlink_bindings::rt_rule::OpDelruleDo<'_>

Available on crate feature rt-rule only.
Source

impl NetlinkRequest for OpDelsetDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDelsetelemDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDeltableDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDeltclassDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpDeltfilterDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpDestroychainDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDestroyflowtableDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDestroyobjDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDestroyruleDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDestroysetDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDestroysetelemDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDestroytableDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpDevAssocDo<'_>

Available on crate feature psp only.
Source

type ReplyType<'buf> = IterableDev<'buf>

Source

impl NetlinkRequest for OpDevDisassocDo<'_>

Available on crate feature psp only.
Source

type ReplyType<'buf> = IterableDev<'buf>

Source

impl NetlinkRequest for netlink_bindings::netdev::OpDevGetDo<'_>

Available on crate feature netdev only.
Source

type ReplyType<'buf> = IterableDev<'buf>

Source

impl NetlinkRequest for netlink_bindings::psp::OpDevGetDo<'_>

Available on crate feature psp only.
Source

type ReplyType<'buf> = IterableDev<'buf>

Source

impl NetlinkRequest for netlink_bindings::netdev::OpDevGetDump<'_>

Available on crate feature netdev only.
Source

type ReplyType<'buf> = IterableDev<'buf>

Source

impl NetlinkRequest for netlink_bindings::psp::OpDevGetDump<'_>

Available on crate feature psp only.
Source

type ReplyType<'buf> = IterableDev<'buf>

Source

impl NetlinkRequest for OpDevSetDo<'_>

Available on crate feature psp only.
Source

type ReplyType<'buf> = IterableDev<'buf>

Source

impl NetlinkRequest for OpDeviceGetDo<'_>

Available on crate feature dpll only.
Source

type ReplyType<'buf> = IterableDpll<'buf>

Source

impl NetlinkRequest for OpDeviceGetDump<'_>

Available on crate feature dpll only.
Source

type ReplyType<'buf> = IterableDpll<'buf>

Source

impl NetlinkRequest for OpDeviceIdGetDo<'_>

Available on crate feature dpll only.
Source

type ReplyType<'buf> = IterableDpll<'buf>

Source

impl NetlinkRequest for OpDeviceSetDo<'_>

Available on crate feature dpll only.
Source

type ReplyType<'buf> = IterableDpll<'buf>

Source

impl NetlinkRequest for OpDo<'_>

Available on crate feature nl80211 only.
Source

impl NetlinkRequest for OpDoneDo<'_>

Available on crate feature handshake only.
Source

type ReplyType<'buf> = IterableDone<'buf>

Source

impl NetlinkRequest for OpDpipeEntriesGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpDpipeHeadersGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpDpipeTableCountersSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpDpipeTableGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpDump<'_>

Available on crate feature nl80211 only.
Source

impl NetlinkRequest for OpEeeGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableEee<'buf>

Source

impl NetlinkRequest for OpEeeGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableEee<'buf>

Source

impl NetlinkRequest for OpEeeSetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableEee<'buf>

Source

impl NetlinkRequest for OpEswitchGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpEswitchSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpExecuteDo<'_>

Available on crate feature ovs_packet only.
Source

impl NetlinkRequest for OpExpkeyGetReqsDump<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpExpkeySetReqsDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpFeaturesGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpFeaturesGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpFeaturesSetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpFecGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableFec<'buf>

Source

impl NetlinkRequest for OpFecGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableFec<'buf>

Source

impl NetlinkRequest for OpFecSetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableFec<'buf>

Source

impl NetlinkRequest for OpFlashUpdateDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpFlushAddrsDo<'_>

Available on crate feature mptcp_pm only.
Source

impl NetlinkRequest for OpGetAddrDo<'_>

Available on crate feature mptcp_pm only.
Source

type ReplyType<'buf> = IterableAttr<'buf>

Source

impl NetlinkRequest for OpGetAddrDump<'_>

Available on crate feature mptcp_pm only.
Source

type ReplyType<'buf> = IterableAttr<'buf>

Source

impl NetlinkRequest for OpGetDeviceDump<'_>

Available on crate feature wireguard only.
Source

impl NetlinkRequest for netlink_bindings::conntrack::OpGetDo<'_>

Available on crate feature conntrack only.
Source

impl NetlinkRequest for netlink_bindings::devlink::OpGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for netlink_bindings::fou::OpGetDo<'_>

Available on crate feature fou only.
Source

type ReplyType<'buf> = IterableFou<'buf>

Source

impl NetlinkRequest for netlink_bindings::net_shaper::OpGetDo<'_>

Available on crate feature net-shaper only.
Source

impl NetlinkRequest for netlink_bindings::ovs_datapath::OpGetDo<'_>

Available on crate feature ovs_datapath only.
Source

impl NetlinkRequest for netlink_bindings::ovs_flow::OpGetDo<'_>

Available on crate feature ovs_flow only.
Source

impl NetlinkRequest for netlink_bindings::ovs_vport::OpGetDo<'_>

Available on crate feature ovs_vport only.
Source

impl NetlinkRequest for netlink_bindings::tcp_metrics::OpGetDo<'_>

Available on crate feature tcp_metrics only.
Source

impl NetlinkRequest for netlink_bindings::conntrack::OpGetDump<'_>

Available on crate feature conntrack only.
Source

impl NetlinkRequest for netlink_bindings::devlink::OpGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for netlink_bindings::fou::OpGetDump<'_>

Available on crate feature fou only.
Source

type ReplyType<'buf> = IterableFou<'buf>

Source

impl NetlinkRequest for netlink_bindings::net_shaper::OpGetDump<'_>

Available on crate feature net-shaper only.
Source

impl NetlinkRequest for netlink_bindings::ovs_datapath::OpGetDump<'_>

Available on crate feature ovs_datapath only.
Source

impl NetlinkRequest for netlink_bindings::ovs_flow::OpGetDump<'_>

Available on crate feature ovs_flow only.
Source

impl NetlinkRequest for netlink_bindings::ovs_vport::OpGetDump<'_>

Available on crate feature ovs_vport only.
Source

impl NetlinkRequest for netlink_bindings::tcp_metrics::OpGetDump<'_>

Available on crate feature tcp_metrics only.
Source

impl NetlinkRequest for OpGetErrorCounterDo<'_>

Available on crate feature drm-ras only.
Source

impl NetlinkRequest for OpGetErrorCounterDump<'_>

Available on crate feature drm-ras only.
Source

impl NetlinkRequest for OpGetInterfaceDo<'_>

Available on crate feature nl80211 only.
Source

impl NetlinkRequest for OpGetInterfaceDump<'_>

Available on crate feature nl80211 only.
Source

impl NetlinkRequest for OpGetLimitsDo<'_>

Available on crate feature mptcp_pm only.
Source

type ReplyType<'buf> = IterableAttr<'buf>

Source

impl NetlinkRequest for OpGetPerfDomainsDo<'_>

Available on crate feature dev-energymodel only.
Source

impl NetlinkRequest for OpGetPerfDomainsDump<'_>

Available on crate feature dev-energymodel only.
Source

impl NetlinkRequest for OpGetPerfTableDo<'_>

Available on crate feature dev-energymodel only.
Source

impl NetlinkRequest for OpGetProtocolFeaturesDo<'_>

Available on crate feature nl80211 only.
Source

impl NetlinkRequest for OpGetStatsDo<'_>

Available on crate feature psp only.
Source

type ReplyType<'buf> = IterableStats<'buf>

Source

impl NetlinkRequest for netlink_bindings::conntrack::OpGetStatsDump<'_>

Available on crate feature conntrack only.
Source

impl NetlinkRequest for netlink_bindings::psp::OpGetStatsDump<'_>

Available on crate feature psp only.
Source

type ReplyType<'buf> = IterableStats<'buf>

Source

impl NetlinkRequest for OpGetWiphyDo<'_>

Available on crate feature nl80211 only.
Source

impl NetlinkRequest for OpGetWiphyDump<'_>

Available on crate feature nl80211 only.
Source

impl NetlinkRequest for OpGetaddrDump<'_>

Available on crate feature rt-addr only.
Source

impl NetlinkRequest for netlink_bindings::nftables::OpGetchainDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for netlink_bindings::tc::OpGetchainDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpGetchainDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetcompatDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetcompatDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetfamilyDo<'_>

Available on crate feature nlctrl only.
Source

impl NetlinkRequest for OpGetfamilyDump<'_>

Available on crate feature nlctrl only.
Source

impl NetlinkRequest for OpGetflowtableDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetflowtableDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetgenDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetgenDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetlinkDo<'_>

Available on crate feature rt-link only.
Source

impl NetlinkRequest for OpGetlinkDump<'_>

Available on crate feature rt-link only.
Source

impl NetlinkRequest for OpGetmulticastDo<'_>

Available on crate feature rt-addr only.
Source

impl NetlinkRequest for OpGetmulticastDump<'_>

Available on crate feature rt-addr only.
Source

impl NetlinkRequest for OpGetneighDo<'_>

Available on crate feature rt-neigh only.
Source

impl NetlinkRequest for OpGetneighDump<'_>

Available on crate feature rt-neigh only.
Source

impl NetlinkRequest for OpGetneightblDump<'_>

Available on crate feature rt-neigh only.
Source

impl NetlinkRequest for OpGetobjDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetobjDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetpolicyDump<'_>

Available on crate feature nlctrl only.
Source

impl NetlinkRequest for OpGetqdiscDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpGetqdiscDump<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpGetrouteDo<'_>

Available on crate feature rt-route only.
Source

impl NetlinkRequest for OpGetrouteDump<'_>

Available on crate feature rt-route only.
Source

impl NetlinkRequest for OpGetruleDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for netlink_bindings::nftables::OpGetruleDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for netlink_bindings::rt_rule::OpGetruleDump<'_>

Available on crate feature rt-rule only.
Source

impl NetlinkRequest for OpGetruleResetDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetruleResetDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetsetDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetsetDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetsetelemDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetsetelemDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetsetelemResetDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetsetelemResetDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGetstatsDo<'_>

Available on crate feature rt-link only.
Source

impl NetlinkRequest for OpGetstatsDump<'_>

Available on crate feature rt-link only.
Source

impl NetlinkRequest for OpGettableDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGettableDump<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpGettclassDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpGettfilterDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpGettfilterDump<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpGroupDo<'_>

Available on crate feature net-shaper only.
Source

impl NetlinkRequest for OpHealthReporterDiagnoseDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpHealthReporterDumpClearDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpHealthReporterDumpGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpHealthReporterGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpHealthReporterGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpHealthReporterRecoverDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpHealthReporterSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpHealthReporterTestDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpInfoGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpInfoGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpIpMapGetReqsDump<'_>

Available on crate feature sunrpc only.
Source

impl NetlinkRequest for OpIpMapSetReqsDo<'_>

Available on crate feature sunrpc only.
Source

impl NetlinkRequest for OpKeyDelDo<'_>

Available on crate feature ovpn only.
Source

impl NetlinkRequest for OpKeyGetDo<'_>

Available on crate feature ovpn only.
Source

impl NetlinkRequest for OpKeyNewDo<'_>

Available on crate feature ovpn only.
Source

type ReplyType<'buf> = IterableOvpn<'buf>

Source

impl NetlinkRequest for OpKeyRotateDo<'_>

Available on crate feature psp only.
Source

type ReplyType<'buf> = IterableDev<'buf>

Source

impl NetlinkRequest for OpKeySwapDo<'_>

Available on crate feature ovpn only.
Source

impl NetlinkRequest for OpLinecardGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpLinecardGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpLinecardSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpLinkinfoGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpLinkinfoGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpLinkinfoSetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpLinkmodesGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpLinkmodesGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpLinkmodesSetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpLinkstateGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpLinkstateGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpListNodesDump<'_>

Available on crate feature drm-ras only.
Source

impl NetlinkRequest for OpListenerGetDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpListenerSetDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpMmGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableMm<'buf>

Source

impl NetlinkRequest for OpMmGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableMm<'buf>

Source

impl NetlinkRequest for OpMmSetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableMm<'buf>

Source

impl NetlinkRequest for OpModuleEepromGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpModuleEepromGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpModuleFwFlashActDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpModuleGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpModuleGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpModuleSetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpMseGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableMse<'buf>

Source

impl NetlinkRequest for OpMseGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableMse<'buf>

Source

impl NetlinkRequest for OpNapiGetDo<'_>

Available on crate feature netdev only.
Source

type ReplyType<'buf> = IterableNapi<'buf>

Source

impl NetlinkRequest for OpNapiGetDump<'_>

Available on crate feature netdev only.
Source

type ReplyType<'buf> = IterableNapi<'buf>

Source

impl NetlinkRequest for OpNapiSetDo<'_>

Available on crate feature netdev only.
Source

type ReplyType<'buf> = IterableNapi<'buf>

Source

impl NetlinkRequest for netlink_bindings::ovs_datapath::OpNewDo<'_>

Available on crate feature ovs_datapath only.
Source

impl NetlinkRequest for netlink_bindings::ovs_flow::OpNewDo<'_>

Available on crate feature ovs_flow only.
Source

impl NetlinkRequest for netlink_bindings::ovs_vport::OpNewDo<'_>

Available on crate feature ovs_vport only.
Source

impl NetlinkRequest for OpNewaddrDo<'_>

Available on crate feature rt-addr only.
Source

impl NetlinkRequest for netlink_bindings::nftables::OpNewchainDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for netlink_bindings::tc::OpNewchainDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpNewflowtableDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpNewlinkDo<'_>

Available on crate feature rt-link only.
Source

impl NetlinkRequest for OpNewneighDo<'_>

Available on crate feature rt-neigh only.
Source

impl NetlinkRequest for OpNewobjDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpNewqdiscDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpNewrouteDo<'_>

Available on crate feature rt-route only.
Source

impl NetlinkRequest for netlink_bindings::nftables::OpNewruleDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for netlink_bindings::rt_rule::OpNewruleDo<'_>

Available on crate feature rt-rule only.
Source

impl NetlinkRequest for OpNewsetDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpNewsetelemDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpNewtableDo<'_>

Available on crate feature nftables only.
Source

impl NetlinkRequest for OpNewtclassDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpNewtfilterDo<'_>

Available on crate feature tc only.
Source

type ReplyType<'buf> = (Tcmsg, IterableAttrs<'buf>)

Source

impl NetlinkRequest for OpNoopDo<'_>

Available on crate feature team only.
Source

type ReplyType<'buf> = IterableTeam<'buf>

Source

impl NetlinkRequest for OpNotifyFilterSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpOptionsGetDo<'_>

Available on crate feature team only.
Source

type ReplyType<'buf> = IterableTeam<'buf>

Source

impl NetlinkRequest for OpOptionsSetDo<'_>

Available on crate feature team only.
Source

type ReplyType<'buf> = IterableTeam<'buf>

Source

impl NetlinkRequest for OpPagePoolGetDo<'_>

Available on crate feature netdev only.
Source

impl NetlinkRequest for OpPagePoolGetDump<'_>

Available on crate feature netdev only.
Source

impl NetlinkRequest for OpPagePoolStatsGetDo<'_>

Available on crate feature netdev only.
Source

impl NetlinkRequest for OpPagePoolStatsGetDump<'_>

Available on crate feature netdev only.
Source

impl NetlinkRequest for OpParamGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpParamGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpParamSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPauseGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePause<'buf>

Source

impl NetlinkRequest for OpPauseGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePause<'buf>

Source

impl NetlinkRequest for OpPauseSetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePause<'buf>

Source

impl NetlinkRequest for OpPeerDelDo<'_>

Available on crate feature ovpn only.
Source

impl NetlinkRequest for OpPeerGetDo<'_>

Available on crate feature ovpn only.
Source

type ReplyType<'buf> = IterableOvpn<'buf>

Source

impl NetlinkRequest for OpPeerGetDump<'_>

Available on crate feature ovpn only.
Source

type ReplyType<'buf> = IterableOvpn<'buf>

Source

impl NetlinkRequest for OpPeerNewDo<'_>

Available on crate feature ovpn only.
Source

impl NetlinkRequest for OpPeerSetDo<'_>

Available on crate feature ovpn only.
Source

impl NetlinkRequest for OpPhcVclocksGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpPhcVclocksGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpPhyGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePhy<'buf>

Source

impl NetlinkRequest for OpPhyGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePhy<'buf>

Source

impl NetlinkRequest for OpPinGetDo<'_>

Available on crate feature dpll only.
Source

type ReplyType<'buf> = IterablePin<'buf>

Source

impl NetlinkRequest for OpPinGetDump<'_>

Available on crate feature dpll only.
Source

type ReplyType<'buf> = IterablePin<'buf>

Source

impl NetlinkRequest for OpPinIdGetDo<'_>

Available on crate feature dpll only.
Source

type ReplyType<'buf> = IterablePin<'buf>

Source

impl NetlinkRequest for OpPinSetDo<'_>

Available on crate feature dpll only.
Source

type ReplyType<'buf> = IterablePin<'buf>

Source

impl NetlinkRequest for OpPlcaGetCfgDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePlca<'buf>

Source

impl NetlinkRequest for OpPlcaGetCfgDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePlca<'buf>

Source

impl NetlinkRequest for OpPlcaGetStatusDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePlca<'buf>

Source

impl NetlinkRequest for OpPlcaGetStatusDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePlca<'buf>

Source

impl NetlinkRequest for OpPlcaSetCfgDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePlca<'buf>

Source

impl NetlinkRequest for OpPoolModeGetDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpPoolModeSetDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpPortDelDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPortGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPortGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPortListGetDo<'_>

Available on crate feature team only.
Source

type ReplyType<'buf> = IterableTeam<'buf>

Source

impl NetlinkRequest for OpPortNewDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPortParamGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPortParamGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPortParamSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPortSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPortSplitDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPortUnsplitDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpPrivflagsGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpPrivflagsGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpPrivflagsSetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpPseGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePse<'buf>

Source

impl NetlinkRequest for OpPseGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePse<'buf>

Source

impl NetlinkRequest for OpPseSetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterablePse<'buf>

Source

impl NetlinkRequest for OpQstatsGetDump<'_>

Available on crate feature netdev only.
Source

impl NetlinkRequest for OpQueueCreateDo<'_>

Available on crate feature netdev only.
Source

type ReplyType<'buf> = IterableQueue<'buf>

Source

impl NetlinkRequest for OpQueueGetDo<'_>

Available on crate feature netdev only.
Source

type ReplyType<'buf> = IterableQueue<'buf>

Source

impl NetlinkRequest for OpQueueGetDump<'_>

Available on crate feature netdev only.
Source

type ReplyType<'buf> = IterableQueue<'buf>

Source

impl NetlinkRequest for OpRateDelDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRateGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRateGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRateNewDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRateSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRegionDelDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRegionGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRegionGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRegionNewDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRegionReadDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpReloadDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRemoveDo<'_>

Available on crate feature mptcp_pm only.
Source

type ReplyType<'buf> = IterableAttr<'buf>

Source

impl NetlinkRequest for OpResourceDumpDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpResourceDumpDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpResourceSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpRingsGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableRings<'buf>

Source

impl NetlinkRequest for OpRingsGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableRings<'buf>

Source

impl NetlinkRequest for OpRingsSetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableRings<'buf>

Source

impl NetlinkRequest for OpRpcStatusGetDump<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpRssCreateActDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableRss<'buf>

Source

impl NetlinkRequest for OpRssDeleteActDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableRss<'buf>

Source

impl NetlinkRequest for OpRssGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableRss<'buf>

Source

impl NetlinkRequest for OpRssGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableRss<'buf>

Source

impl NetlinkRequest for OpRssSetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableRss<'buf>

Source

impl NetlinkRequest for OpRxAssocDo<'_>

Available on crate feature psp only.
Source

type ReplyType<'buf> = IterableAssoc<'buf>

Source

impl NetlinkRequest for OpSbGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbOccMaxClearDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbOccSnapshotDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbPoolGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbPoolGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbPoolSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbPortPoolGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbPortPoolGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbPortPoolSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbTcPoolBindGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbTcPoolBindGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSbTcPoolBindSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSelftestsGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSelftestsGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpSelftestsRunDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpServerGetDo<'_>

Available on crate feature lockd only.
Source

impl NetlinkRequest for OpServerSetDo<'_>

Available on crate feature lockd only.
Source

impl NetlinkRequest for OpSetDeviceDo<'_>

Available on crate feature wireguard only.
Source

impl NetlinkRequest for OpSetDo<'_>

Available on crate feature net-shaper only.
Source

impl NetlinkRequest for OpSetFlagsDo<'_>

Available on crate feature mptcp_pm only.
Source

type ReplyType<'buf> = IterableAttr<'buf>

Source

impl NetlinkRequest for OpSetLimitsDo<'_>

Available on crate feature mptcp_pm only.
Source

type ReplyType<'buf> = IterableAttr<'buf>

Source

impl NetlinkRequest for OpSetlinkDo<'_>

Available on crate feature rt-link only.
Source

impl NetlinkRequest for OpSetneightblDo<'_>

Available on crate feature rt-neigh only.
Source

impl NetlinkRequest for OpStatsGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableStats<'buf>

Source

impl NetlinkRequest for OpStatsGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableStats<'buf>

Source

impl NetlinkRequest for OpStrsetGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpStrsetGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpSubflowCreateDo<'_>

Available on crate feature mptcp_pm only.
Source

type ReplyType<'buf> = IterableAttr<'buf>

Source

impl NetlinkRequest for OpSubflowDestroyDo<'_>

Available on crate feature mptcp_pm only.
Source

type ReplyType<'buf> = IterableAttr<'buf>

Source

impl NetlinkRequest for OpSvcExportGetReqsDump<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpSvcExportSetReqsDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpTcpDiagDump<'_>

Available on crate feature inet-diag only.
Source

impl NetlinkRequest for OpThreadsGetDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpThreadsSetDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpTrapGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpTrapGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpTrapGroupGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpTrapGroupGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpTrapGroupSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpTrapPolicerGetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpTrapPolicerGetDump<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpTrapPolicerSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpTrapSetDo<'_>

Available on crate feature devlink only.
Source

impl NetlinkRequest for OpTsconfigGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpTsconfigGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpTsconfigSetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpTsinfoGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpTsinfoGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpTunnelInfoGetDo<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpTunnelInfoGetDump<'_>

Available on crate feature ethtool only.
Source

impl NetlinkRequest for OpTxAssocDo<'_>

Available on crate feature psp only.
Source

type ReplyType<'buf> = IterableAssoc<'buf>

Source

impl NetlinkRequest for OpUdpDiagDump<'_>

Available on crate feature inet-diag only.
Source

impl NetlinkRequest for OpUnixDiagDump<'_>

Available on crate feature unix-diag only.
Source

impl NetlinkRequest for OpUnixGidGetReqsDump<'_>

Available on crate feature sunrpc only.
Source

impl NetlinkRequest for OpUnixGidSetReqsDo<'_>

Available on crate feature sunrpc only.
Source

impl NetlinkRequest for OpUnlockExportDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpUnlockFilesystemDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpUnlockIpDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpVersionGetDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpVersionSetDo<'_>

Available on crate feature nfsd only.
Source

impl NetlinkRequest for OpWolGetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableWol<'buf>

Source

impl NetlinkRequest for OpWolGetDump<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableWol<'buf>

Source

impl NetlinkRequest for OpWolSetDo<'_>

Available on crate feature ethtool only.
Source

type ReplyType<'buf> = IterableWol<'buf>