pub struct IterableWgpeer<'a> { /* private fields */ }Available on crate feature
wireguard only.Implementations
Sourceimpl<'a> IterableWgpeer<'a>
impl<'a> IterableWgpeer<'a>
pub fn get_public_key(&self) -> Result<&'a [u8], ErrorContext>
Set as all zeros to remove.
Sourcepub fn get_flags(&self) -> Result<u32, ErrorContext>
pub fn get_flags(&self) -> Result<u32, ErrorContext>
0 and/or WGPEER_F_REMOVE_ME if the specified peer should not exist
at the end of the operation, rather than added/updated and/or
WGPEER_F_REPLACE_ALLOWEDIPS if all current allowed IPs of this peer
should be removed prior to adding the list below and/or
WGPEER_F_UPDATE_ONLY if the peer should only be set if it already
exists.
Associated type: WgpeerFlags (enum)
Sourcepub fn get_endpoint(&self) -> Result<SocketAddr, ErrorContext>
pub fn get_endpoint(&self) -> Result<SocketAddr, ErrorContext>
struct sockaddr_in or struct sockaddr_in6
Sourcepub fn get_persistent_keepalive_interval(&self) -> Result<u16, ErrorContext>
pub fn get_persistent_keepalive_interval(&self) -> Result<u16, ErrorContext>
Set as 0 to disable.
pub fn get_last_handshake_time(&self) -> Result<KernelTimespec, ErrorContext>
pub fn get_rx_bytes(&self) -> Result<u64, ErrorContext>
pub fn get_tx_bytes(&self) -> Result<u64, ErrorContext>
Sourcepub fn get_allowedips(
&self,
) -> Result<ArrayIterable<IterableArrayWgallowedip<'a>, IterableWgallowedip<'a>>, ErrorContext>
pub fn get_allowedips( &self, ) -> Result<ArrayIterable<IterableArrayWgallowedip<'a>, IterableWgallowedip<'a>>, ErrorContext>
The index/type parameter is unused on SET_DEVICE operations and is
zero on GET_DEVICE operations.
Sourcepub fn get_protocol_version(&self) -> Result<u32, ErrorContext>
pub fn get_protocol_version(&self) -> Result<u32, ErrorContext>
Should not be set or used at all by most users of this API, as the most
recent protocol will be used when this is unset. Otherwise, must be set
to 1.