pub struct PushPin<Prev: Rec> { /* private fields */ }dpll only.Implementations
Sourceimpl<Prev: Rec> PushPin<Prev>
impl<Prev: Rec> PushPin<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
pub fn push_id(self, value: u32) -> Self
pub fn push_parent_id(self, value: u32) -> Self
pub fn push_module_name(self, value: &CStr) -> Self
pub fn push_module_name_bytes(self, value: &[u8]) -> Self
pub fn push_pad(self, value: &[u8]) -> Self
pub fn push_clock_id(self, value: u64) -> Self
pub fn push_board_label(self, value: &CStr) -> Self
pub fn push_board_label_bytes(self, value: &[u8]) -> Self
pub fn push_panel_label(self, value: &CStr) -> Self
pub fn push_panel_label_bytes(self, value: &[u8]) -> Self
pub fn push_package_label(self, value: &CStr) -> Self
pub fn push_package_label_bytes(self, value: &[u8]) -> Self
Sourcepub fn push_direction(self, value: u32) -> Self
pub fn push_direction(self, value: u32) -> Self
Associated type: PinDirection (enum)
pub fn push_frequency(self, value: u64) -> Self
Sourcepub fn nested_frequency_supported(self) -> PushFrequencyRange<Self>
pub fn nested_frequency_supported(self) -> PushFrequencyRange<Self>
Attribute may repeat multiple times (treat it as array)
pub fn push_frequency_min(self, value: u64) -> Self
pub fn push_frequency_max(self, value: u64) -> Self
pub fn push_prio(self, value: u32) -> Self
Sourcepub fn push_state(self, value: u32) -> Self
pub fn push_state(self, value: u32) -> Self
Associated type: PinState (enum)
Sourcepub fn push_capabilities(self, value: u32) -> Self
pub fn push_capabilities(self, value: u32) -> Self
Associated type: PinCapabilities (enum)
Sourcepub fn nested_parent_device(self) -> PushPinParentDevice<Self>
pub fn nested_parent_device(self) -> PushPinParentDevice<Self>
Attribute may repeat multiple times (treat it as array)
Sourcepub fn nested_parent_pin(self) -> PushPinParentPin<Self>
pub fn nested_parent_pin(self) -> PushPinParentPin<Self>
Attribute may repeat multiple times (treat it as array)
pub fn push_phase_adjust_min(self, value: i32) -> Self
pub fn push_phase_adjust_max(self, value: i32) -> Self
pub fn push_phase_adjust(self, value: i32) -> Self
pub fn push_phase_offset(self, value: i64) -> Self
Sourcepub fn push_fractional_frequency_offset(self, value: i32) -> Self
pub fn push_fractional_frequency_offset(self, value: i32) -> Self
The FFO (Fractional Frequency Offset) between the RX and TX symbol rate on the media associated with the pin: (rx_frequency-tx_frequency)/rx_frequency Value is in PPM (parts per million). This may be implemented for example for pin of type PIN_TYPE_SYNCE_ETH_PORT.
Sourcepub fn push_esync_frequency(self, value: u64) -> Self
pub fn push_esync_frequency(self, value: u64) -> Self
Frequency of Embedded SYNC signal. If provided, the pin is configured with a SYNC signal embedded into its base clock frequency.
Sourcepub fn nested_esync_frequency_supported(self) -> PushFrequencyRange<Self>
pub fn nested_esync_frequency_supported(self) -> PushFrequencyRange<Self>
If provided a pin is capable of embedding a SYNC signal (within given range) into its base frequency signal.
Attribute may repeat multiple times (treat it as array)
Sourcepub fn push_esync_pulse(self, value: u32) -> Self
pub fn push_esync_pulse(self, value: u32) -> Self
A ratio of high to low state of a SYNC signal pulse embedded into base clock frequency. Value is in percents.
Sourcepub fn nested_reference_sync(self) -> PushReferenceSync<Self>
pub fn nested_reference_sync(self) -> PushReferenceSync<Self>
Capable pin provides list of pins that can be bound to create a reference-sync pin pair.
Attribute may repeat multiple times (treat it as array)
Sourcepub fn push_phase_adjust_gran(self, value: u32) -> Self
pub fn push_phase_adjust_gran(self, value: u32) -> Self
Granularity of phase adjustment, in picoseconds. The value of phase adjustment must be a multiple of this granularity.
Sourcepub fn push_fractional_frequency_offset_ppt(self, value: i32) -> Self
pub fn push_fractional_frequency_offset_ppt(self, value: i32) -> Self
The FFO (Fractional Frequency Offset) of the pin with respect to the nominal frequency. Value = (frequency_measured - frequency_nominal) / frequency_nominal Value is in PPT (parts per trillion, 10^-12). Note: This attribute provides higher resolution than the standard fractional-frequency-offset (which is in PPM).