PauseStat

Enum PauseStat 

pub enum PauseStat<'a> {
    Pad(&'a [u8]),
    TxFrames(u64),
    RxFrames(u64),
    TxPauseStormEvents(u64),
}
Available on crate feature ethtool only.

Variants



Pad(&'a [u8])



TxFrames(u64)



RxFrames(u64)



TxPauseStormEvents(u64)

TX pause storm event count. Increments each time device detects that its pause assertion condition has been true for too long for normal operation. As a result, the device has temporarily disabled its own Pause TX function to protect the network from itself. This counter should never increment under normal overload conditions; it indicates catastrophic failure like an OS crash. The rate of incrementing is implementation specific.

Implementations

Source

impl PauseStat<'_>

pub fn new<'a>(buf: &'a [u8]) -> IterablePauseStat<'a>