PseEvent

Enum PseEvent 

pub enum PseEvent {
    PseEventOverCurrent = 1,
    PseEventOverTemp = 2,
    C33PseEventDetection = 4,
    C33PseEventClassification = 8,
    C33PseEventDisconnection = 16,
    PseEventOverBudget = 32,
    PseEventSwPwControlError = 64,
}
Available on crate feature ethtool only.
PSE event list for the PSE controller Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)

Variants



PseEventOverCurrent = 1

PSE output current is too high



PseEventOverTemp = 2

PSE in over temperature state



C33PseEventDetection = 4

detection process occur on the PSE. IEEE 802.3-2022 33.2.5 and 145.2.6 PSE detection of PDs. IEEE 802.3-202 30.9.1.1.5 aPSEPowerDetectionStatus



C33PseEventClassification = 8

classification process occur on the PSE. IEEE 802.3-2022 33.2.6 and 145.2.8 classification of PDs mutual identification. IEEE 802.3-2022 30.9.1.1.8 aPSEPowerClassification.



C33PseEventDisconnection = 16

PD has been disconnected on the PSE. IEEE 802.3-2022 33.3.8 and 145.3.9 PD Maintain Power Signature. IEEE 802.3-2022 33.5.1.2.9 MPS Absent. IEEE 802.3-2022 30.9.1.1.20 aPSEMPSAbsentCounter.



PseEventOverBudget = 32

PSE turned off due to over budget situation



PseEventSwPwControlError = 64

PSE faced an error managing the power control from software

Implementations

Source

impl PseEvent

pub fn from_value(value: u64) -> Option<Self>