pub struct OpGroupDo<'r> { /* private fields */ }net-shaper only.Expand description
Create or update a scheduling group, attaching the specified @leaves shapers under the specified node identified by @handle. The @leaves shapers scope must be @queue and the node shaper scope must be either @node or @netdev. When the node shaper has @node scope, if the @handle @id is not specified, a new shaper of such scope is created, otherwise the specified node must already exist. When updating an existing node shaper, the specified @leaves are added to the existing node; such node will also retain any preexisting leave. The @parent handle for a new node shaper defaults to the parent of all the leaves, provided all the leaves share the same parent. Otherwise @parent handle must be specified. The user can optionally provide shaping attributes for the node shaper. The operation is atomic, on failure no change is applied to the device shaping configuration, otherwise the @node shaper full identifier, comprising @binding and @handle, is provided as the reply.
Flags: admin-perm
Request attributes:
- .nested_handle()
- .push_metric()
- .push_bw_min()
- .push_bw_max()
- .push_burst()
- .push_priority()
- .push_weight()
- .push_ifindex()
- .nested_parent()
- .nested_leaves()
Reply attributes: