PushNetShaper

Struct PushNetShaper 

pub struct PushNetShaper<Prev: Rec> { /* private fields */ }
Available on crate feature net-shaper only.

Implementations

Source

impl<Prev: Rec> PushNetShaper<Prev>

pub fn new(prev: Prev) -> Self

pub fn end_nested(self) -> Prev

pub fn nested_handle(self) -> PushHandle<Self>

Unique identifier for the given shaper inside the owning device.

pub fn push_metric(self, value: u32) -> Self

Metric used by the given shaper for bw-min, bw-max and burst.

Associated type: Metric (enum)

pub fn push_bw_min(self, value: u32) -> Self

Guaranteed bandwidth for the given shaper.

pub fn push_bw_max(self, value: u32) -> Self

Maximum bandwidth for the given shaper or 0 when unlimited.

pub fn push_burst(self, value: u32) -> Self

Maximum burst-size for shaping. Should not be interpreted as a quantum.

pub fn push_priority(self, value: u32) -> Self

Scheduling priority for the given shaper. The priority scheduling is applied to sibling shapers.

pub fn push_weight(self, value: u32) -> Self

Relative weight for round robin scheduling of the given shaper. The scheduling is applied to all sibling shapers with the same priority.

pub fn push_ifindex(self, value: u32) -> Self

Interface index owning the specified shaper.

pub fn nested_parent(self) -> PushHandle<Self>

Identifier for the parent of the affected shaper. Only needed for @group operation.

pub fn nested_leaves(self) -> PushLeafInfo<Self>

Describes a set of leaves shapers for a @group operation.

Attribute may repeat multiple times (treat it as array)