Available on crate feature
netdev only.Expand description
netdev configuration over generic netlink.
Structs
- Iterable
Dev - Iterable
Dmabuf - Iterable
IoUring Provider Info - Iterable
Lease - Iterable
Napi - Iterable
Page Pool - Iterable
Page Pool Info - Iterable
Page Pool Stats - Iterable
Qstats - Iterable
Queue - Iterable
Queue Id - Iterable
XskInfo - Notif
Group - OpBind
RxDo - Bind dmabuf to netdev
- OpBind
TxDo - Bind dmabuf to netdev for TX
- OpDev
AddNotif - Notify attributes:
- OpDev
Change Notif - Notify attributes:
- OpDev
DelNotif - Notify attributes:
- OpDev
GetDo - Get / dump information about a netdev.
- OpDev
GetDump - Get / dump information about a netdev.
- OpNapi
GetDo - Get information about NAPI instances configured on the system.
- OpNapi
GetDump - Get information about NAPI instances configured on the system.
- OpNapi
SetDo - Set configurable NAPI instance settings.
- OpPage
Pool AddNotif - Notify attributes:
- OpPage
Pool Change Notif - Notify attributes:
- OpPage
Pool DelNotif - Notify attributes:
- OpPage
Pool GetDo - Get / dump information about Page Pools. Only Page Pools associated by the driver with a net_device can be listed. ifindex will not be reported if the net_device no longer exists.
- OpPage
Pool GetDump - Get / dump information about Page Pools. Only Page Pools associated by the driver with a net_device can be listed. ifindex will not be reported if the net_device no longer exists.
- OpPage
Pool Stats GetDo - Get page pool statistics.
- OpPage
Pool Stats GetDump - Get page pool statistics.
- OpQstats
GetDump - Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
- OpQueue
Create Do - Create a new queue for the given netdevice. Whether this operation is supported depends on the device and the driver.
- OpQueue
GetDo - Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
- OpQueue
GetDump - Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
- PushDev
- Push
Dmabuf - Push
IoUring Provider Info - Push
Lease - Push
Napi - Push
Page Pool - Push
Page Pool Info - Push
Page Pool Stats - Push
Qstats - Push
Queue - Push
Queue Id - Push
XskInfo - Request
- Request
Info
Enums
- Dev
- Dmabuf
- IoUring
Provider Info - Lease
- Napi
- Napi
Threaded - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- Page
Pool - Page
Pool Info - Page
Pool Stats - Qstats
- Qstats
Scope - Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
- Queue
- QueueId
- Queue
Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- XdpAct
- Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
- XdpRx
Metadata - Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
- XskFlags
- Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
- XskInfo