Module netdev

Module netdev 

Available on crate feature netdev only.
netdev configuration over generic netlink.

Structs

IterableDev
IterableDmabuf
IterableIoUringProviderInfo
IterableNapi
IterablePagePool
IterablePagePoolInfo
IterablePagePoolStats
IterableQstats
IterableQueue
IterableQueueId
IterableXskInfo
NotifGroup
OpBindRxDo
Bind dmabuf to netdev Flags: admin-perm Request attributes:
OpBindTxDo
Bind dmabuf to netdev for TX Request attributes:
OpDevAddNotif
Notify attributes:
OpDevChangeNotif
Notify attributes:
OpDevDelNotif
Notify attributes:
OpDevGetDo
Get / dump information about a netdev. Request attributes:
OpDevGetDump
Get / dump information about a netdev.
OpNapiGetDo
Get information about NAPI instances configured on the system. Request attributes:
OpNapiGetDump
Get information about NAPI instances configured on the system. Request attributes:
OpNapiSetDo
Set configurable NAPI instance settings. Flags: admin-perm Request attributes:
OpPagePoolAddNotif
Notify attributes:
OpPagePoolChangeNotif
Notify attributes:
OpPagePoolDelNotif
Notify attributes:
OpPagePoolGetDo
Get / dump information about Page Pools. Only Page Pools associated by the driver with a net_device can be listed. ifindex will not be reported if the net_device no longer exists.
OpPagePoolGetDump
Get / dump information about Page Pools. Only Page Pools associated by the driver with a net_device can be listed. ifindex will not be reported if the net_device no longer exists.
OpPagePoolStatsGetDo
Get page pool statistics. Request attributes:
OpPagePoolStatsGetDump
Get page pool statistics.
OpQstatsGetDump
Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
OpQueueGetDo
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues). Request attributes:
OpQueueGetDump
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues). Request attributes:
PushDev
PushDmabuf
PushIoUringProviderInfo
PushNapi
PushPagePool
PushPagePoolInfo
PushPagePoolStats
PushQstats
PushQueue
PushQueueId
PushXskInfo
Request
RequestInfo

Enums

Dev
Dmabuf
IoUringProviderInfo
Napi
NapiThreaded
Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
PagePool
PagePoolInfo
PagePoolStats
Qstats
QstatsScope
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
Queue
QueueId
QueueType
Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
XdpAct
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
XdpRxMetadata
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
XskFlags
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
XskInfo

Constants

PROTONAME
PROTONAME_CSTR