Module netdev

Module netdev 

Available on crate feature netdev only.
netdev configuration over generic netlink.

Structs

IterableDev
IterableDmabuf
IterableIoUringProviderInfo
IterableNapi
IterableOpBindRxDoReply
IterableOpBindRxDoRequest
IterableOpBindTxDoReply
IterableOpBindTxDoRequest
IterableOpDevGetDoReply
IterableOpDevGetDoRequest
IterableOpDevGetDumpReply
IterableOpDevGetDumpRequest
IterableOpNapiGetDoReply
IterableOpNapiGetDoRequest
IterableOpNapiGetDumpReply
IterableOpNapiGetDumpRequest
IterableOpNapiSetDoReply
IterableOpNapiSetDoRequest
IterableOpPagePoolGetDoReply
IterableOpPagePoolGetDoRequest
IterableOpPagePoolGetDumpReply
IterableOpPagePoolGetDumpRequest
IterableOpPagePoolStatsGetDoReply
IterableOpPagePoolStatsGetDoRequest
IterableOpPagePoolStatsGetDumpReply
IterableOpPagePoolStatsGetDumpRequest
IterableOpQstatsGetDumpReply
IterableOpQstatsGetDumpRequest
IterableOpQueueGetDoReply
IterableOpQueueGetDoRequest
IterableOpQueueGetDumpReply
IterableOpQueueGetDumpRequest
IterablePagePool
IterablePagePoolInfo
IterablePagePoolStats
IterableQstats
IterableQueue
IterableQueueId
IterableXskInfo
PushDev
PushDmabuf
PushIoUringProviderInfo
PushNapi
PushOpBindRxDoReply
Bind dmabuf to netdev
PushOpBindRxDoRequest
Bind dmabuf to netdev
PushOpBindTxDoReply
Bind dmabuf to netdev for TX
PushOpBindTxDoRequest
Bind dmabuf to netdev for TX
PushOpDevGetDoReply
Get / dump information about a netdev.
PushOpDevGetDoRequest
Get / dump information about a netdev.
PushOpDevGetDumpReply
Get / dump information about a netdev.
PushOpDevGetDumpRequest
Get / dump information about a netdev.
PushOpNapiGetDoReply
Get information about NAPI instances configured on the system.
PushOpNapiGetDoRequest
Get information about NAPI instances configured on the system.
PushOpNapiGetDumpReply
Get information about NAPI instances configured on the system.
PushOpNapiGetDumpRequest
Get information about NAPI instances configured on the system.
PushOpNapiSetDoReply
Set configurable NAPI instance settings.
PushOpNapiSetDoRequest
Set configurable NAPI instance settings.
PushOpPagePoolGetDoReply
Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
PushOpPagePoolGetDoRequest
Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
PushOpPagePoolGetDumpReply
Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
PushOpPagePoolGetDumpRequest
Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
PushOpPagePoolStatsGetDoReply
Get page pool statistics.
PushOpPagePoolStatsGetDoRequest
Get page pool statistics.
PushOpPagePoolStatsGetDumpReply
Get page pool statistics.
PushOpPagePoolStatsGetDumpRequest
Get page pool statistics.
PushOpQstatsGetDumpReply
Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
PushOpQstatsGetDumpRequest
Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
PushOpQueueGetDoReply
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
PushOpQueueGetDoRequest
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
PushOpQueueGetDumpReply
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
PushOpQueueGetDumpRequest
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
PushPagePool
PushPagePoolInfo
PushPagePoolStats
PushQstats
PushQueue
PushQueueId
PushXskInfo
Request
RequestInfo
RequestOpBindRxDoRequest
RequestOpBindTxDoRequest
RequestOpDevGetDoRequest
RequestOpDevGetDumpRequest
RequestOpNapiGetDoRequest
RequestOpNapiGetDumpRequest
RequestOpNapiSetDoRequest
RequestOpPagePoolGetDoRequest
RequestOpPagePoolGetDumpRequest
RequestOpPagePoolStatsGetDoRequest
RequestOpPagePoolStatsGetDumpRequest
RequestOpQstatsGetDumpRequest
RequestOpQueueGetDoRequest
RequestOpQueueGetDumpRequest

Enums

Dev
Dmabuf
IoUringProviderInfo
Napi
NapiThreaded
Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
OpBindRxDoReply
Bind dmabuf to netdev
OpBindRxDoRequest
Bind dmabuf to netdev
OpBindTxDoReply
Bind dmabuf to netdev for TX
OpBindTxDoRequest
Bind dmabuf to netdev for TX
OpDevGetDoReply
Get / dump information about a netdev.
OpDevGetDoRequest
Get / dump information about a netdev.
OpDevGetDumpReply
Get / dump information about a netdev.
OpDevGetDumpRequest
Get / dump information about a netdev.
OpNapiGetDoReply
Get information about NAPI instances configured on the system.
OpNapiGetDoRequest
Get information about NAPI instances configured on the system.
OpNapiGetDumpReply
Get information about NAPI instances configured on the system.
OpNapiGetDumpRequest
Get information about NAPI instances configured on the system.
OpNapiSetDoReply
Set configurable NAPI instance settings.
OpNapiSetDoRequest
Set configurable NAPI instance settings.
OpPagePoolGetDoReply
Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
OpPagePoolGetDoRequest
Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
OpPagePoolGetDumpReply
Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
OpPagePoolGetDumpRequest
Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
OpPagePoolStatsGetDoReply
Get page pool statistics.
OpPagePoolStatsGetDoRequest
Get page pool statistics.
OpPagePoolStatsGetDumpReply
Get page pool statistics.
OpPagePoolStatsGetDumpRequest
Get page pool statistics.
OpQstatsGetDumpReply
Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
OpQstatsGetDumpRequest
Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
OpQueueGetDoReply
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
OpQueueGetDoRequest
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
OpQueueGetDumpReply
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
OpQueueGetDumpRequest
Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
PagePool
PagePoolInfo
PagePoolStats
Qstats
QstatsScope
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
Queue
QueueId
QueueType
Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
XdpAct
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
XdpRxMetadata
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
XskFlags
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
XskInfo

Constants

PROTONAME