Available on crate feature
netdev only.Expand description
netdev configuration over generic netlink.
Structs
- Iterable
Dev - Iterable
Dmabuf - Iterable
IoUring Provider Info - Iterable
Napi - Iterable
OpBind RxDo Reply - Iterable
OpBind RxDo Request - Iterable
OpBind TxDo Reply - Iterable
OpBind TxDo Request - Iterable
OpDev GetDo Reply - Iterable
OpDev GetDo Request - Iterable
OpDev GetDump Reply - Iterable
OpDev GetDump Request - Iterable
OpNapi GetDo Reply - Iterable
OpNapi GetDo Request - Iterable
OpNapi GetDump Reply - Iterable
OpNapi GetDump Request - Iterable
OpNapi SetDo Reply - Iterable
OpNapi SetDo Request - Iterable
OpPage Pool GetDo Reply - Iterable
OpPage Pool GetDo Request - Iterable
OpPage Pool GetDump Reply - Iterable
OpPage Pool GetDump Request - Iterable
OpPage Pool Stats GetDo Reply - Iterable
OpPage Pool Stats GetDo Request - Iterable
OpPage Pool Stats GetDump Reply - Iterable
OpPage Pool Stats GetDump Request - Iterable
OpQstats GetDump Reply - Iterable
OpQstats GetDump Request - Iterable
OpQueue GetDo Reply - Iterable
OpQueue GetDo Request - Iterable
OpQueue GetDump Reply - Iterable
OpQueue GetDump Request - Iterable
Page Pool - Iterable
Page Pool Info - Iterable
Page Pool Stats - Iterable
Qstats - Iterable
Queue - Iterable
Queue Id - Iterable
XskInfo - PushDev
- Push
Dmabuf - Push
IoUring Provider Info - Push
Napi - Push
OpBind RxDo Reply - Bind dmabuf to netdev
- Push
OpBind RxDo Request - Bind dmabuf to netdev
- Push
OpBind TxDo Reply - Bind dmabuf to netdev for TX
- Push
OpBind TxDo Request - Bind dmabuf to netdev for TX
- Push
OpDev GetDo Reply - Get / dump information about a netdev.
- Push
OpDev GetDo Request - Get / dump information about a netdev.
- Push
OpDev GetDump Reply - Get / dump information about a netdev.
- Push
OpDev GetDump Request - Get / dump information about a netdev.
- Push
OpNapi GetDo Reply - Get information about NAPI instances configured on the system.
- Push
OpNapi GetDo Request - Get information about NAPI instances configured on the system.
- Push
OpNapi GetDump Reply - Get information about NAPI instances configured on the system.
- Push
OpNapi GetDump Request - Get information about NAPI instances configured on the system.
- Push
OpNapi SetDo Reply - Set configurable NAPI instance settings.
- Push
OpNapi SetDo Request - Set configurable NAPI instance settings.
- Push
OpPage Pool GetDo Reply - Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
- Push
OpPage Pool GetDo Request - Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
- Push
OpPage Pool GetDump Reply - Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
- Push
OpPage Pool GetDump Request - Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
- Push
OpPage Pool Stats GetDo Reply - Get page pool statistics.
- Push
OpPage Pool Stats GetDo Request - Get page pool statistics.
- Push
OpPage Pool Stats GetDump Reply - Get page pool statistics.
- Push
OpPage Pool Stats GetDump Request - Get page pool statistics.
- Push
OpQstats GetDump Reply - Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
- Push
OpQstats GetDump Request - Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
- Push
OpQueue GetDo Reply - Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
- Push
OpQueue GetDo Request - Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
- Push
OpQueue GetDump Reply - Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
- Push
OpQueue GetDump Request - Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
- Push
Page Pool - Push
Page Pool Info - Push
Page Pool Stats - Push
Qstats - Push
Queue - Push
Queue Id - Push
XskInfo - Request
- Request
Info - Request
OpBind RxDo Request - Request
OpBind TxDo Request - Request
OpDev GetDo Request - Request
OpDev GetDump Request - Request
OpNapi GetDo Request - Request
OpNapi GetDump Request - Request
OpNapi SetDo Request - Request
OpPage Pool GetDo Request - Request
OpPage Pool GetDump Request - Request
OpPage Pool Stats GetDo Request - Request
OpPage Pool Stats GetDump Request - Request
OpQstats GetDump Request - Request
OpQueue GetDo Request - Request
OpQueue GetDump Request
Enums
- Dev
- Dmabuf
- IoUring
Provider Info - Napi
- Napi
Threaded - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- OpBind
RxDo Reply - Bind dmabuf to netdev
- OpBind
RxDo Request - Bind dmabuf to netdev
- OpBind
TxDo Reply - Bind dmabuf to netdev for TX
- OpBind
TxDo Request - Bind dmabuf to netdev for TX
- OpDev
GetDo Reply - Get / dump information about a netdev.
- OpDev
GetDo Request - Get / dump information about a netdev.
- OpDev
GetDump Reply - Get / dump information about a netdev.
- OpDev
GetDump Request - Get / dump information about a netdev.
- OpNapi
GetDo Reply - Get information about NAPI instances configured on the system.
- OpNapi
GetDo Request - Get information about NAPI instances configured on the system.
- OpNapi
GetDump Reply - Get information about NAPI instances configured on the system.
- OpNapi
GetDump Request - Get information about NAPI instances configured on the system.
- OpNapi
SetDo Reply - Set configurable NAPI instance settings.
- OpNapi
SetDo Request - Set configurable NAPI instance settings.
- OpPage
Pool GetDo Reply - Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
- OpPage
Pool GetDo Request - Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
- OpPage
Pool GetDump Reply - Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
- OpPage
Pool GetDump Request - Get / dump information about Page Pools. (Only Page Pools associated with a net_device can be listed.)
- OpPage
Pool Stats GetDo Reply - Get page pool statistics.
- OpPage
Pool Stats GetDo Request - Get page pool statistics.
- OpPage
Pool Stats GetDump Reply - Get page pool statistics.
- OpPage
Pool Stats GetDump Request - Get page pool statistics.
- OpQstats
GetDump Reply - Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
- OpQstats
GetDump Request - Get / dump fine grained statistics. Which statistics are reported depends on the device and the driver, and whether the driver stores software counters per-queue.
- OpQueue
GetDo Reply - Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
- OpQueue
GetDo Request - Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
- OpQueue
GetDump Reply - Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
- OpQueue
GetDump Request - Get queue information from the kernel. Only configured queues will be reported (as opposed to all available hardware queues).
- Page
Pool - Page
Pool Info - Page
Pool Stats - Qstats
- Qstats
Scope - Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
- Queue
- QueueId
- Queue
Type - Enum - defines an integer enumeration, with values for each entry incrementing by 1, (e.g. 0, 1, 2, 3)
- XdpAct
- Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
- XdpRx
Metadata - Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
- XskFlags
- Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)
- XskInfo