Queue

Enum Queue 

pub enum Queue<'a> {
    Id(u32),
    Ifindex(u32),
    Type(u32),
    NapiId(u32),
    Dmabuf(u32),
    IoUring(IterableIoUringProviderInfo<'a>),
    Xsk(IterableXskInfo<'a>),
}
Available on crate feature netdev only.

Variants



Id(u32)

Queue index; most queue types are indexed like a C array, with indexes starting at 0 and ending at queue count - 1. Queue indexes are scoped to an interface and queue type.



Ifindex(u32)

ifindex of the netdevice to which the queue belongs.



Type(u32)

Queue type as rx, tx. Each queue type defines a separate ID space. XDP TX queues allocated in the kernel are not linked to NAPIs and thus not listed. AF_XDP queues will have more information set in the xsk attribute. Associated type: QueueType (enum)



NapiId(u32)

ID of the NAPI instance which services this queue.



Dmabuf(u32)

ID of the dmabuf attached to this queue, if any.



IoUring(IterableIoUringProviderInfo<'a>)

io_uring memory provider information.



Xsk(IterableXskInfo<'a>)

XSK information for this queue, if any.

Implementations

Source

impl Queue<'_>

pub fn new<'a>(buf: &'a [u8]) -> IterableQueue<'a>