XdpRxMetadata

Enum XdpRxMetadata 

pub enum XdpRxMetadata {
    Timestamp = 1,
    Hash = 2,
    VlanTag = 4,
}
Available on crate feature netdev only.
Flags - defines an integer enumeration, with values for each entry occupying a bit, starting from bit 0, (e.g. 1, 2, 4, 8)

Variants



Timestamp = 1

Device is capable of exposing receive HW timestamp via bpf_xdp_metadata_rx_timestamp().



Hash = 2

Device is capable of exposing receive packet hash via bpf_xdp_metadata_rx_hash().



VlanTag = 4

Device is capable of exposing receive packet VLAN tag via bpf_xdp_metadata_rx_vlan_tag().

Implementations

Source

impl XdpRxMetadata

pub fn from_value(value: u64) -> Option<Self>