pub struct IterableQstats<'a> { /* private fields */ }netdev only.Implementations
Sourceimpl<'a> IterableQstats<'a>
impl<'a> IterableQstats<'a>
Sourcepub fn get_ifindex(&self) -> Result<u32, ErrorContext>
pub fn get_ifindex(&self) -> Result<u32, ErrorContext>
ifindex of the netdevice to which stats belong.
Sourcepub fn get_queue_type(&self) -> Result<u32, ErrorContext>
pub fn get_queue_type(&self) -> Result<u32, ErrorContext>
Queue type as rx, tx, for queue-id.
Associated type: QueueType (enum)
Sourcepub fn get_queue_id(&self) -> Result<u32, ErrorContext>
pub fn get_queue_id(&self) -> Result<u32, ErrorContext>
Queue ID, if stats are scoped to a single queue instance.
Sourcepub fn get_scope(&self) -> Result<u32, ErrorContext>
pub fn get_scope(&self) -> Result<u32, ErrorContext>
What object type should be used to iterate over the stats.
Associated type: QstatsScope (enum)
Sourcepub fn get_rx_packets(&self) -> Result<u32, ErrorContext>
pub fn get_rx_packets(&self) -> Result<u32, ErrorContext>
Number of wire packets successfully received and passed to the stack. For drivers supporting XDP, XDP is considered the first layer of the stack, so packets consumed by XDP are still counted here.
Sourcepub fn get_rx_bytes(&self) -> Result<u32, ErrorContext>
pub fn get_rx_bytes(&self) -> Result<u32, ErrorContext>
Successfully received bytes, see `rx-packets`.
Sourcepub fn get_tx_packets(&self) -> Result<u32, ErrorContext>
pub fn get_tx_packets(&self) -> Result<u32, ErrorContext>
Number of wire packets successfully sent. Packet is considered to be successfully sent once it is in device memory (usually this means the device has issued a DMA completion for the packet).
Sourcepub fn get_tx_bytes(&self) -> Result<u32, ErrorContext>
pub fn get_tx_bytes(&self) -> Result<u32, ErrorContext>
Successfully sent bytes, see `tx-packets`.
Sourcepub fn get_rx_alloc_fail(&self) -> Result<u32, ErrorContext>
pub fn get_rx_alloc_fail(&self) -> Result<u32, ErrorContext>
Number of times skb or buffer allocation failed on the Rx datapath. Allocation failure may, or may not result in a packet drop, depending on driver implementation and whether system recovers quickly.
Sourcepub fn get_rx_hw_drops(&self) -> Result<u32, ErrorContext>
pub fn get_rx_hw_drops(&self) -> Result<u32, ErrorContext>
Number of all packets which entered the device, but never left it, including but not limited to: packets dropped due to lack of buffer space, processing errors, explicit or implicit policies and packet filters.
Sourcepub fn get_rx_hw_drop_overruns(&self) -> Result<u32, ErrorContext>
pub fn get_rx_hw_drop_overruns(&self) -> Result<u32, ErrorContext>
Number of packets dropped due to transient lack of resources, such as buffer space, host descriptors etc.
Sourcepub fn get_rx_csum_complete(&self) -> Result<u32, ErrorContext>
pub fn get_rx_csum_complete(&self) -> Result<u32, ErrorContext>
Number of packets that were marked as CHECKSUM_COMPLETE.
Sourcepub fn get_rx_csum_unnecessary(&self) -> Result<u32, ErrorContext>
pub fn get_rx_csum_unnecessary(&self) -> Result<u32, ErrorContext>
Number of packets that were marked as CHECKSUM_UNNECESSARY.
Sourcepub fn get_rx_csum_none(&self) -> Result<u32, ErrorContext>
pub fn get_rx_csum_none(&self) -> Result<u32, ErrorContext>
Number of packets that were not checksummed by device.
Sourcepub fn get_rx_csum_bad(&self) -> Result<u32, ErrorContext>
pub fn get_rx_csum_bad(&self) -> Result<u32, ErrorContext>
Number of packets with bad checksum. The packets are not discarded, but still delivered to the stack.
Sourcepub fn get_rx_hw_gro_packets(&self) -> Result<u32, ErrorContext>
pub fn get_rx_hw_gro_packets(&self) -> Result<u32, ErrorContext>
Number of packets that were coalesced from smaller packets by the device. Counts only packets coalesced with the HW-GRO netdevice feature, LRO-coalesced packets are not counted.
Sourcepub fn get_rx_hw_gro_bytes(&self) -> Result<u32, ErrorContext>
pub fn get_rx_hw_gro_bytes(&self) -> Result<u32, ErrorContext>
See `rx-hw-gro-packets`.
Sourcepub fn get_rx_hw_gro_wire_packets(&self) -> Result<u32, ErrorContext>
pub fn get_rx_hw_gro_wire_packets(&self) -> Result<u32, ErrorContext>
Number of packets that were coalesced to bigger packetss with the HW-GRO netdevice feature. LRO-coalesced packets are not counted.
Sourcepub fn get_rx_hw_gro_wire_bytes(&self) -> Result<u32, ErrorContext>
pub fn get_rx_hw_gro_wire_bytes(&self) -> Result<u32, ErrorContext>
See `rx-hw-gro-wire-packets`.
Sourcepub fn get_rx_hw_drop_ratelimits(&self) -> Result<u32, ErrorContext>
pub fn get_rx_hw_drop_ratelimits(&self) -> Result<u32, ErrorContext>
Number of the packets dropped by the device due to the received packets bitrate exceeding the device rate limit.
Sourcepub fn get_tx_hw_drops(&self) -> Result<u32, ErrorContext>
pub fn get_tx_hw_drops(&self) -> Result<u32, ErrorContext>
Number of packets that arrived at the device but never left it, encompassing packets dropped for reasons such as processing errors, as well as those affected by explicitly defined policies and packet filtering criteria.
Sourcepub fn get_tx_hw_drop_errors(&self) -> Result<u32, ErrorContext>
pub fn get_tx_hw_drop_errors(&self) -> Result<u32, ErrorContext>
Number of packets dropped because they were invalid or malformed.
Sourcepub fn get_tx_csum_none(&self) -> Result<u32, ErrorContext>
pub fn get_tx_csum_none(&self) -> Result<u32, ErrorContext>
Number of packets that did not require the device to calculate the checksum.
Sourcepub fn get_tx_needs_csum(&self) -> Result<u32, ErrorContext>
pub fn get_tx_needs_csum(&self) -> Result<u32, ErrorContext>
Number of packets that required the device to calculate the checksum. This counter includes the number of GSO wire packets for which device calculated the L4 checksum.
Sourcepub fn get_tx_hw_gso_packets(&self) -> Result<u32, ErrorContext>
pub fn get_tx_hw_gso_packets(&self) -> Result<u32, ErrorContext>
Number of packets that necessitated segmentation into smaller packets by the device.
Sourcepub fn get_tx_hw_gso_bytes(&self) -> Result<u32, ErrorContext>
pub fn get_tx_hw_gso_bytes(&self) -> Result<u32, ErrorContext>
See `tx-hw-gso-packets`.
Sourcepub fn get_tx_hw_gso_wire_packets(&self) -> Result<u32, ErrorContext>
pub fn get_tx_hw_gso_wire_packets(&self) -> Result<u32, ErrorContext>
Number of wire-sized packets generated by processing `tx-hw-gso-packets`
Sourcepub fn get_tx_hw_gso_wire_bytes(&self) -> Result<u32, ErrorContext>
pub fn get_tx_hw_gso_wire_bytes(&self) -> Result<u32, ErrorContext>
See `tx-hw-gso-wire-packets`.
Sourcepub fn get_tx_hw_drop_ratelimits(&self) -> Result<u32, ErrorContext>
pub fn get_tx_hw_drop_ratelimits(&self) -> Result<u32, ErrorContext>
Number of the packets dropped by the device due to the transmit packets bitrate exceeding the device rate limit.
Sourcepub fn get_tx_stop(&self) -> Result<u32, ErrorContext>
pub fn get_tx_stop(&self) -> Result<u32, ErrorContext>
Number of times driver paused accepting new tx packets from the stack to this queue, because the queue was full. Note that if BQL is supported and enabled on the device the networking stack will avoid queuing a lot of data at once.
Sourcepub fn get_tx_wake(&self) -> Result<u32, ErrorContext>
pub fn get_tx_wake(&self) -> Result<u32, ErrorContext>
Number of times driver re-started accepting send requests to this queue from the stack.