pub struct PushOpNapiGetDoReply<Prev: Rec> { /* private fields */ }netdev only.Expand description
Get information about NAPI instances configured on the system.
Implementations
Sourceimpl<Prev: Rec> PushOpNapiGetDoReply<Prev>
impl<Prev: Rec> PushOpNapiGetDoReply<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
Sourcepub fn push_ifindex(self, value: u32) -> Self
pub fn push_ifindex(self, value: u32) -> Self
ifindex of the netdevice to which NAPI instance belongs.
Sourcepub fn push_pid(self, value: u32) -> Self
pub fn push_pid(self, value: u32) -> Self
PID of the napi thread, if NAPI is configured to operate in threaded mode. If NAPI is not in threaded mode (i.e. uses normal softirq context), the attribute will be absent.
Sourcepub fn push_defer_hard_irqs(self, value: u32) -> Self
pub fn push_defer_hard_irqs(self, value: u32) -> Self
The number of consecutive empty polls before IRQ deferral ends and hardware IRQs are re-enabled.
Sourcepub fn push_gro_flush_timeout(self, value: u32) -> Self
pub fn push_gro_flush_timeout(self, value: u32) -> Self
The timeout, in nanoseconds, of when to trigger the NAPI watchdog timer which schedules NAPI processing. Additionally, a non-zero value will also prevent GRO from flushing recent super-frames at the end of a NAPI cycle. This may add receive latency in exchange for reducing the number of frames processed by the network stack.
Sourcepub fn push_irq_suspend_timeout(self, value: u32) -> Self
pub fn push_irq_suspend_timeout(self, value: u32) -> Self
The timeout, in nanoseconds, of how long to suspend irq processing, if event polling finds events
Sourcepub fn push_threaded(self, value: u32) -> Self
pub fn push_threaded(self, value: u32) -> Self
Whether the NAPI is configured to operate in threaded polling mode. If this is set to enabled then the NAPI context operates in threaded polling mode. If this is set to busy-poll, then the threaded polling mode also busy polls. Associated type: “NapiThreaded” (enum)