PushOpNapiSetDoRequest

Struct PushOpNapiSetDoRequest 

pub struct PushOpNapiSetDoRequest<Prev: Rec> { /* private fields */ }
Available on crate feature netdev only.
Set configurable NAPI instance settings.

Implementations

Source

impl<Prev: Rec> PushOpNapiSetDoRequest<Prev>

pub fn new(prev: Prev) -> Self

pub fn end_nested(self) -> Prev

pub fn push_id(self, value: u32) -> Self

ID of the NAPI instance.

pub fn push_defer_hard_irqs(self, value: u32) -> Self

The number of consecutive empty polls before IRQ deferral ends and hardware IRQs are re-enabled.

pub fn push_gro_flush_timeout(self, value: u32) -> Self

The timeout, in nanoseconds, of when to trigger the NAPI watchdog timer which schedules NAPI processing. Additionally, a non-zero value will also prevent GRO from flushing recent super-frames at the end of a NAPI cycle. This may add receive latency in exchange for reducing the number of frames processed by the network stack.

pub fn push_irq_suspend_timeout(self, value: u32) -> Self

The timeout, in nanoseconds, of how long to suspend irq processing, if event polling finds events

pub fn push_threaded(self, value: u32) -> Self

Whether the NAPI is configured to operate in threaded polling mode. If this is set to enabled then the NAPI context operates in threaded polling mode. If this is set to busy-poll, then the threaded polling mode also busy polls. Associated type: “NapiThreaded” (enum)