pub struct PushQstats<Prev: Pusher> { /* private fields */ }netdev only.Implementations
Sourceimpl<Prev: Pusher> PushQstats<Prev>
impl<Prev: Pusher> PushQstats<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
Sourcepub fn push_ifindex(self, value: u32) -> Self
pub fn push_ifindex(self, value: u32) -> Self
ifindex of the netdevice to which stats belong.
Sourcepub fn push_queue_type(self, value: u32) -> Self
pub fn push_queue_type(self, value: u32) -> Self
Queue type as rx, tx, for queue-id.
Associated type: QueueType (enum)
Sourcepub fn push_queue_id(self, value: u32) -> Self
pub fn push_queue_id(self, value: u32) -> Self
Queue ID, if stats are scoped to a single queue instance.
Sourcepub fn push_scope(self, value: u32) -> Self
pub fn push_scope(self, value: u32) -> Self
What object type should be used to iterate over the stats.
Associated type: QstatsScope (enum)
Sourcepub fn push_rx_packets(self, value: u32) -> Self
pub fn push_rx_packets(self, value: u32) -> Self
Number of wire packets successfully received and passed to the stack. For drivers supporting XDP, XDP is considered the first layer of the stack, so packets consumed by XDP are still counted here.
Sourcepub fn push_rx_bytes(self, value: u32) -> Self
pub fn push_rx_bytes(self, value: u32) -> Self
Successfully received bytes, see [rx-packets]{.title-ref}.
Sourcepub fn push_tx_packets(self, value: u32) -> Self
pub fn push_tx_packets(self, value: u32) -> Self
Number of wire packets successfully sent. Packet is considered to be successfully sent once it is in device memory (usually this means the device has issued a DMA completion for the packet).
Sourcepub fn push_tx_bytes(self, value: u32) -> Self
pub fn push_tx_bytes(self, value: u32) -> Self
Successfully sent bytes, see [tx-packets]{.title-ref}.
Sourcepub fn push_rx_alloc_fail(self, value: u32) -> Self
pub fn push_rx_alloc_fail(self, value: u32) -> Self
Number of times skb or buffer allocation failed on the Rx datapath. Allocation failure may, or may not result in a packet drop, depending on driver implementation and whether system recovers quickly.
Sourcepub fn push_rx_hw_drops(self, value: u32) -> Self
pub fn push_rx_hw_drops(self, value: u32) -> Self
Number of all packets which entered the device, but never left it, including but not limited to: packets dropped due to lack of buffer space, processing errors, explicit or implicit policies and packet filters.
Sourcepub fn push_rx_hw_drop_overruns(self, value: u32) -> Self
pub fn push_rx_hw_drop_overruns(self, value: u32) -> Self
Number of packets dropped due to transient lack of resources, such as buffer space, host descriptors etc.
Sourcepub fn push_rx_csum_complete(self, value: u32) -> Self
pub fn push_rx_csum_complete(self, value: u32) -> Self
Number of packets that were marked as CHECKSUM_COMPLETE.
Sourcepub fn push_rx_csum_unnecessary(self, value: u32) -> Self
pub fn push_rx_csum_unnecessary(self, value: u32) -> Self
Number of packets that were marked as CHECKSUM_UNNECESSARY.
Sourcepub fn push_rx_csum_none(self, value: u32) -> Self
pub fn push_rx_csum_none(self, value: u32) -> Self
Number of packets that were not checksummed by device.
Sourcepub fn push_rx_csum_bad(self, value: u32) -> Self
pub fn push_rx_csum_bad(self, value: u32) -> Self
Number of packets with bad checksum. The packets are not discarded, but still delivered to the stack.
Sourcepub fn push_rx_hw_gro_packets(self, value: u32) -> Self
pub fn push_rx_hw_gro_packets(self, value: u32) -> Self
Number of packets that were coalesced from smaller packets by the device. Counts only packets coalesced with the HW-GRO netdevice feature, LRO-coalesced packets are not counted.
Sourcepub fn push_rx_hw_gro_bytes(self, value: u32) -> Self
pub fn push_rx_hw_gro_bytes(self, value: u32) -> Self
See [rx-hw-gro-packets]{.title-ref}.
Sourcepub fn push_rx_hw_gro_wire_packets(self, value: u32) -> Self
pub fn push_rx_hw_gro_wire_packets(self, value: u32) -> Self
Number of packets that were coalesced to bigger packetss with the HW-GRO netdevice feature. LRO-coalesced packets are not counted.
Sourcepub fn push_rx_hw_gro_wire_bytes(self, value: u32) -> Self
pub fn push_rx_hw_gro_wire_bytes(self, value: u32) -> Self
See [rx-hw-gro-wire-packets]{.title-ref}.
Sourcepub fn push_rx_hw_drop_ratelimits(self, value: u32) -> Self
pub fn push_rx_hw_drop_ratelimits(self, value: u32) -> Self
Number of the packets dropped by the device due to the received packets bitrate exceeding the device rate limit.
Sourcepub fn push_tx_hw_drops(self, value: u32) -> Self
pub fn push_tx_hw_drops(self, value: u32) -> Self
Number of packets that arrived at the device but never left it, encompassing packets dropped for reasons such as processing errors, as well as those affected by explicitly defined policies and packet filtering criteria.
Sourcepub fn push_tx_hw_drop_errors(self, value: u32) -> Self
pub fn push_tx_hw_drop_errors(self, value: u32) -> Self
Number of packets dropped because they were invalid or malformed.
Sourcepub fn push_tx_csum_none(self, value: u32) -> Self
pub fn push_tx_csum_none(self, value: u32) -> Self
Number of packets that did not require the device to calculate the checksum.
Sourcepub fn push_tx_needs_csum(self, value: u32) -> Self
pub fn push_tx_needs_csum(self, value: u32) -> Self
Number of packets that required the device to calculate the checksum. This counter includes the number of GSO wire packets for which device calculated the L4 checksum.
Sourcepub fn push_tx_hw_gso_packets(self, value: u32) -> Self
pub fn push_tx_hw_gso_packets(self, value: u32) -> Self
Number of packets that necessitated segmentation into smaller packets by the device.
Sourcepub fn push_tx_hw_gso_bytes(self, value: u32) -> Self
pub fn push_tx_hw_gso_bytes(self, value: u32) -> Self
See [tx-hw-gso-packets]{.title-ref}.
Sourcepub fn push_tx_hw_gso_wire_packets(self, value: u32) -> Self
pub fn push_tx_hw_gso_wire_packets(self, value: u32) -> Self
Number of wire-sized packets generated by processing [tx-hw-gso-packets]{.title-ref}
Sourcepub fn push_tx_hw_gso_wire_bytes(self, value: u32) -> Self
pub fn push_tx_hw_gso_wire_bytes(self, value: u32) -> Self
See [tx-hw-gso-wire-packets]{.title-ref}.
Sourcepub fn push_tx_hw_drop_ratelimits(self, value: u32) -> Self
pub fn push_tx_hw_drop_ratelimits(self, value: u32) -> Self
Number of the packets dropped by the device due to the transmit packets bitrate exceeding the device rate limit.
Sourcepub fn push_tx_stop(self, value: u32) -> Self
pub fn push_tx_stop(self, value: u32) -> Self
Number of times driver paused accepting new tx packets from the stack to this queue, because the queue was full. Note that if BQL is supported and enabled on the device the networking stack will avoid queuing a lot of data at once.
Sourcepub fn push_tx_wake(self, value: u32) -> Self
pub fn push_tx_wake(self, value: u32) -> Self
Number of times driver re-started accepting send requests to this queue from the stack.