pub struct PushStats<Prev: Rec> { /* private fields */ }psp only.Implementations
Sourceimpl<Prev: Rec> PushStats<Prev>
impl<Prev: Rec> PushStats<Prev>
pub fn new(prev: Prev) -> Self
pub fn end_nested(self) -> Prev
Sourcepub fn push_dev_id(self, value: u32) -> Self
pub fn push_dev_id(self, value: u32) -> Self
PSP device ID.
Sourcepub fn push_key_rotations(self, value: u32) -> Self
pub fn push_key_rotations(self, value: u32) -> Self
Number of key rotations during the lifetime of the device. Kernel statistic.
Sourcepub fn push_stale_events(self, value: u32) -> Self
pub fn push_stale_events(self, value: u32) -> Self
Number of times a socket’s Rx got shut down due to using a key which went stale (fully rotated out). Kernel statistic.
Sourcepub fn push_rx_packets(self, value: u32) -> Self
pub fn push_rx_packets(self, value: u32) -> Self
Number of successfully processed and authenticated PSP packets. Device statistic (from the PSP spec).
Sourcepub fn push_rx_bytes(self, value: u32) -> Self
pub fn push_rx_bytes(self, value: u32) -> Self
Number of successfully authenticated PSP bytes received, counting from the first byte after the IV through the last byte of payload. The fixed initial portion of the PSP header (16 bytes) and the PSP trailer/ICV (16 bytes) are not included in this count. Device statistic (from the PSP spec).
Sourcepub fn push_rx_auth_fail(self, value: u32) -> Self
pub fn push_rx_auth_fail(self, value: u32) -> Self
Number of received PSP packets with unsuccessful authentication. Device statistic (from the PSP spec).
Sourcepub fn push_rx_error(self, value: u32) -> Self
pub fn push_rx_error(self, value: u32) -> Self
Number of received PSP packets with length/framing errors. Device statistic (from the PSP spec).
Sourcepub fn push_rx_bad(self, value: u32) -> Self
pub fn push_rx_bad(self, value: u32) -> Self
Number of received PSP packets with miscellaneous errors (invalid master key indicated by SPI, unsupported version, etc.) Device statistic (from the PSP spec).
Sourcepub fn push_tx_packets(self, value: u32) -> Self
pub fn push_tx_packets(self, value: u32) -> Self
Number of successfully processed PSP packets for transmission. Device statistic (from the PSP spec).
Sourcepub fn push_tx_bytes(self, value: u32) -> Self
pub fn push_tx_bytes(self, value: u32) -> Self
Number of successfully processed PSP bytes for transmit, counting from the first byte after the IV through the last byte of payload. The fixed initial portion of the PSP header (16 bytes) and the PSP trailer/ICV (16 bytes) are not included in this count. Device statistic (from the PSP spec).
Sourcepub fn push_tx_error(self, value: u32) -> Self
pub fn push_tx_error(self, value: u32) -> Self
Number of PSP packets for transmission with errors. Device statistic (from the PSP spec).