pub trait NetlinkRequest {
type ReplyType<'buf>;
// Required methods
fn protocol(&self) -> Protocol;
fn flags(&self) -> u16;
fn payload(&self) -> &[u8] ⓘ;
fn decode_reply(buf: &[u8]) -> Self::ReplyType<'_>;
// Provided method
fn lookup(
buf: &[u8],
offset: usize,
missing_type: Option<u16>,
) -> (Vec<(&'static str, usize)>, Option<&'static str>) { ... }
}Expand description
A trait describing how to handle a particular request. It designed to be used by a netlink socket implementation.
Required Associated Types
Required Methods
fn decode_reply(buf: &[u8]) -> Self::ReplyType<'_>
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl NetlinkRequest for netlink_bindings::conntrack::RequestOpGetDoRequest<'_>
Available on crate feature conntrack only.
impl NetlinkRequest for netlink_bindings::conntrack::RequestOpGetDoRequest<'_>
Available on crate feature
conntrack only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetDoReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::conntrack::RequestOpGetDumpRequest<'_>
Available on crate feature conntrack only.
impl NetlinkRequest for netlink_bindings::conntrack::RequestOpGetDumpRequest<'_>
Available on crate feature
conntrack only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetStatsDumpRequest<'_>
Available on crate feature conntrack only.
impl NetlinkRequest for RequestOpGetStatsDumpRequest<'_>
Available on crate feature
conntrack only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetStatsDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDpipeEntriesGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpDpipeEntriesGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpDpipeEntriesGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpDpipeHeadersGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpDpipeHeadersGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpDpipeHeadersGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpDpipeTableCountersSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpDpipeTableCountersSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpDpipeTableCountersSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpDpipeTableGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpDpipeTableGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpDpipeTableGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpEswitchGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpEswitchGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpEswitchGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpEswitchSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpEswitchSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpEswitchSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpFlashUpdateDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpFlashUpdateDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpFlashUpdateDoReply<'buf>
Sourceimpl NetlinkRequest for netlink_bindings::devlink::RequestOpGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for netlink_bindings::devlink::RequestOpGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpGetDoReply<'buf>
Sourceimpl NetlinkRequest for netlink_bindings::devlink::RequestOpGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for netlink_bindings::devlink::RequestOpGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpHealthReporterDiagnoseDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpHealthReporterDiagnoseDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpHealthReporterDiagnoseDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpHealthReporterDumpClearDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpHealthReporterDumpClearDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpHealthReporterDumpClearDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpHealthReporterDumpGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpHealthReporterDumpGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpHealthReporterDumpGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpHealthReporterGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpHealthReporterGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpHealthReporterGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpHealthReporterGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpHealthReporterGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpHealthReporterGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpHealthReporterRecoverDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpHealthReporterRecoverDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpHealthReporterRecoverDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpHealthReporterSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpHealthReporterSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpHealthReporterSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpHealthReporterTestDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpHealthReporterTestDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpHealthReporterTestDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpInfoGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpInfoGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpInfoGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpInfoGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpInfoGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpInfoGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpLinecardGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpLinecardGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpLinecardGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpLinecardGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpLinecardGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpLinecardGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpLinecardSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpLinecardSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpLinecardSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpNotifyFilterSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpNotifyFilterSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpNotifyFilterSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpParamGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpParamGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpParamGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpParamGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpParamGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpParamGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpParamSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpParamSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpParamSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPortDelDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpPortDelDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpPortDelDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPortGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpPortGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpPortGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPortGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpPortGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpPortGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPortNewDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpPortNewDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpPortNewDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPortParamGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpPortParamGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpPortParamGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPortParamGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpPortParamGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpPortParamGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPortParamSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpPortParamSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpPortParamSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPortSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpPortSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpPortSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPortSplitDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpPortSplitDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpPortSplitDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPortUnsplitDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpPortUnsplitDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpPortUnsplitDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpRateDelDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpRateDelDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpRateDelDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpRateGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpRateGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpRateGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpRateGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpRateGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpRateGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpRateNewDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpRateNewDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpRateNewDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpRateSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpRateSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpRateSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpRegionDelDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpRegionDelDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpRegionDelDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpRegionGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpRegionGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpRegionGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpRegionGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpRegionGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpRegionGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpRegionNewDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpRegionNewDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpRegionNewDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpRegionReadDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpRegionReadDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpRegionReadDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpReloadDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpReloadDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpReloadDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpResourceDumpDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpResourceDumpDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpResourceDumpDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpResourceSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpResourceSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpResourceSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbOccMaxClearDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbOccMaxClearDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbOccMaxClearDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbOccSnapshotDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbOccSnapshotDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbOccSnapshotDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbPoolGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbPoolGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbPoolGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbPoolGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbPoolGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbPoolGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbPoolSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbPoolSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbPoolSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbPortPoolGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbPortPoolGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbPortPoolGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbPortPoolGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbPortPoolGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbPortPoolGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbPortPoolSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbPortPoolSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbPortPoolSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbTcPoolBindGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbTcPoolBindGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbTcPoolBindGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbTcPoolBindGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbTcPoolBindGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbTcPoolBindGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSbTcPoolBindSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSbTcPoolBindSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSbTcPoolBindSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSelftestsGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSelftestsGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSelftestsGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSelftestsGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSelftestsGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSelftestsGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSelftestsRunDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpSelftestsRunDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpSelftestsRunDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpTrapGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpTrapGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpTrapGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpTrapGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpTrapGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpTrapGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpTrapGroupGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpTrapGroupGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpTrapGroupGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpTrapGroupGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpTrapGroupGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpTrapGroupGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpTrapGroupSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpTrapGroupSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpTrapGroupSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpTrapPolicerGetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpTrapPolicerGetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpTrapPolicerGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpTrapPolicerGetDumpRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpTrapPolicerGetDumpRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpTrapPolicerGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpTrapPolicerSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpTrapPolicerSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpTrapPolicerSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpTrapSetDoRequest<'_>
Available on crate feature devlink only.
impl NetlinkRequest for RequestOpTrapSetDoRequest<'_>
Available on crate feature
devlink only.type ReplyType<'buf> = IterableOpTrapSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpBindRxDoRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpBindRxDoRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpBindRxDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpBindTxDoRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpBindTxDoRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpBindTxDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpDevGetDoRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpDevGetDoRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpDevGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpDevGetDumpRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpDevGetDumpRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpDevGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpNapiGetDoRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpNapiGetDoRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpNapiGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpNapiGetDumpRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpNapiGetDumpRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpNapiGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpNapiSetDoRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpNapiSetDoRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpNapiSetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPagePoolGetDoRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpPagePoolGetDoRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpPagePoolGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPagePoolGetDumpRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpPagePoolGetDumpRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpPagePoolGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPagePoolStatsGetDoRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpPagePoolStatsGetDoRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpPagePoolStatsGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpPagePoolStatsGetDumpRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpPagePoolStatsGetDumpRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpPagePoolStatsGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpQstatsGetDumpRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpQstatsGetDumpRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpQstatsGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpQueueGetDoRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpQueueGetDoRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpQueueGetDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpQueueGetDumpRequest<'_>
Available on crate feature netdev only.
impl NetlinkRequest for RequestOpQueueGetDumpRequest<'_>
Available on crate feature
netdev only.type ReplyType<'buf> = IterableOpQueueGetDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpBatchBeginDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpBatchBeginDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpBatchBeginDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpBatchEndDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpBatchEndDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpBatchEndDoReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::nftables::RequestOpDelchainDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for netlink_bindings::nftables::RequestOpDelchainDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDelchainDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDelflowtableDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDelflowtableDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDelflowtableDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDelobjDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDelobjDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDelobjDoReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::nftables::RequestOpDelruleDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for netlink_bindings::nftables::RequestOpDelruleDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDelruleDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDelsetDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDelsetDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDelsetDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDelsetelemDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDelsetelemDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDelsetelemDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDeltableDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDeltableDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDeltableDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDestroychainDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDestroychainDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDestroychainDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDestroyflowtableDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDestroyflowtableDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDestroyflowtableDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDestroyobjDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDestroyobjDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDestroyobjDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDestroyruleDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDestroyruleDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDestroyruleDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDestroysetDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDestroysetDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDestroysetDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDestroysetelemDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDestroysetelemDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDestroysetelemDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDestroytableDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpDestroytableDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpDestroytableDoReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::nftables::RequestOpGetchainDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for netlink_bindings::nftables::RequestOpGetchainDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetchainDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetchainDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetchainDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetchainDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetcompatDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetcompatDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetcompatDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetcompatDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetcompatDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetcompatDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetflowtableDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetflowtableDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetflowtableDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetflowtableDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetflowtableDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetflowtableDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetgenDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetgenDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetgenDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetgenDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetgenDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetgenDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetobjDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetobjDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetobjDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetobjDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetobjDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetobjDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetruleDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetruleDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetruleDoReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::nftables::RequestOpGetruleDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for netlink_bindings::nftables::RequestOpGetruleDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetruleDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetruleResetDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetruleResetDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetruleResetDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetruleResetDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetruleResetDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetruleResetDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetsetDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetsetDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetsetDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetsetDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetsetDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetsetDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetsetelemDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetsetelemDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetsetelemDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetsetelemDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetsetelemDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetsetelemDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetsetelemResetDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetsetelemResetDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetsetelemResetDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetsetelemResetDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGetsetelemResetDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGetsetelemResetDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGettableDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGettableDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGettableDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGettableDumpRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpGettableDumpRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpGettableDumpReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::nftables::RequestOpNewchainDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for netlink_bindings::nftables::RequestOpNewchainDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpNewchainDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewflowtableDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpNewflowtableDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpNewflowtableDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewobjDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpNewobjDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpNewobjDoReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::nftables::RequestOpNewruleDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for netlink_bindings::nftables::RequestOpNewruleDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpNewruleDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewsetDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpNewsetDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpNewsetDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewsetelemDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpNewsetelemDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpNewsetelemDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewtableDoRequest<'_>
Available on crate feature nftables only.
impl NetlinkRequest for RequestOpNewtableDoRequest<'_>
Available on crate feature
nftables only.type ReplyType<'buf> = (PushNfgenmsg, IterableOpNewtableDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDoRequest<'_>
Available on crate feature nl80211 only.
impl NetlinkRequest for RequestOpDoRequest<'_>
Available on crate feature
nl80211 only.type ReplyType<'buf> = IterableNl80211Attrs<'buf>
Sourceimpl NetlinkRequest for RequestOpDumpRequest<'_>
Available on crate feature nl80211 only.
impl NetlinkRequest for RequestOpDumpRequest<'_>
Available on crate feature
nl80211 only.type ReplyType<'buf> = IterableNl80211Attrs<'buf>
Sourceimpl NetlinkRequest for RequestOpGetInterfaceDoRequest<'_>
Available on crate feature nl80211 only.
impl NetlinkRequest for RequestOpGetInterfaceDoRequest<'_>
Available on crate feature
nl80211 only.type ReplyType<'buf> = IterableNl80211Attrs<'buf>
Sourceimpl NetlinkRequest for RequestOpGetInterfaceDumpRequest<'_>
Available on crate feature nl80211 only.
impl NetlinkRequest for RequestOpGetInterfaceDumpRequest<'_>
Available on crate feature
nl80211 only.type ReplyType<'buf> = IterableNl80211Attrs<'buf>
Sourceimpl NetlinkRequest for RequestOpGetProtocolFeaturesDoRequest<'_>
Available on crate feature nl80211 only.
impl NetlinkRequest for RequestOpGetProtocolFeaturesDoRequest<'_>
Available on crate feature
nl80211 only.type ReplyType<'buf> = IterableNl80211Attrs<'buf>
Sourceimpl NetlinkRequest for RequestOpGetWiphyDoRequest<'_>
Available on crate feature nl80211 only.
impl NetlinkRequest for RequestOpGetWiphyDoRequest<'_>
Available on crate feature
nl80211 only.type ReplyType<'buf> = IterableNl80211Attrs<'buf>
Sourceimpl NetlinkRequest for RequestOpGetWiphyDumpRequest<'_>
Available on crate feature nl80211 only.
impl NetlinkRequest for RequestOpGetWiphyDumpRequest<'_>
Available on crate feature
nl80211 only.type ReplyType<'buf> = IterableNl80211Attrs<'buf>
Sourceimpl NetlinkRequest for RequestOpGetfamilyDoRequest<'_>
Available on crate feature nlctrl only.
impl NetlinkRequest for RequestOpGetfamilyDoRequest<'_>
Available on crate feature
nlctrl only.type ReplyType<'buf> = IterableOpGetfamilyDoReply<'buf>
Sourceimpl NetlinkRequest for RequestOpGetfamilyDumpRequest<'_>
Available on crate feature nlctrl only.
impl NetlinkRequest for RequestOpGetfamilyDumpRequest<'_>
Available on crate feature
nlctrl only.type ReplyType<'buf> = IterableOpGetfamilyDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpGetpolicyDumpRequest<'_>
Available on crate feature nlctrl only.
impl NetlinkRequest for RequestOpGetpolicyDumpRequest<'_>
Available on crate feature
nlctrl only.type ReplyType<'buf> = IterableOpGetpolicyDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpDeladdrDoRequest<'_>
Available on crate feature rt-addr only.
impl NetlinkRequest for RequestOpDeladdrDoRequest<'_>
Available on crate feature
rt-addr only.type ReplyType<'buf> = (PushIfaddrmsg, IterableOpDeladdrDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetaddrDumpRequest<'_>
Available on crate feature rt-addr only.
impl NetlinkRequest for RequestOpGetaddrDumpRequest<'_>
Available on crate feature
rt-addr only.type ReplyType<'buf> = (PushIfaddrmsg, IterableOpGetaddrDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetmulticastDoRequest<'_>
Available on crate feature rt-addr only.
impl NetlinkRequest for RequestOpGetmulticastDoRequest<'_>
Available on crate feature
rt-addr only.type ReplyType<'buf> = (PushIfaddrmsg, IterableOpGetmulticastDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetmulticastDumpRequest<'_>
Available on crate feature rt-addr only.
impl NetlinkRequest for RequestOpGetmulticastDumpRequest<'_>
Available on crate feature
rt-addr only.type ReplyType<'buf> = (PushIfaddrmsg, IterableOpGetmulticastDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewaddrDoRequest<'_>
Available on crate feature rt-addr only.
impl NetlinkRequest for RequestOpNewaddrDoRequest<'_>
Available on crate feature
rt-addr only.type ReplyType<'buf> = (PushIfaddrmsg, IterableOpNewaddrDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDellinkDoRequest<'_>
Available on crate feature rt-link only.
impl NetlinkRequest for RequestOpDellinkDoRequest<'_>
Available on crate feature
rt-link only.type ReplyType<'buf> = (PushIfinfomsg, IterableOpDellinkDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetlinkDoRequest<'_>
Available on crate feature rt-link only.
impl NetlinkRequest for RequestOpGetlinkDoRequest<'_>
Available on crate feature
rt-link only.type ReplyType<'buf> = (PushIfinfomsg, IterableOpGetlinkDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetlinkDumpRequest<'_>
Available on crate feature rt-link only.
impl NetlinkRequest for RequestOpGetlinkDumpRequest<'_>
Available on crate feature
rt-link only.type ReplyType<'buf> = (PushIfinfomsg, IterableOpGetlinkDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetstatsDoRequest<'_>
Available on crate feature rt-link only.
impl NetlinkRequest for RequestOpGetstatsDoRequest<'_>
Available on crate feature
rt-link only.type ReplyType<'buf> = (PushIfStatsMsg, IterableOpGetstatsDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetstatsDumpRequest<'_>
Available on crate feature rt-link only.
impl NetlinkRequest for RequestOpGetstatsDumpRequest<'_>
Available on crate feature
rt-link only.type ReplyType<'buf> = (PushIfStatsMsg, IterableOpGetstatsDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewlinkDoRequest<'_>
Available on crate feature rt-link only.
impl NetlinkRequest for RequestOpNewlinkDoRequest<'_>
Available on crate feature
rt-link only.type ReplyType<'buf> = (PushIfinfomsg, IterableOpNewlinkDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpSetlinkDoRequest<'_>
Available on crate feature rt-link only.
impl NetlinkRequest for RequestOpSetlinkDoRequest<'_>
Available on crate feature
rt-link only.type ReplyType<'buf> = (PushIfinfomsg, IterableOpSetlinkDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDelneighDoRequest<'_>
Available on crate feature rt-neigh only.
impl NetlinkRequest for RequestOpDelneighDoRequest<'_>
Available on crate feature
rt-neigh only.type ReplyType<'buf> = (PushNdmsg, IterableOpDelneighDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetneighDoRequest<'_>
Available on crate feature rt-neigh only.
impl NetlinkRequest for RequestOpGetneighDoRequest<'_>
Available on crate feature
rt-neigh only.type ReplyType<'buf> = (PushNdmsg, IterableOpGetneighDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetneighDumpRequest<'_>
Available on crate feature rt-neigh only.
impl NetlinkRequest for RequestOpGetneighDumpRequest<'_>
Available on crate feature
rt-neigh only.type ReplyType<'buf> = (PushNdmsg, IterableOpGetneighDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetneightblDumpRequest<'_>
Available on crate feature rt-neigh only.
impl NetlinkRequest for RequestOpGetneightblDumpRequest<'_>
Available on crate feature
rt-neigh only.type ReplyType<'buf> = (PushNdtmsg, IterableOpGetneightblDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewneighDoRequest<'_>
Available on crate feature rt-neigh only.
impl NetlinkRequest for RequestOpNewneighDoRequest<'_>
Available on crate feature
rt-neigh only.type ReplyType<'buf> = (PushNdmsg, IterableOpNewneighDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpSetneightblDoRequest<'_>
Available on crate feature rt-neigh only.
impl NetlinkRequest for RequestOpSetneightblDoRequest<'_>
Available on crate feature
rt-neigh only.type ReplyType<'buf> = (PushNdtmsg, IterableOpSetneightblDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDelrouteDoRequest<'_>
Available on crate feature rt-route only.
impl NetlinkRequest for RequestOpDelrouteDoRequest<'_>
Available on crate feature
rt-route only.type ReplyType<'buf> = (PushRtmsg, IterableOpDelrouteDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetrouteDoRequest<'_>
Available on crate feature rt-route only.
impl NetlinkRequest for RequestOpGetrouteDoRequest<'_>
Available on crate feature
rt-route only.type ReplyType<'buf> = (PushRtmsg, IterableOpGetrouteDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetrouteDumpRequest<'_>
Available on crate feature rt-route only.
impl NetlinkRequest for RequestOpGetrouteDumpRequest<'_>
Available on crate feature
rt-route only.type ReplyType<'buf> = (PushRtmsg, IterableOpGetrouteDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewrouteDoRequest<'_>
Available on crate feature rt-route only.
impl NetlinkRequest for RequestOpNewrouteDoRequest<'_>
Available on crate feature
rt-route only.type ReplyType<'buf> = (PushRtmsg, IterableOpNewrouteDoReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::rt_rule::RequestOpDelruleDoRequest<'_>
Available on crate feature rt-rule only.
impl NetlinkRequest for netlink_bindings::rt_rule::RequestOpDelruleDoRequest<'_>
Available on crate feature
rt-rule only.type ReplyType<'buf> = (PushFibRuleHdr, IterableOpDelruleDoReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::rt_rule::RequestOpGetruleDumpRequest<'_>
Available on crate feature rt-rule only.
impl NetlinkRequest for netlink_bindings::rt_rule::RequestOpGetruleDumpRequest<'_>
Available on crate feature
rt-rule only.type ReplyType<'buf> = (PushFibRuleHdr, IterableOpGetruleDumpReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::rt_rule::RequestOpNewruleDoRequest<'_>
Available on crate feature rt-rule only.
impl NetlinkRequest for netlink_bindings::rt_rule::RequestOpNewruleDoRequest<'_>
Available on crate feature
rt-rule only.type ReplyType<'buf> = (PushFibRuleHdr, IterableOpNewruleDoReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::tc::RequestOpDelchainDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for netlink_bindings::tc::RequestOpDelchainDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpDelchainDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDelqdiscDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpDelqdiscDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpDelqdiscDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDeltclassDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpDeltclassDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpDeltclassDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpDeltfilterDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpDeltfilterDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpDeltfilterDoReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::tc::RequestOpGetchainDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for netlink_bindings::tc::RequestOpGetchainDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpGetchainDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetqdiscDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpGetqdiscDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpGetqdiscDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetqdiscDumpRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpGetqdiscDumpRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpGetqdiscDumpReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGettclassDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpGettclassDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpGettclassDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGettfilterDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpGettfilterDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpGettfilterDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGettfilterDumpRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpGettfilterDumpRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpGettfilterDumpReply<'buf>)
Sourceimpl NetlinkRequest for netlink_bindings::tc::RequestOpNewchainDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for netlink_bindings::tc::RequestOpNewchainDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpNewchainDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewqdiscDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpNewqdiscDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpNewqdiscDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewtclassDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpNewtclassDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpNewtclassDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpNewtfilterDoRequest<'_>
Available on crate feature tc only.
impl NetlinkRequest for RequestOpNewtfilterDoRequest<'_>
Available on crate feature
tc only.type ReplyType<'buf> = (PushTcmsg, IterableOpNewtfilterDoReply<'buf>)
Sourceimpl NetlinkRequest for RequestOpGetDeviceDumpRequest<'_>
Available on crate feature wireguard only.
impl NetlinkRequest for RequestOpGetDeviceDumpRequest<'_>
Available on crate feature
wireguard only.type ReplyType<'buf> = IterableOpGetDeviceDumpReply<'buf>
Sourceimpl NetlinkRequest for RequestOpSetDeviceDoRequest<'_>
Available on crate feature wireguard only.
impl NetlinkRequest for RequestOpSetDeviceDoRequest<'_>
Available on crate feature
wireguard only.